## Getting started

To create a new [Cloudscape](https://cloudscape.design/) React Typescript Project, there are a couple of options:

### Via Projen CLI

```
npx projen new --from @aws-prototyping-sdk/cloudscape-react-ts-website cloudscape-react-ts-website [--application-name <your-app>]
```

### Programmatically

```java
// Example automatically generated from non-compiling source. May contain errors.
CloudscapeReactTsWebsiteProject.Builder.create()
        .defaultReleaseBranch("mainline")
        .name("<name-of-package>")
        .applicationName("<name-of-app>")
        .build();
```

### Running your synthesized Application

To run your synthesized application locally, run `npx projen dev`.

## Developer Notes

To enable Cognito auth, ensure you have a runtime-config.json file in the root of your deployed project which at least contains the following:

```json
{
    "region": "<aws-region>",
    "identityPoolId":"<identity-pool-id>",
    "userPoolId":"<user-pool-id>",
    "userPoolWebClientId":"<user-pool-web-client-id>"
}
```

The easiest way to get this set up is to use the static-website + identity packages to deploy your website.

An example of how to do this is as follows:

```java
// Example automatically generated from non-compiling source. May contain errors.
Object userIdentity = new UserIdentity(this, "UserIdentity");
StaticWebsite.Builder.create(this, "StaticWebsite")
        .websiteContentPath("<relative>/<path>/<to>/<built>/<website>")
        .runtimeOptions(Map.of(
                "jsonPayload", Map.of(
                        "region", Stack.of(this).getRegion(),
                        "identityPoolId", userIdentity.getIdentityPool().getIdentityPoolId(),
                        "userPoolId", userIdentity.getUserPool().getUserPoolId(),
                        "userPoolWebClientId", userIdentity.getUserPoolClient().getUserPoolClientId())))
        .build();
```

For local development, you will need to copy the generated runtime-config.json file into your /public directory. An example on how to do this is as follows:

```
curl https://dxxxxxxxxxx.cloudfront.net/runtime-config.json > public/runtime-config.json
```
# API Reference <a name="API Reference" id="api-reference"></a>


## Structs <a name="Structs" id="Structs"></a>

### CloudscapeReactTsWebsiteProjectOptions <a name="CloudscapeReactTsWebsiteProjectOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions"></a>

Configuration options for the CloudscapeReactTsWebsiteProject.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.Initializer"></a>

```java
import software.aws.awsprototypingsdk.cloudscapereacttswebsite.CloudscapeReactTsWebsiteProjectOptions;

CloudscapeReactTsWebsiteProjectOptions.builder()
    .name(java.lang.String)
//  .commitGenerated(java.lang.Boolean)
//  .gitIgnoreOptions(IgnoreFileOptions)
//  .gitOptions(GitOptions)
//  .logging(LoggerOptions)
//  .outdir(java.lang.String)
//  .parent(Project)
//  .projenCommand(java.lang.String)
//  .projenrcJson(java.lang.Boolean)
//  .projenrcJsonOptions(ProjenrcJsonOptions)
//  .renovatebot(java.lang.Boolean)
//  .renovatebotOptions(RenovatebotOptions)
//  .autoApproveOptions(AutoApproveOptions)
//  .autoMerge(java.lang.Boolean)
//  .autoMergeOptions(AutoMergeOptions)
//  .clobber(java.lang.Boolean)
//  .devContainer(java.lang.Boolean)
//  .github(java.lang.Boolean)
//  .githubOptions(GitHubOptions)
//  .gitpod(java.lang.Boolean)
//  .mergify(java.lang.Boolean)
//  .mergifyOptions(MergifyOptions)
//  .projectType(ProjectType)
//  .projenCredentials(GithubCredentials)
//  .projenTokenSecret(java.lang.String)
//  .readme(SampleReadmeProps)
//  .stale(java.lang.Boolean)
//  .staleOptions(StaleOptions)
//  .vscode(java.lang.Boolean)
//  .allowLibraryDependencies(java.lang.Boolean)
//  .authorEmail(java.lang.String)
//  .authorName(java.lang.String)
//  .authorOrganization(java.lang.Boolean)
//  .authorUrl(java.lang.String)
//  .autoDetectBin(java.lang.Boolean)
//  .bin(java.util.Map<java.lang.String, java.lang.String>)
//  .bugsEmail(java.lang.String)
//  .bugsUrl(java.lang.String)
//  .bundledDeps(java.util.List<java.lang.String>)
//  .codeArtifactOptions(CodeArtifactOptions)
//  .deps(java.util.List<java.lang.String>)
//  .description(java.lang.String)
//  .devDeps(java.util.List<java.lang.String>)
//  .entrypoint(java.lang.String)
//  .homepage(java.lang.String)
//  .keywords(java.util.List<java.lang.String>)
//  .license(java.lang.String)
//  .licensed(java.lang.Boolean)
//  .maxNodeVersion(java.lang.String)
//  .minNodeVersion(java.lang.String)
//  .npmAccess(NpmAccess)
//  .npmRegistry(java.lang.String)
//  .npmRegistryUrl(java.lang.String)
//  .npmTokenSecret(java.lang.String)
//  .packageManager(NodePackageManager)
//  .packageName(java.lang.String)
//  .peerDependencyOptions(PeerDependencyOptions)
//  .peerDeps(java.util.List<java.lang.String>)
//  .pnpmVersion(java.lang.String)
//  .repository(java.lang.String)
//  .repositoryDirectory(java.lang.String)
//  .scopedPackagesOptions(java.util.List<ScopedPackagesOptions>)
//  .scripts(java.util.Map<java.lang.String, java.lang.String>)
//  .stability(java.lang.String)
//  .jsiiReleaseVersion(java.lang.String)
//  .majorVersion(java.lang.Number)
//  .minMajorVersion(java.lang.Number)
//  .npmDistTag(java.lang.String)
//  .postBuildSteps(java.util.List<JobStep>)
//  .prerelease(java.lang.String)
//  .publishDryRun(java.lang.Boolean)
//  .publishTasks(java.lang.Boolean)
//  .releaseBranches(java.util.Map<java.lang.String, BranchOptions>)
//  .releaseEveryCommit(java.lang.Boolean)
//  .releaseFailureIssue(java.lang.Boolean)
//  .releaseFailureIssueLabel(java.lang.String)
//  .releaseSchedule(java.lang.String)
//  .releaseTagPrefix(java.lang.String)
//  .releaseTrigger(ReleaseTrigger)
//  .releaseWorkflowName(java.lang.String)
//  .releaseWorkflowSetupSteps(java.util.List<JobStep>)
//  .versionrcOptions(java.util.Map<java.lang.String, java.lang.Object>)
//  .workflowContainerImage(java.lang.String)
//  .workflowRunsOn(java.util.List<java.lang.String>)
    .defaultReleaseBranch(java.lang.String)
//  .artifactsDirectory(java.lang.String)
//  .autoApproveUpgrades(java.lang.Boolean)
//  .buildWorkflow(java.lang.Boolean)
//  .buildWorkflowTriggers(Triggers)
//  .bundlerOptions(BundlerOptions)
//  .codeCov(java.lang.Boolean)
//  .codeCovTokenSecret(java.lang.String)
//  .copyrightOwner(java.lang.String)
//  .copyrightPeriod(java.lang.String)
//  .dependabot(java.lang.Boolean)
//  .dependabotOptions(DependabotOptions)
//  .depsUpgrade(java.lang.Boolean)
//  .depsUpgradeOptions(UpgradeDependenciesOptions)
//  .gitignore(java.util.List<java.lang.String>)
//  .jest(java.lang.Boolean)
//  .jestOptions(JestOptions)
//  .mutableBuild(java.lang.Boolean)
//  .npmignore(java.util.List<java.lang.String>)
//  .npmignoreEnabled(java.lang.Boolean)
//  .npmIgnoreOptions(IgnoreFileOptions)
//  .package(java.lang.Boolean)
//  .prettier(java.lang.Boolean)
//  .prettierOptions(PrettierOptions)
//  .projenDevDependency(java.lang.Boolean)
//  .projenrcJs(java.lang.Boolean)
//  .projenrcJsOptions(ProjenrcOptions)
//  .projenVersion(java.lang.String)
//  .pullRequestTemplate(java.lang.Boolean)
//  .pullRequestTemplateContents(java.util.List<java.lang.String>)
//  .release(java.lang.Boolean)
//  .releaseToNpm(java.lang.Boolean)
//  .releaseWorkflow(java.lang.Boolean)
//  .workflowBootstrapSteps(java.util.List<JobStep>)
//  .workflowGitIdentity(GitIdentity)
//  .workflowNodeVersion(java.lang.String)
//  .disableTsconfig(java.lang.Boolean)
//  .disableTsconfigDev(java.lang.Boolean)
//  .docgen(java.lang.Boolean)
//  .docsDirectory(java.lang.String)
//  .entrypointTypes(java.lang.String)
//  .eslint(java.lang.Boolean)
//  .eslintOptions(EslintOptions)
//  .libdir(java.lang.String)
//  .projenrcTs(java.lang.Boolean)
//  .projenrcTsOptions(ProjenrcOptions)
//  .sampleCode(java.lang.Boolean)
//  .srcdir(java.lang.String)
//  .testdir(java.lang.String)
//  .tsconfig(TypescriptConfigOptions)
//  .tsconfigDev(TypescriptConfigOptions)
//  .tsconfigDevFile(java.lang.String)
//  .typescriptVersion(java.lang.String)
//  .rewire(java.util.Map<java.lang.String, java.lang.Object>)
//  .applicationName(java.lang.String)
//  .publicDir(java.lang.String)
    .build();
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.name">name</a></code> | <code>java.lang.String</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.commitGenerated">commitGenerated</a></code> | <code>java.lang.Boolean</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitIgnoreOptions">gitIgnoreOptions</a></code> | <code>io.github.cdklabs.projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitOptions">gitOptions</a></code> | <code>io.github.cdklabs.projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.logging">logging</a></code> | <code>io.github.cdklabs.projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.outdir">outdir</a></code> | <code>java.lang.String</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.parent">parent</a></code> | <code>io.github.cdklabs.projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenCommand">projenCommand</a></code> | <code>java.lang.String</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJson">projenrcJson</a></code> | <code>java.lang.Boolean</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJsonOptions">projenrcJsonOptions</a></code> | <code>io.github.cdklabs.projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.renovatebot">renovatebot</a></code> | <code>java.lang.Boolean</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.renovatebotOptions">renovatebotOptions</a></code> | <code>io.github.cdklabs.projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoApproveOptions">autoApproveOptions</a></code> | <code>io.github.cdklabs.projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoMerge">autoMerge</a></code> | <code>java.lang.Boolean</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoMergeOptions">autoMergeOptions</a></code> | <code>io.github.cdklabs.projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.clobber">clobber</a></code> | <code>java.lang.Boolean</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.devContainer">devContainer</a></code> | <code>java.lang.Boolean</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.github">github</a></code> | <code>java.lang.Boolean</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.githubOptions">githubOptions</a></code> | <code>io.github.cdklabs.projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitpod">gitpod</a></code> | <code>java.lang.Boolean</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mergify">mergify</a></code> | <code>java.lang.Boolean</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mergifyOptions">mergifyOptions</a></code> | <code>io.github.cdklabs.projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projectType">projectType</a></code> | <code>io.github.cdklabs.projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenCredentials">projenCredentials</a></code> | <code>io.github.cdklabs.projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenTokenSecret">projenTokenSecret</a></code> | <code>java.lang.String</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.readme">readme</a></code> | <code>io.github.cdklabs.projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.stale">stale</a></code> | <code>java.lang.Boolean</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.staleOptions">staleOptions</a></code> | <code>io.github.cdklabs.projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.vscode">vscode</a></code> | <code>java.lang.Boolean</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.allowLibraryDependencies">allowLibraryDependencies</a></code> | <code>java.lang.Boolean</code> | Allow the project to include `peerDependencies` and `bundledDependencies`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorEmail">authorEmail</a></code> | <code>java.lang.String</code> | Author's e-mail. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorName">authorName</a></code> | <code>java.lang.String</code> | Author's name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorOrganization">authorOrganization</a></code> | <code>java.lang.Boolean</code> | Is the author an organization. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorUrl">authorUrl</a></code> | <code>java.lang.String</code> | Author's URL / Website. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoDetectBin">autoDetectBin</a></code> | <code>java.lang.Boolean</code> | Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bin">bin</a></code> | <code>java.util.Map<java.lang.String, java.lang.String></code> | Binary programs vended with your module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bugsEmail">bugsEmail</a></code> | <code>java.lang.String</code> | The email address to which issues should be reported. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bugsUrl">bugsUrl</a></code> | <code>java.lang.String</code> | The url to your project's issue tracker. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bundledDeps">bundledDeps</a></code> | <code>java.util.List<java.lang.String></code> | List of dependencies to bundle into this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeArtifactOptions">codeArtifactOptions</a></code> | <code>io.github.cdklabs.projen.javascript.CodeArtifactOptions</code> | Options for npm packages using AWS CodeArtifact. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.deps">deps</a></code> | <code>java.util.List<java.lang.String></code> | Runtime dependencies of this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.description">description</a></code> | <code>java.lang.String</code> | The description is just a string that helps people understand the purpose of the package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.devDeps">devDeps</a></code> | <code>java.util.List<java.lang.String></code> | Build dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.entrypoint">entrypoint</a></code> | <code>java.lang.String</code> | Module entrypoint (`main` in `package.json`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.homepage">homepage</a></code> | <code>java.lang.String</code> | Package's Homepage / Website. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.keywords">keywords</a></code> | <code>java.util.List<java.lang.String></code> | Keywords to include in `package.json`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.license">license</a></code> | <code>java.lang.String</code> | License's SPDX identifier. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.licensed">licensed</a></code> | <code>java.lang.Boolean</code> | Indicates if a license should be added. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.maxNodeVersion">maxNodeVersion</a></code> | <code>java.lang.String</code> | Minimum node.js version to require via `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.minNodeVersion">minNodeVersion</a></code> | <code>java.lang.String</code> | Minimum Node.js version to require via package.json `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmAccess">npmAccess</a></code> | <code>io.github.cdklabs.projen.javascript.NpmAccess</code> | Access level of the npm package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmRegistry">npmRegistry</a></code> | <code>java.lang.String</code> | The host name of the npm registry to publish to. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmRegistryUrl">npmRegistryUrl</a></code> | <code>java.lang.String</code> | The base URL of the npm package registry. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmTokenSecret">npmTokenSecret</a></code> | <code>java.lang.String</code> | GitHub secret which contains the NPM token to use when publishing packages. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.packageManager">packageManager</a></code> | <code>io.github.cdklabs.projen.javascript.NodePackageManager</code> | The Node Package Manager used to execute scripts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.packageName">packageName</a></code> | <code>java.lang.String</code> | The "name" in package.json. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.peerDependencyOptions">peerDependencyOptions</a></code> | <code>io.github.cdklabs.projen.javascript.PeerDependencyOptions</code> | Options for `peerDeps`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.peerDeps">peerDeps</a></code> | <code>java.util.List<java.lang.String></code> | Peer dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pnpmVersion">pnpmVersion</a></code> | <code>java.lang.String</code> | The version of PNPM to use if using PNPM as a package manager. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.repository">repository</a></code> | <code>java.lang.String</code> | The repository is the location where the actual code for your package lives. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.repositoryDirectory">repositoryDirectory</a></code> | <code>java.lang.String</code> | If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.scopedPackagesOptions">scopedPackagesOptions</a></code> | <code>java.util.List<io.github.cdklabs.projen.javascript.ScopedPackagesOptions></code> | Options for privately hosted scoped packages. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.scripts">scripts</a></code> | <code>java.util.Map<java.lang.String, java.lang.String></code> | npm scripts to include. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.stability">stability</a></code> | <code>java.lang.String</code> | Package's Stability. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jsiiReleaseVersion">jsiiReleaseVersion</a></code> | <code>java.lang.String</code> | Version requirement of `publib` which is used to publish modules to npm. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.majorVersion">majorVersion</a></code> | <code>java.lang.Number</code> | Major version to release from the default branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.minMajorVersion">minMajorVersion</a></code> | <code>java.lang.Number</code> | Minimal Major version to release. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmDistTag">npmDistTag</a></code> | <code>java.lang.String</code> | The npmDistTag to use when publishing from the default branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.postBuildSteps">postBuildSteps</a></code> | <code>java.util.List<io.github.cdklabs.projen.github.workflows.JobStep></code> | Steps to execute after build as part of the release workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prerelease">prerelease</a></code> | <code>java.lang.String</code> | Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre"). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publishDryRun">publishDryRun</a></code> | <code>java.lang.Boolean</code> | Instead of actually publishing to package managers, just print the publishing command. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publishTasks">publishTasks</a></code> | <code>java.lang.Boolean</code> | Define publishing tasks that can be executed manually as well as workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseBranches">releaseBranches</a></code> | <code>java.util.Map<java.lang.String, io.github.cdklabs.projen.release.BranchOptions></code> | Defines additional release branches. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseEveryCommit">releaseEveryCommit</a></code> | <code>java.lang.Boolean</code> | Automatically release new versions every commit to one of branches in `releaseBranches`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseFailureIssue">releaseFailureIssue</a></code> | <code>java.lang.Boolean</code> | Create a github issue on every failed publishing task. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseFailureIssueLabel">releaseFailureIssueLabel</a></code> | <code>java.lang.String</code> | The label to apply to issues indicating publish failures. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseSchedule">releaseSchedule</a></code> | <code>java.lang.String</code> | CRON schedule to trigger new releases. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseTagPrefix">releaseTagPrefix</a></code> | <code>java.lang.String</code> | Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseTrigger">releaseTrigger</a></code> | <code>io.github.cdklabs.projen.release.ReleaseTrigger</code> | The release trigger to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflowName">releaseWorkflowName</a></code> | <code>java.lang.String</code> | The name of the default release workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflowSetupSteps">releaseWorkflowSetupSteps</a></code> | <code>java.util.List<io.github.cdklabs.projen.github.workflows.JobStep></code> | A set of workflow steps to execute in order to setup the workflow container. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.versionrcOptions">versionrcOptions</a></code> | <code>java.util.Map<java.lang.String, java.lang.Object></code> | Custom configuration used when creating changelog with standard-version package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowContainerImage">workflowContainerImage</a></code> | <code>java.lang.String</code> | Container image to use for GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowRunsOn">workflowRunsOn</a></code> | <code>java.util.List<java.lang.String></code> | Github Runner selection labels. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.defaultReleaseBranch">defaultReleaseBranch</a></code> | <code>java.lang.String</code> | The name of the main release branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.artifactsDirectory">artifactsDirectory</a></code> | <code>java.lang.String</code> | A directory which will contain build artifacts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoApproveUpgrades">autoApproveUpgrades</a></code> | <code>java.lang.Boolean</code> | Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.buildWorkflow">buildWorkflow</a></code> | <code>java.lang.Boolean</code> | Define a GitHub workflow for building PRs. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.buildWorkflowTriggers">buildWorkflowTriggers</a></code> | <code>io.github.cdklabs.projen.github.workflows.Triggers</code> | Build workflow triggers. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bundlerOptions">bundlerOptions</a></code> | <code>io.github.cdklabs.projen.javascript.BundlerOptions</code> | Options for `Bundler`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeCov">codeCov</a></code> | <code>java.lang.Boolean</code> | Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with @codeCovTokenSecret. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeCovTokenSecret">codeCovTokenSecret</a></code> | <code>java.lang.String</code> | Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.copyrightOwner">copyrightOwner</a></code> | <code>java.lang.String</code> | License copyright owner. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.copyrightPeriod">copyrightPeriod</a></code> | <code>java.lang.String</code> | The copyright years to put in the LICENSE file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.dependabot">dependabot</a></code> | <code>java.lang.Boolean</code> | Use dependabot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.dependabotOptions">dependabotOptions</a></code> | <code>io.github.cdklabs.projen.github.DependabotOptions</code> | Options for dependabot. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.depsUpgrade">depsUpgrade</a></code> | <code>java.lang.Boolean</code> | Use github workflows to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.depsUpgradeOptions">depsUpgradeOptions</a></code> | <code>io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions</code> | Options for `UpgradeDependencies`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitignore">gitignore</a></code> | <code>java.util.List<java.lang.String></code> | Additional entries to .gitignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jest">jest</a></code> | <code>java.lang.Boolean</code> | Setup jest unit tests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jestOptions">jestOptions</a></code> | <code>io.github.cdklabs.projen.javascript.JestOptions</code> | Jest options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mutableBuild">mutableBuild</a></code> | <code>java.lang.Boolean</code> | Automatically update files modified during builds to pull-request branches. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmignore">npmignore</a></code> | <code>java.util.List<java.lang.String></code> | Additional entries to .npmignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmignoreEnabled">npmignoreEnabled</a></code> | <code>java.lang.Boolean</code> | Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmIgnoreOptions">npmIgnoreOptions</a></code> | <code>io.github.cdklabs.projen.IgnoreFileOptions</code> | Configuration options for .npmignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.package">package</a></code> | <code>java.lang.Boolean</code> | Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prettier">prettier</a></code> | <code>java.lang.Boolean</code> | Setup prettier. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prettierOptions">prettierOptions</a></code> | <code>io.github.cdklabs.projen.javascript.PrettierOptions</code> | Prettier options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenDevDependency">projenDevDependency</a></code> | <code>java.lang.Boolean</code> | Indicates of "projen" should be installed as a devDependency. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJs">projenrcJs</a></code> | <code>java.lang.Boolean</code> | Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJsOptions">projenrcJsOptions</a></code> | <code>io.github.cdklabs.projen.javascript.ProjenrcOptions</code> | Options for .projenrc.js. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenVersion">projenVersion</a></code> | <code>java.lang.String</code> | Version of projen to install. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pullRequestTemplate">pullRequestTemplate</a></code> | <code>java.lang.Boolean</code> | Include a GitHub pull request template. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pullRequestTemplateContents">pullRequestTemplateContents</a></code> | <code>java.util.List<java.lang.String></code> | The contents of the pull request template. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.release">release</a></code> | <code>java.lang.Boolean</code> | Add release management to this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseToNpm">releaseToNpm</a></code> | <code>java.lang.Boolean</code> | Automatically release to npm when new versions are introduced. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflow">releaseWorkflow</a></code> | <code>java.lang.Boolean</code> | DEPRECATED: renamed to `release`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowBootstrapSteps">workflowBootstrapSteps</a></code> | <code>java.util.List<io.github.cdklabs.projen.github.workflows.JobStep></code> | Workflow steps to use in order to bootstrap this repo. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowGitIdentity">workflowGitIdentity</a></code> | <code>io.github.cdklabs.projen.github.GitIdentity</code> | The git identity to use in workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowNodeVersion">workflowNodeVersion</a></code> | <code>java.lang.String</code> | The node version to use in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.disableTsconfig">disableTsconfig</a></code> | <code>java.lang.Boolean</code> | Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.disableTsconfigDev">disableTsconfigDev</a></code> | <code>java.lang.Boolean</code> | Do not generate a `tsconfig.dev.json` file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.docgen">docgen</a></code> | <code>java.lang.Boolean</code> | Docgen by Typedoc. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.docsDirectory">docsDirectory</a></code> | <code>java.lang.String</code> | Docs directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.entrypointTypes">entrypointTypes</a></code> | <code>java.lang.String</code> | The .d.ts file that includes the type declarations for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.eslint">eslint</a></code> | <code>java.lang.Boolean</code> | Setup eslint. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.eslintOptions">eslintOptions</a></code> | <code>io.github.cdklabs.projen.javascript.EslintOptions</code> | Eslint options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.libdir">libdir</a></code> | <code>java.lang.String</code> | Typescript  artifacts output directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcTs">projenrcTs</a></code> | <code>java.lang.Boolean</code> | Use TypeScript for your projenrc file (`.projenrc.ts`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcTsOptions">projenrcTsOptions</a></code> | <code>io.github.cdklabs.projen.typescript.ProjenrcOptions</code> | Options for .projenrc.ts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.sampleCode">sampleCode</a></code> | <code>java.lang.Boolean</code> | Generate one-time sample in `src/` and `test/` if there are no files there. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.srcdir">srcdir</a></code> | <code>java.lang.String</code> | Typescript sources directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.testdir">testdir</a></code> | <code>java.lang.String</code> | Jest tests directory. Tests files should be named `xxx.test.ts`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfig">tsconfig</a></code> | <code>io.github.cdklabs.projen.javascript.TypescriptConfigOptions</code> | Custom TSConfig. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfigDev">tsconfigDev</a></code> | <code>io.github.cdklabs.projen.javascript.TypescriptConfigOptions</code> | Custom tsconfig options for the development tsconfig.json file (used for testing). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfigDevFile">tsconfigDevFile</a></code> | <code>java.lang.String</code> | The name of the development tsconfig.json file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.typescriptVersion">typescriptVersion</a></code> | <code>java.lang.String</code> | TypeScript version to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.rewire">rewire</a></code> | <code>java.util.Map<java.lang.String, java.lang.Object></code> | Rewire webpack configuration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.applicationName">applicationName</a></code> | <code>java.lang.String</code> | Name of the application name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publicDir">publicDir</a></code> | <code>java.lang.String</code> | Public directory. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.name"></a>

```java
public java.lang.String getName();
```

- *Type:* java.lang.String
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commitGenerated`<sup>Optional</sup> <a name="commitGenerated" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.commitGenerated"></a>

```java
public java.lang.Boolean getCommitGenerated();
```

- *Type:* java.lang.Boolean
- *Default:* true

Whether to commit the managed files by default.

---

##### `gitIgnoreOptions`<sup>Optional</sup> <a name="gitIgnoreOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitIgnoreOptions"></a>

```java
public IgnoreFileOptions getGitIgnoreOptions();
```

- *Type:* io.github.cdklabs.projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `gitOptions`<sup>Optional</sup> <a name="gitOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitOptions"></a>

```java
public GitOptions getGitOptions();
```

- *Type:* io.github.cdklabs.projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.logging"></a>

```java
public LoggerOptions getLogging();
```

- *Type:* io.github.cdklabs.projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.outdir"></a>

```java
public java.lang.String getOutdir();
```

- *Type:* java.lang.String
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.parent"></a>

```java
public Project getParent();
```

- *Type:* io.github.cdklabs.projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projenCommand`<sup>Optional</sup> <a name="projenCommand" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenCommand"></a>

```java
public java.lang.String getProjenCommand();
```

- *Type:* java.lang.String
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrcJson`<sup>Optional</sup> <a name="projenrcJson" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJson"></a>

```java
public java.lang.Boolean getProjenrcJson();
```

- *Type:* java.lang.Boolean
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrcJsonOptions`<sup>Optional</sup> <a name="projenrcJsonOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJsonOptions"></a>

```java
public ProjenrcJsonOptions getProjenrcJsonOptions();
```

- *Type:* io.github.cdklabs.projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.renovatebot"></a>

```java
public java.lang.Boolean getRenovatebot();
```

- *Type:* java.lang.Boolean
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebotOptions`<sup>Optional</sup> <a name="renovatebotOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.renovatebotOptions"></a>

```java
public RenovatebotOptions getRenovatebotOptions();
```

- *Type:* io.github.cdklabs.projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `autoApproveOptions`<sup>Optional</sup> <a name="autoApproveOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoApproveOptions"></a>

```java
public AutoApproveOptions getAutoApproveOptions();
```

- *Type:* io.github.cdklabs.projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `autoMerge`<sup>Optional</sup> <a name="autoMerge" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoMerge"></a>

```java
public java.lang.Boolean getAutoMerge();
```

- *Type:* java.lang.Boolean
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `autoMergeOptions`<sup>Optional</sup> <a name="autoMergeOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoMergeOptions"></a>

```java
public AutoMergeOptions getAutoMergeOptions();
```

- *Type:* io.github.cdklabs.projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.clobber"></a>

```java
public java.lang.Boolean getClobber();
```

- *Type:* java.lang.Boolean
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `devContainer`<sup>Optional</sup> <a name="devContainer" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.devContainer"></a>

```java
public java.lang.Boolean getDevContainer();
```

- *Type:* java.lang.Boolean
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.github"></a>

```java
public java.lang.Boolean getGithub();
```

- *Type:* java.lang.Boolean
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `githubOptions`<sup>Optional</sup> <a name="githubOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.githubOptions"></a>

```java
public GitHubOptions getGithubOptions();
```

- *Type:* io.github.cdklabs.projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitpod"></a>

```java
public java.lang.Boolean getGitpod();
```

- *Type:* java.lang.Boolean
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

```java
public java.lang.Boolean getMergify();
```

- *Type:* java.lang.Boolean
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergifyOptions`~~<sup>Optional</sup> <a name="mergifyOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

```java
public MergifyOptions getMergifyOptions();
```

- *Type:* io.github.cdklabs.projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`projectType`~~<sup>Optional</sup> <a name="projectType" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projectType"></a>

- *Deprecated:* no longer supported at the base project level

```java
public ProjectType getProjectType();
```

- *Type:* io.github.cdklabs.projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projenCredentials`<sup>Optional</sup> <a name="projenCredentials" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenCredentials"></a>

```java
public GithubCredentials getProjenCredentials();
```

- *Type:* io.github.cdklabs.projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projenTokenSecret`~~<sup>Optional</sup> <a name="projenTokenSecret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

```java
public java.lang.String getProjenTokenSecret();
```

- *Type:* java.lang.String
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.readme"></a>

```java
public SampleReadmeProps getReadme();
```

- *Type:* io.github.cdklabs.projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```java
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.stale"></a>

```java
public java.lang.Boolean getStale();
```

- *Type:* java.lang.Boolean
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `staleOptions`<sup>Optional</sup> <a name="staleOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.staleOptions"></a>

```java
public StaleOptions getStaleOptions();
```

- *Type:* io.github.cdklabs.projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.vscode"></a>

```java
public java.lang.Boolean getVscode();
```

- *Type:* java.lang.Boolean
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `allowLibraryDependencies`<sup>Optional</sup> <a name="allowLibraryDependencies" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.allowLibraryDependencies"></a>

```java
public java.lang.Boolean getAllowLibraryDependencies();
```

- *Type:* java.lang.Boolean
- *Default:* true

Allow the project to include `peerDependencies` and `bundledDependencies`.

This is normally only allowed for libraries. For apps, there's no meaning
for specifying these.

---

##### `authorEmail`<sup>Optional</sup> <a name="authorEmail" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorEmail"></a>

```java
public java.lang.String getAuthorEmail();
```

- *Type:* java.lang.String

Author's e-mail.

---

##### `authorName`<sup>Optional</sup> <a name="authorName" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorName"></a>

```java
public java.lang.String getAuthorName();
```

- *Type:* java.lang.String

Author's name.

---

##### `authorOrganization`<sup>Optional</sup> <a name="authorOrganization" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorOrganization"></a>

```java
public java.lang.Boolean getAuthorOrganization();
```

- *Type:* java.lang.Boolean

Is the author an organization.

---

##### `authorUrl`<sup>Optional</sup> <a name="authorUrl" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorUrl"></a>

```java
public java.lang.String getAuthorUrl();
```

- *Type:* java.lang.String

Author's URL / Website.

---

##### `autoDetectBin`<sup>Optional</sup> <a name="autoDetectBin" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoDetectBin"></a>

```java
public java.lang.Boolean getAutoDetectBin();
```

- *Type:* java.lang.Boolean
- *Default:* true

Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section.

---

##### `bin`<sup>Optional</sup> <a name="bin" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bin"></a>

```java
public java.util.Map<java.lang.String, java.lang.String> getBin();
```

- *Type:* java.util.Map<java.lang.String, java.lang.String>

Binary programs vended with your module.

You can use this option to add/customize how binaries are represented in
your `package.json`, but unless `autoDetectBin` is `false`, every
executable file under `bin` will automatically be added to this section.

---

##### `bugsEmail`<sup>Optional</sup> <a name="bugsEmail" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bugsEmail"></a>

```java
public java.lang.String getBugsEmail();
```

- *Type:* java.lang.String

The email address to which issues should be reported.

---

##### `bugsUrl`<sup>Optional</sup> <a name="bugsUrl" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bugsUrl"></a>

```java
public java.lang.String getBugsUrl();
```

- *Type:* java.lang.String

The url to your project's issue tracker.

---

##### `bundledDeps`<sup>Optional</sup> <a name="bundledDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bundledDeps"></a>

```java
public java.util.List<java.lang.String> getBundledDeps();
```

- *Type:* java.util.List<java.lang.String>

List of dependencies to bundle into this module.

These modules will be
added both to the `dependencies` section and `bundledDependencies` section of
your `package.json`.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

##### `codeArtifactOptions`<sup>Optional</sup> <a name="codeArtifactOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeArtifactOptions"></a>

```java
public CodeArtifactOptions getCodeArtifactOptions();
```

- *Type:* io.github.cdklabs.projen.javascript.CodeArtifactOptions
- *Default:* undefined

Options for npm packages using AWS CodeArtifact.

This is required if publishing packages to, or installing scoped packages from AWS CodeArtifact

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.deps"></a>

```java
public java.util.List<java.lang.String> getDeps();
```

- *Type:* java.util.List<java.lang.String>
- *Default:* []

Runtime dependencies of this module.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```java
[ 'express', 'lodash', 'foo@^2' ]
```


##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.description"></a>

```java
public java.lang.String getDescription();
```

- *Type:* java.lang.String

The description is just a string that helps people understand the purpose of the package.

It can be used when searching for packages in a package manager as well.
See https://classic.yarnpkg.com/en/docs/package-json/#toc-description

---

##### `devDeps`<sup>Optional</sup> <a name="devDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.devDeps"></a>

```java
public java.util.List<java.lang.String> getDevDeps();
```

- *Type:* java.util.List<java.lang.String>
- *Default:* []

Build dependencies for this module.

These dependencies will only be
available in your build environment but will not be fetched when this
module is consumed.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```java
[ 'typescript', '@types/express' ]
```


##### `entrypoint`<sup>Optional</sup> <a name="entrypoint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.entrypoint"></a>

```java
public java.lang.String getEntrypoint();
```

- *Type:* java.lang.String
- *Default:* "lib/index.js"

Module entrypoint (`main` in `package.json`).

Set to an empty string to not include `main` in your package.json

---

##### `homepage`<sup>Optional</sup> <a name="homepage" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.homepage"></a>

```java
public java.lang.String getHomepage();
```

- *Type:* java.lang.String

Package's Homepage / Website.

---

##### `keywords`<sup>Optional</sup> <a name="keywords" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.keywords"></a>

```java
public java.util.List<java.lang.String> getKeywords();
```

- *Type:* java.util.List<java.lang.String>

Keywords to include in `package.json`.

---

##### `license`<sup>Optional</sup> <a name="license" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.license"></a>

```java
public java.lang.String getLicense();
```

- *Type:* java.lang.String
- *Default:* "Apache-2.0"

License's SPDX identifier.

See https://github.com/projen/projen/tree/main/license-text for a list of supported licenses.
Use the `licensed` option if you want to no license to be specified.

---

##### `licensed`<sup>Optional</sup> <a name="licensed" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.licensed"></a>

```java
public java.lang.Boolean getLicensed();
```

- *Type:* java.lang.Boolean
- *Default:* true

Indicates if a license should be added.

---

##### `maxNodeVersion`<sup>Optional</sup> <a name="maxNodeVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.maxNodeVersion"></a>

```java
public java.lang.String getMaxNodeVersion();
```

- *Type:* java.lang.String
- *Default:* no max

Minimum node.js version to require via `engines` (inclusive).

---

##### `minNodeVersion`<sup>Optional</sup> <a name="minNodeVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.minNodeVersion"></a>

```java
public java.lang.String getMinNodeVersion();
```

- *Type:* java.lang.String
- *Default:* no "engines" specified

Minimum Node.js version to require via package.json `engines` (inclusive).

---

##### `npmAccess`<sup>Optional</sup> <a name="npmAccess" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmAccess"></a>

```java
public NpmAccess getNpmAccess();
```

- *Type:* io.github.cdklabs.projen.javascript.NpmAccess
- *Default:* for scoped packages (e.g. `foo@bar`), the default is `NpmAccess.RESTRICTED`, for non-scoped packages, the default is `NpmAccess.PUBLIC`.

Access level of the npm package.

---

##### ~~`npmRegistry`~~<sup>Optional</sup> <a name="npmRegistry" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmRegistry"></a>

- *Deprecated:* use `npmRegistryUrl` instead

```java
public java.lang.String getNpmRegistry();
```

- *Type:* java.lang.String

The host name of the npm registry to publish to.

Cannot be set together with `npmRegistryUrl`.

---

##### `npmRegistryUrl`<sup>Optional</sup> <a name="npmRegistryUrl" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmRegistryUrl"></a>

```java
public java.lang.String getNpmRegistryUrl();
```

- *Type:* java.lang.String
- *Default:* "https://registry.npmjs.org"

The base URL of the npm package registry.

Must be a URL (e.g. start with "https://" or "http://")

---

##### `npmTokenSecret`<sup>Optional</sup> <a name="npmTokenSecret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmTokenSecret"></a>

```java
public java.lang.String getNpmTokenSecret();
```

- *Type:* java.lang.String
- *Default:* "NPM_TOKEN"

GitHub secret which contains the NPM token to use when publishing packages.

---

##### `packageManager`<sup>Optional</sup> <a name="packageManager" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.packageManager"></a>

```java
public NodePackageManager getPackageManager();
```

- *Type:* io.github.cdklabs.projen.javascript.NodePackageManager
- *Default:* NodePackageManager.YARN

The Node Package Manager used to execute scripts.

---

##### `packageName`<sup>Optional</sup> <a name="packageName" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.packageName"></a>

```java
public java.lang.String getPackageName();
```

- *Type:* java.lang.String
- *Default:* defaults to project name

The "name" in package.json.

---

##### `peerDependencyOptions`<sup>Optional</sup> <a name="peerDependencyOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.peerDependencyOptions"></a>

```java
public PeerDependencyOptions getPeerDependencyOptions();
```

- *Type:* io.github.cdklabs.projen.javascript.PeerDependencyOptions

Options for `peerDeps`.

---

##### `peerDeps`<sup>Optional</sup> <a name="peerDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.peerDeps"></a>

```java
public java.util.List<java.lang.String> getPeerDeps();
```

- *Type:* java.util.List<java.lang.String>
- *Default:* []

Peer dependencies for this module.

Dependencies listed here are required to
be installed (and satisfied) by the _consumer_ of this library. Using peer
dependencies allows you to ensure that only a single module of a certain
library exists in the `node_modules` tree of your consumers.

Note that prior to npm@7, peer dependencies are _not_ automatically
installed, which means that adding peer dependencies to a library will be a
breaking change for your customers.

Unless `peerDependencyOptions.pinnedDevDependency` is disabled (it is
enabled by default), projen will automatically add a dev dependency with a
pinned version for each peer dependency. This will ensure that you build &
test your module against the lowest peer version required.

---

##### `pnpmVersion`<sup>Optional</sup> <a name="pnpmVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pnpmVersion"></a>

```java
public java.lang.String getPnpmVersion();
```

- *Type:* java.lang.String
- *Default:* "7"

The version of PNPM to use if using PNPM as a package manager.

---

##### `repository`<sup>Optional</sup> <a name="repository" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.repository"></a>

```java
public java.lang.String getRepository();
```

- *Type:* java.lang.String

The repository is the location where the actual code for your package lives.

See https://classic.yarnpkg.com/en/docs/package-json/#toc-repository

---

##### `repositoryDirectory`<sup>Optional</sup> <a name="repositoryDirectory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.repositoryDirectory"></a>

```java
public java.lang.String getRepositoryDirectory();
```

- *Type:* java.lang.String

If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives.

---

##### `scopedPackagesOptions`<sup>Optional</sup> <a name="scopedPackagesOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.scopedPackagesOptions"></a>

```java
public java.util.List<ScopedPackagesOptions> getScopedPackagesOptions();
```

- *Type:* java.util.List<io.github.cdklabs.projen.javascript.ScopedPackagesOptions>
- *Default:* fetch all scoped packages from the public npm registry

Options for privately hosted scoped packages.

---

##### `scripts`<sup>Optional</sup> <a name="scripts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.scripts"></a>

```java
public java.util.Map<java.lang.String, java.lang.String> getScripts();
```

- *Type:* java.util.Map<java.lang.String, java.lang.String>
- *Default:* {}

npm scripts to include.

If a script has the same name as a standard script,
the standard script will be overwritten.

---

##### `stability`<sup>Optional</sup> <a name="stability" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.stability"></a>

```java
public java.lang.String getStability();
```

- *Type:* java.lang.String

Package's Stability.

---

##### `jsiiReleaseVersion`<sup>Optional</sup> <a name="jsiiReleaseVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jsiiReleaseVersion"></a>

```java
public java.lang.String getJsiiReleaseVersion();
```

- *Type:* java.lang.String
- *Default:* "latest"

Version requirement of `publib` which is used to publish modules to npm.

---

##### `majorVersion`<sup>Optional</sup> <a name="majorVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.majorVersion"></a>

```java
public java.lang.Number getMajorVersion();
```

- *Type:* java.lang.Number
- *Default:* Major version is not enforced.

Major version to release from the default branch.

If this is specified, we bump the latest version of this major version line.
If not specified, we bump the global latest version.

---

##### `minMajorVersion`<sup>Optional</sup> <a name="minMajorVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.minMajorVersion"></a>

```java
public java.lang.Number getMinMajorVersion();
```

- *Type:* java.lang.Number
- *Default:* No minimum version is being enforced

Minimal Major version to release.

This can be useful to set to 1, as breaking changes before the 1.x major
release are not incrementing the major version number.

Can not be set together with `majorVersion`.

---

##### `npmDistTag`<sup>Optional</sup> <a name="npmDistTag" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmDistTag"></a>

```java
public java.lang.String getNpmDistTag();
```

- *Type:* java.lang.String
- *Default:* "latest"

The npmDistTag to use when publishing from the default branch.

To set the npm dist-tag for release branches, set the `npmDistTag` property
for each branch.

---

##### `postBuildSteps`<sup>Optional</sup> <a name="postBuildSteps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.postBuildSteps"></a>

```java
public java.util.List<JobStep> getPostBuildSteps();
```

- *Type:* java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>
- *Default:* []

Steps to execute after build as part of the release workflow.

---

##### `prerelease`<sup>Optional</sup> <a name="prerelease" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prerelease"></a>

```java
public java.lang.String getPrerelease();
```

- *Type:* java.lang.String
- *Default:* normal semantic versions

Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre").

---

##### `publishDryRun`<sup>Optional</sup> <a name="publishDryRun" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publishDryRun"></a>

```java
public java.lang.Boolean getPublishDryRun();
```

- *Type:* java.lang.Boolean
- *Default:* false

Instead of actually publishing to package managers, just print the publishing command.

---

##### `publishTasks`<sup>Optional</sup> <a name="publishTasks" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publishTasks"></a>

```java
public java.lang.Boolean getPublishTasks();
```

- *Type:* java.lang.Boolean
- *Default:* false

Define publishing tasks that can be executed manually as well as workflows.

Normally, publishing only happens within automated workflows. Enable this
in order to create a publishing task for each publishing activity.

---

##### `releaseBranches`<sup>Optional</sup> <a name="releaseBranches" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseBranches"></a>

```java
public java.util.Map<java.lang.String, BranchOptions> getReleaseBranches();
```

- *Type:* java.util.Map<java.lang.String, io.github.cdklabs.projen.release.BranchOptions>
- *Default:* no additional branches are used for release. you can use `addBranch()` to add additional branches.

Defines additional release branches.

A workflow will be created for each
release branch which will publish releases from commits in this branch.
Each release branch _must_ be assigned a major version number which is used
to enforce that versions published from that branch always use that major
version. If multiple branches are used, the `majorVersion` field must also
be provided for the default branch.

---

##### ~~`releaseEveryCommit`~~<sup>Optional</sup> <a name="releaseEveryCommit" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseEveryCommit"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.continuous()` instead

```java
public java.lang.Boolean getReleaseEveryCommit();
```

- *Type:* java.lang.Boolean
- *Default:* true

Automatically release new versions every commit to one of branches in `releaseBranches`.

---

##### `releaseFailureIssue`<sup>Optional</sup> <a name="releaseFailureIssue" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseFailureIssue"></a>

```java
public java.lang.Boolean getReleaseFailureIssue();
```

- *Type:* java.lang.Boolean
- *Default:* false

Create a github issue on every failed publishing task.

---

##### `releaseFailureIssueLabel`<sup>Optional</sup> <a name="releaseFailureIssueLabel" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseFailureIssueLabel"></a>

```java
public java.lang.String getReleaseFailureIssueLabel();
```

- *Type:* java.lang.String
- *Default:* "failed-release"

The label to apply to issues indicating publish failures.

Only applies if `releaseFailureIssue` is true.

---

##### ~~`releaseSchedule`~~<sup>Optional</sup> <a name="releaseSchedule" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseSchedule"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.scheduled()` instead

```java
public java.lang.String getReleaseSchedule();
```

- *Type:* java.lang.String
- *Default:* no scheduled releases

CRON schedule to trigger new releases.

---

##### `releaseTagPrefix`<sup>Optional</sup> <a name="releaseTagPrefix" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseTagPrefix"></a>

```java
public java.lang.String getReleaseTagPrefix();
```

- *Type:* java.lang.String
- *Default:* "v"

Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers.

Note: this prefix is used to detect the latest tagged version
when bumping, so if you change this on a project with an existing version
history, you may need to manually tag your latest release
with the new prefix.

---

##### `releaseTrigger`<sup>Optional</sup> <a name="releaseTrigger" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseTrigger"></a>

```java
public ReleaseTrigger getReleaseTrigger();
```

- *Type:* io.github.cdklabs.projen.release.ReleaseTrigger
- *Default:* Continuous releases (`ReleaseTrigger.continuous()`)

The release trigger to use.

---

##### `releaseWorkflowName`<sup>Optional</sup> <a name="releaseWorkflowName" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflowName"></a>

```java
public java.lang.String getReleaseWorkflowName();
```

- *Type:* java.lang.String
- *Default:* "Release"

The name of the default release workflow.

---

##### `releaseWorkflowSetupSteps`<sup>Optional</sup> <a name="releaseWorkflowSetupSteps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflowSetupSteps"></a>

```java
public java.util.List<JobStep> getReleaseWorkflowSetupSteps();
```

- *Type:* java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>

A set of workflow steps to execute in order to setup the workflow container.

---

##### `versionrcOptions`<sup>Optional</sup> <a name="versionrcOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.versionrcOptions"></a>

```java
public java.util.Map<java.lang.String, java.lang.Object> getVersionrcOptions();
```

- *Type:* java.util.Map<java.lang.String, java.lang.Object>
- *Default:* standard configuration applicable for GitHub repositories

Custom configuration used when creating changelog with standard-version package.

Given values either append to default configuration or overwrite values in it.

---

##### `workflowContainerImage`<sup>Optional</sup> <a name="workflowContainerImage" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowContainerImage"></a>

```java
public java.lang.String getWorkflowContainerImage();
```

- *Type:* java.lang.String
- *Default:* default image

Container image to use for GitHub workflows.

---

##### `workflowRunsOn`<sup>Optional</sup> <a name="workflowRunsOn" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowRunsOn"></a>

```java
public java.util.List<java.lang.String> getWorkflowRunsOn();
```

- *Type:* java.util.List<java.lang.String>
- *Default:* ["ubuntu-latest"]

Github Runner selection labels.

---

##### `defaultReleaseBranch`<sup>Required</sup> <a name="defaultReleaseBranch" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.defaultReleaseBranch"></a>

```java
public java.lang.String getDefaultReleaseBranch();
```

- *Type:* java.lang.String
- *Default:* "main"

The name of the main release branch.

---

##### `artifactsDirectory`<sup>Optional</sup> <a name="artifactsDirectory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.artifactsDirectory"></a>

```java
public java.lang.String getArtifactsDirectory();
```

- *Type:* java.lang.String
- *Default:* "dist"

A directory which will contain build artifacts.

---

##### `autoApproveUpgrades`<sup>Optional</sup> <a name="autoApproveUpgrades" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoApproveUpgrades"></a>

```java
public java.lang.Boolean getAutoApproveUpgrades();
```

- *Type:* java.lang.Boolean
- *Default:* true

Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued).

Throw if set to true but `autoApproveOptions` are not defined.

---

##### `buildWorkflow`<sup>Optional</sup> <a name="buildWorkflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.buildWorkflow"></a>

```java
public java.lang.Boolean getBuildWorkflow();
```

- *Type:* java.lang.Boolean
- *Default:* true if not a subproject

Define a GitHub workflow for building PRs.

---

##### `buildWorkflowTriggers`<sup>Optional</sup> <a name="buildWorkflowTriggers" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.buildWorkflowTriggers"></a>

```java
public Triggers getBuildWorkflowTriggers();
```

- *Type:* io.github.cdklabs.projen.github.workflows.Triggers
- *Default:* "{ pullRequest: {}, workflowDispatch: {} }"

Build workflow triggers.

---

##### `bundlerOptions`<sup>Optional</sup> <a name="bundlerOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bundlerOptions"></a>

```java
public BundlerOptions getBundlerOptions();
```

- *Type:* io.github.cdklabs.projen.javascript.BundlerOptions

Options for `Bundler`.

---

##### `codeCov`<sup>Optional</sup> <a name="codeCov" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeCov"></a>

```java
public java.lang.Boolean getCodeCov();
```

- *Type:* java.lang.Boolean
- *Default:* false

Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with @codeCovTokenSecret.

---

##### `codeCovTokenSecret`<sup>Optional</sup> <a name="codeCovTokenSecret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeCovTokenSecret"></a>

```java
public java.lang.String getCodeCovTokenSecret();
```

- *Type:* java.lang.String
- *Default:* if this option is not specified, only public repositories are supported

Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories.

---

##### `copyrightOwner`<sup>Optional</sup> <a name="copyrightOwner" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.copyrightOwner"></a>

```java
public java.lang.String getCopyrightOwner();
```

- *Type:* java.lang.String
- *Default:* defaults to the value of authorName or "" if `authorName` is undefined.

License copyright owner.

---

##### `copyrightPeriod`<sup>Optional</sup> <a name="copyrightPeriod" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.copyrightPeriod"></a>

```java
public java.lang.String getCopyrightPeriod();
```

- *Type:* java.lang.String
- *Default:* current year

The copyright years to put in the LICENSE file.

---

##### `dependabot`<sup>Optional</sup> <a name="dependabot" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.dependabot"></a>

```java
public java.lang.Boolean getDependabot();
```

- *Type:* java.lang.Boolean
- *Default:* false

Use dependabot to handle dependency upgrades.

Cannot be used in conjunction with `depsUpgrade`.

---

##### `dependabotOptions`<sup>Optional</sup> <a name="dependabotOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.dependabotOptions"></a>

```java
public DependabotOptions getDependabotOptions();
```

- *Type:* io.github.cdklabs.projen.github.DependabotOptions
- *Default:* default options

Options for dependabot.

---

##### `depsUpgrade`<sup>Optional</sup> <a name="depsUpgrade" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.depsUpgrade"></a>

```java
public java.lang.Boolean getDepsUpgrade();
```

- *Type:* java.lang.Boolean
- *Default:* true

Use github workflows to handle dependency upgrades.

Cannot be used in conjunction with `dependabot`.

---

##### `depsUpgradeOptions`<sup>Optional</sup> <a name="depsUpgradeOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.depsUpgradeOptions"></a>

```java
public UpgradeDependenciesOptions getDepsUpgradeOptions();
```

- *Type:* io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions
- *Default:* default options

Options for `UpgradeDependencies`.

---

##### `gitignore`<sup>Optional</sup> <a name="gitignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitignore"></a>

```java
public java.util.List<java.lang.String> getGitignore();
```

- *Type:* java.util.List<java.lang.String>

Additional entries to .gitignore.

---

##### `jest`<sup>Optional</sup> <a name="jest" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jest"></a>

```java
public java.lang.Boolean getJest();
```

- *Type:* java.lang.Boolean
- *Default:* true

Setup jest unit tests.

---

##### `jestOptions`<sup>Optional</sup> <a name="jestOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jestOptions"></a>

```java
public JestOptions getJestOptions();
```

- *Type:* io.github.cdklabs.projen.javascript.JestOptions
- *Default:* default options

Jest options.

---

##### `mutableBuild`<sup>Optional</sup> <a name="mutableBuild" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mutableBuild"></a>

```java
public java.lang.Boolean getMutableBuild();
```

- *Type:* java.lang.Boolean
- *Default:* true

Automatically update files modified during builds to pull-request branches.

This means
that any files synthesized by projen or e.g. test snapshots will always be up-to-date
before a PR is merged.

Implies that PR builds do not have anti-tamper checks.

---

##### ~~`npmignore`~~<sup>Optional</sup> <a name="npmignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmignore"></a>

- *Deprecated:* - use `project.addPackageIgnore`

```java
public java.util.List<java.lang.String> getNpmignore();
```

- *Type:* java.util.List<java.lang.String>

Additional entries to .npmignore.

---

##### `npmignoreEnabled`<sup>Optional</sup> <a name="npmignoreEnabled" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmignoreEnabled"></a>

```java
public java.lang.Boolean getNpmignoreEnabled();
```

- *Type:* java.lang.Boolean
- *Default:* true

Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs.

---

##### `npmIgnoreOptions`<sup>Optional</sup> <a name="npmIgnoreOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmIgnoreOptions"></a>

```java
public IgnoreFileOptions getNpmIgnoreOptions();
```

- *Type:* io.github.cdklabs.projen.IgnoreFileOptions

Configuration options for .npmignore file.

---

##### `package`<sup>Optional</sup> <a name="package" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.package"></a>

```java
public java.lang.Boolean getPackage();
```

- *Type:* java.lang.Boolean
- *Default:* true

Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`).

---

##### `prettier`<sup>Optional</sup> <a name="prettier" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prettier"></a>

```java
public java.lang.Boolean getPrettier();
```

- *Type:* java.lang.Boolean
- *Default:* false

Setup prettier.

---

##### `prettierOptions`<sup>Optional</sup> <a name="prettierOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prettierOptions"></a>

```java
public PrettierOptions getPrettierOptions();
```

- *Type:* io.github.cdklabs.projen.javascript.PrettierOptions
- *Default:* default options

Prettier options.

---

##### `projenDevDependency`<sup>Optional</sup> <a name="projenDevDependency" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenDevDependency"></a>

```java
public java.lang.Boolean getProjenDevDependency();
```

- *Type:* java.lang.Boolean
- *Default:* true

Indicates of "projen" should be installed as a devDependency.

---

##### `projenrcJs`<sup>Optional</sup> <a name="projenrcJs" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJs"></a>

```java
public java.lang.Boolean getProjenrcJs();
```

- *Type:* java.lang.Boolean
- *Default:* true if projenrcJson is false

Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation.

---

##### `projenrcJsOptions`<sup>Optional</sup> <a name="projenrcJsOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJsOptions"></a>

```java
public ProjenrcOptions getProjenrcJsOptions();
```

- *Type:* io.github.cdklabs.projen.javascript.ProjenrcOptions
- *Default:* default options

Options for .projenrc.js.

---

##### `projenVersion`<sup>Optional</sup> <a name="projenVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenVersion"></a>

```java
public java.lang.String getProjenVersion();
```

- *Type:* java.lang.String
- *Default:* Defaults to the latest version.

Version of projen to install.

---

##### `pullRequestTemplate`<sup>Optional</sup> <a name="pullRequestTemplate" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pullRequestTemplate"></a>

```java
public java.lang.Boolean getPullRequestTemplate();
```

- *Type:* java.lang.Boolean
- *Default:* true

Include a GitHub pull request template.

---

##### `pullRequestTemplateContents`<sup>Optional</sup> <a name="pullRequestTemplateContents" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pullRequestTemplateContents"></a>

```java
public java.util.List<java.lang.String> getPullRequestTemplateContents();
```

- *Type:* java.util.List<java.lang.String>
- *Default:* default content

The contents of the pull request template.

---

##### `release`<sup>Optional</sup> <a name="release" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.release"></a>

```java
public java.lang.Boolean getRelease();
```

- *Type:* java.lang.Boolean
- *Default:* true (false for subprojects)

Add release management to this project.

---

##### `releaseToNpm`<sup>Optional</sup> <a name="releaseToNpm" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseToNpm"></a>

```java
public java.lang.Boolean getReleaseToNpm();
```

- *Type:* java.lang.Boolean
- *Default:* false

Automatically release to npm when new versions are introduced.

---

##### ~~`releaseWorkflow`~~<sup>Optional</sup> <a name="releaseWorkflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflow"></a>

- *Deprecated:* see `release`.

```java
public java.lang.Boolean getReleaseWorkflow();
```

- *Type:* java.lang.Boolean
- *Default:* true if not a subproject

DEPRECATED: renamed to `release`.

---

##### `workflowBootstrapSteps`<sup>Optional</sup> <a name="workflowBootstrapSteps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowBootstrapSteps"></a>

```java
public java.util.List<JobStep> getWorkflowBootstrapSteps();
```

- *Type:* java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>
- *Default:* "yarn install --frozen-lockfile && yarn projen"

Workflow steps to use in order to bootstrap this repo.

---

##### `workflowGitIdentity`<sup>Optional</sup> <a name="workflowGitIdentity" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowGitIdentity"></a>

```java
public GitIdentity getWorkflowGitIdentity();
```

- *Type:* io.github.cdklabs.projen.github.GitIdentity
- *Default:* GitHub Actions

The git identity to use in workflows.

---

##### `workflowNodeVersion`<sup>Optional</sup> <a name="workflowNodeVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowNodeVersion"></a>

```java
public java.lang.String getWorkflowNodeVersion();
```

- *Type:* java.lang.String
- *Default:* same as `minNodeVersion`

The node version to use in GitHub workflows.

---

##### `disableTsconfig`<sup>Optional</sup> <a name="disableTsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.disableTsconfig"></a>

```java
public java.lang.Boolean getDisableTsconfig();
```

- *Type:* java.lang.Boolean
- *Default:* false

Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler).

---

##### `disableTsconfigDev`<sup>Optional</sup> <a name="disableTsconfigDev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.disableTsconfigDev"></a>

```java
public java.lang.Boolean getDisableTsconfigDev();
```

- *Type:* java.lang.Boolean
- *Default:* false

Do not generate a `tsconfig.dev.json` file.

---

##### `docgen`<sup>Optional</sup> <a name="docgen" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.docgen"></a>

```java
public java.lang.Boolean getDocgen();
```

- *Type:* java.lang.Boolean
- *Default:* false

Docgen by Typedoc.

---

##### `docsDirectory`<sup>Optional</sup> <a name="docsDirectory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.docsDirectory"></a>

```java
public java.lang.String getDocsDirectory();
```

- *Type:* java.lang.String
- *Default:* "docs"

Docs directory.

---

##### `entrypointTypes`<sup>Optional</sup> <a name="entrypointTypes" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.entrypointTypes"></a>

```java
public java.lang.String getEntrypointTypes();
```

- *Type:* java.lang.String
- *Default:* .d.ts file derived from the project's entrypoint (usually lib/index.d.ts)

The .d.ts file that includes the type declarations for this module.

---

##### `eslint`<sup>Optional</sup> <a name="eslint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.eslint"></a>

```java
public java.lang.Boolean getEslint();
```

- *Type:* java.lang.Boolean
- *Default:* true

Setup eslint.

---

##### `eslintOptions`<sup>Optional</sup> <a name="eslintOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.eslintOptions"></a>

```java
public EslintOptions getEslintOptions();
```

- *Type:* io.github.cdklabs.projen.javascript.EslintOptions
- *Default:* opinionated default options

Eslint options.

---

##### `libdir`<sup>Optional</sup> <a name="libdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.libdir"></a>

```java
public java.lang.String getLibdir();
```

- *Type:* java.lang.String
- *Default:* "lib"

Typescript  artifacts output directory.

---

##### `projenrcTs`<sup>Optional</sup> <a name="projenrcTs" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcTs"></a>

```java
public java.lang.Boolean getProjenrcTs();
```

- *Type:* java.lang.Boolean
- *Default:* false

Use TypeScript for your projenrc file (`.projenrc.ts`).

---

##### `projenrcTsOptions`<sup>Optional</sup> <a name="projenrcTsOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcTsOptions"></a>

```java
public ProjenrcOptions getProjenrcTsOptions();
```

- *Type:* io.github.cdklabs.projen.typescript.ProjenrcOptions

Options for .projenrc.ts.

---

##### `sampleCode`<sup>Optional</sup> <a name="sampleCode" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.sampleCode"></a>

```java
public java.lang.Boolean getSampleCode();
```

- *Type:* java.lang.Boolean
- *Default:* true

Generate one-time sample in `src/` and `test/` if there are no files there.

---

##### `srcdir`<sup>Optional</sup> <a name="srcdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.srcdir"></a>

```java
public java.lang.String getSrcdir();
```

- *Type:* java.lang.String
- *Default:* "src"

Typescript sources directory.

---

##### `testdir`<sup>Optional</sup> <a name="testdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.testdir"></a>

```java
public java.lang.String getTestdir();
```

- *Type:* java.lang.String
- *Default:* "test"

Jest tests directory. Tests files should be named `xxx.test.ts`.

If this directory is under `srcdir` (e.g. `src/test`, `src/__tests__`),
then tests are going to be compiled into `lib/` and executed as javascript.
If the test directory is outside of `src`, then we configure jest to
compile the code in-memory.

---

##### `tsconfig`<sup>Optional</sup> <a name="tsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfig"></a>

```java
public TypescriptConfigOptions getTsconfig();
```

- *Type:* io.github.cdklabs.projen.javascript.TypescriptConfigOptions
- *Default:* default options

Custom TSConfig.

---

##### `tsconfigDev`<sup>Optional</sup> <a name="tsconfigDev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfigDev"></a>

```java
public TypescriptConfigOptions getTsconfigDev();
```

- *Type:* io.github.cdklabs.projen.javascript.TypescriptConfigOptions
- *Default:* use the production tsconfig options

Custom tsconfig options for the development tsconfig.json file (used for testing).

---

##### `tsconfigDevFile`<sup>Optional</sup> <a name="tsconfigDevFile" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfigDevFile"></a>

```java
public java.lang.String getTsconfigDevFile();
```

- *Type:* java.lang.String
- *Default:* "tsconfig.dev.json"

The name of the development tsconfig.json file.

---

##### `typescriptVersion`<sup>Optional</sup> <a name="typescriptVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.typescriptVersion"></a>

```java
public java.lang.String getTypescriptVersion();
```

- *Type:* java.lang.String
- *Default:* "latest"

TypeScript version to use.

NOTE: Typescript is not semantically versioned and should remain on the
same minor, so we recommend using a `~` dependency (e.g. `~1.2.3`).

---

##### `rewire`<sup>Optional</sup> <a name="rewire" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.rewire"></a>

```java
public java.util.Map<java.lang.String, java.lang.Object> getRewire();
```

- *Type:* java.util.Map<java.lang.String, java.lang.Object>
- *Default:* No rewired config.

Rewire webpack configuration.

Use this property to override webpack configuration properties provided
by create-react-app, without needing to eject.

This property will create a `config-overrides.js` file in your root directory,
which will contain the desired rewiring code.

To **override** the configuration, you can provide simple key value pairs.
Keys take the form of js code directives that traverse to the desired property.
Values should be JSON serializable objects.

For example, the following config:

```json
rewire: { "module.unknownContextCritical": false }
```

Will translate to the following `config-overrides.js` file:

```js
module.exports = function override(config, env) {
  config.module.unknownContextCritical = false;
}
```

> [https://github.com/timarney/react-app-rewired](https://github.com/timarney/react-app-rewired)

---

##### `applicationName`<sup>Optional</sup> <a name="applicationName" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.applicationName"></a>

```java
public java.lang.String getApplicationName();
```

- *Type:* java.lang.String
- *Default:* "Sample App"

Name of the application name.

---

##### `publicDir`<sup>Optional</sup> <a name="publicDir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publicDir"></a>

```java
public java.lang.String getPublicDir();
```

- *Type:* java.lang.String
- *Default:* "public"

Public directory.

---

## Classes <a name="Classes" id="Classes"></a>

### CloudscapeReactTsWebsiteProject <a name="CloudscapeReactTsWebsiteProject" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject"></a>

Synthesizes a Cloudscape React Typescript Website Project.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer"></a>

```java
import software.aws.awsprototypingsdk.cloudscapereacttswebsite.CloudscapeReactTsWebsiteProject;

CloudscapeReactTsWebsiteProject.Builder.create()
    .name(java.lang.String)
//  .commitGenerated(java.lang.Boolean)
//  .gitIgnoreOptions(IgnoreFileOptions)
//  .gitOptions(GitOptions)
//  .logging(LoggerOptions)
//  .outdir(java.lang.String)
//  .parent(Project)
//  .projenCommand(java.lang.String)
//  .projenrcJson(java.lang.Boolean)
//  .projenrcJsonOptions(ProjenrcJsonOptions)
//  .renovatebot(java.lang.Boolean)
//  .renovatebotOptions(RenovatebotOptions)
//  .autoApproveOptions(AutoApproveOptions)
//  .autoMerge(java.lang.Boolean)
//  .autoMergeOptions(AutoMergeOptions)
//  .clobber(java.lang.Boolean)
//  .devContainer(java.lang.Boolean)
//  .github(java.lang.Boolean)
//  .githubOptions(GitHubOptions)
//  .gitpod(java.lang.Boolean)
//  .mergify(java.lang.Boolean)
//  .mergifyOptions(MergifyOptions)
//  .projectType(ProjectType)
//  .projenCredentials(GithubCredentials)
//  .projenTokenSecret(java.lang.String)
//  .readme(SampleReadmeProps)
//  .stale(java.lang.Boolean)
//  .staleOptions(StaleOptions)
//  .vscode(java.lang.Boolean)
//  .allowLibraryDependencies(java.lang.Boolean)
//  .authorEmail(java.lang.String)
//  .authorName(java.lang.String)
//  .authorOrganization(java.lang.Boolean)
//  .authorUrl(java.lang.String)
//  .autoDetectBin(java.lang.Boolean)
//  .bin(java.util.Map<java.lang.String, java.lang.String>)
//  .bugsEmail(java.lang.String)
//  .bugsUrl(java.lang.String)
//  .bundledDeps(java.util.List<java.lang.String>)
//  .codeArtifactOptions(CodeArtifactOptions)
//  .deps(java.util.List<java.lang.String>)
//  .description(java.lang.String)
//  .devDeps(java.util.List<java.lang.String>)
//  .entrypoint(java.lang.String)
//  .homepage(java.lang.String)
//  .keywords(java.util.List<java.lang.String>)
//  .license(java.lang.String)
//  .licensed(java.lang.Boolean)
//  .maxNodeVersion(java.lang.String)
//  .minNodeVersion(java.lang.String)
//  .npmAccess(NpmAccess)
//  .npmRegistry(java.lang.String)
//  .npmRegistryUrl(java.lang.String)
//  .npmTokenSecret(java.lang.String)
//  .packageManager(NodePackageManager)
//  .packageName(java.lang.String)
//  .peerDependencyOptions(PeerDependencyOptions)
//  .peerDeps(java.util.List<java.lang.String>)
//  .pnpmVersion(java.lang.String)
//  .repository(java.lang.String)
//  .repositoryDirectory(java.lang.String)
//  .scopedPackagesOptions(java.util.List<ScopedPackagesOptions>)
//  .scripts(java.util.Map<java.lang.String, java.lang.String>)
//  .stability(java.lang.String)
//  .jsiiReleaseVersion(java.lang.String)
//  .majorVersion(java.lang.Number)
//  .minMajorVersion(java.lang.Number)
//  .npmDistTag(java.lang.String)
//  .postBuildSteps(java.util.List<JobStep>)
//  .prerelease(java.lang.String)
//  .publishDryRun(java.lang.Boolean)
//  .publishTasks(java.lang.Boolean)
//  .releaseBranches(java.util.Map<java.lang.String, BranchOptions>)
//  .releaseEveryCommit(java.lang.Boolean)
//  .releaseFailureIssue(java.lang.Boolean)
//  .releaseFailureIssueLabel(java.lang.String)
//  .releaseSchedule(java.lang.String)
//  .releaseTagPrefix(java.lang.String)
//  .releaseTrigger(ReleaseTrigger)
//  .releaseWorkflowName(java.lang.String)
//  .releaseWorkflowSetupSteps(java.util.List<JobStep>)
//  .versionrcOptions(java.util.Map<java.lang.String, java.lang.Object>)
//  .workflowContainerImage(java.lang.String)
//  .workflowRunsOn(java.util.List<java.lang.String>)
    .defaultReleaseBranch(java.lang.String)
//  .artifactsDirectory(java.lang.String)
//  .autoApproveUpgrades(java.lang.Boolean)
//  .buildWorkflow(java.lang.Boolean)
//  .buildWorkflowTriggers(Triggers)
//  .bundlerOptions(BundlerOptions)
//  .codeCov(java.lang.Boolean)
//  .codeCovTokenSecret(java.lang.String)
//  .copyrightOwner(java.lang.String)
//  .copyrightPeriod(java.lang.String)
//  .dependabot(java.lang.Boolean)
//  .dependabotOptions(DependabotOptions)
//  .depsUpgrade(java.lang.Boolean)
//  .depsUpgradeOptions(UpgradeDependenciesOptions)
//  .gitignore(java.util.List<java.lang.String>)
//  .jest(java.lang.Boolean)
//  .jestOptions(JestOptions)
//  .mutableBuild(java.lang.Boolean)
//  .npmignore(java.util.List<java.lang.String>)
//  .npmignoreEnabled(java.lang.Boolean)
//  .npmIgnoreOptions(IgnoreFileOptions)
//  .package(java.lang.Boolean)
//  .prettier(java.lang.Boolean)
//  .prettierOptions(PrettierOptions)
//  .projenDevDependency(java.lang.Boolean)
//  .projenrcJs(java.lang.Boolean)
//  .projenrcJsOptions(ProjenrcOptions)
//  .projenVersion(java.lang.String)
//  .pullRequestTemplate(java.lang.Boolean)
//  .pullRequestTemplateContents(java.util.List<java.lang.String>)
//  .release(java.lang.Boolean)
//  .releaseToNpm(java.lang.Boolean)
//  .releaseWorkflow(java.lang.Boolean)
//  .workflowBootstrapSteps(java.util.List<JobStep>)
//  .workflowGitIdentity(GitIdentity)
//  .workflowNodeVersion(java.lang.String)
//  .disableTsconfig(java.lang.Boolean)
//  .disableTsconfigDev(java.lang.Boolean)
//  .docgen(java.lang.Boolean)
//  .docsDirectory(java.lang.String)
//  .entrypointTypes(java.lang.String)
//  .eslint(java.lang.Boolean)
//  .eslintOptions(EslintOptions)
//  .libdir(java.lang.String)
//  .projenrcTs(java.lang.Boolean)
//  .projenrcTsOptions(ProjenrcOptions)
//  .sampleCode(java.lang.Boolean)
//  .srcdir(java.lang.String)
//  .testdir(java.lang.String)
//  .tsconfig(TypescriptConfigOptions)
//  .tsconfigDev(TypescriptConfigOptions)
//  .tsconfigDevFile(java.lang.String)
//  .typescriptVersion(java.lang.String)
//  .rewire(java.util.Map<java.lang.String, java.lang.Object>)
//  .applicationName(java.lang.String)
//  .publicDir(java.lang.String)
    .build();
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.name">name</a></code> | <code>java.lang.String</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.commitGenerated">commitGenerated</a></code> | <code>java.lang.Boolean</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitIgnoreOptions">gitIgnoreOptions</a></code> | <code>io.github.cdklabs.projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitOptions">gitOptions</a></code> | <code>io.github.cdklabs.projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.logging">logging</a></code> | <code>io.github.cdklabs.projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.outdir">outdir</a></code> | <code>java.lang.String</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.parent">parent</a></code> | <code>io.github.cdklabs.projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenCommand">projenCommand</a></code> | <code>java.lang.String</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJson">projenrcJson</a></code> | <code>java.lang.Boolean</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJsonOptions">projenrcJsonOptions</a></code> | <code>io.github.cdklabs.projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.renovatebot">renovatebot</a></code> | <code>java.lang.Boolean</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.renovatebotOptions">renovatebotOptions</a></code> | <code>io.github.cdklabs.projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoApproveOptions">autoApproveOptions</a></code> | <code>io.github.cdklabs.projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoMerge">autoMerge</a></code> | <code>java.lang.Boolean</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoMergeOptions">autoMergeOptions</a></code> | <code>io.github.cdklabs.projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.clobber">clobber</a></code> | <code>java.lang.Boolean</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.devContainer">devContainer</a></code> | <code>java.lang.Boolean</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.github">github</a></code> | <code>java.lang.Boolean</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.githubOptions">githubOptions</a></code> | <code>io.github.cdklabs.projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitpod">gitpod</a></code> | <code>java.lang.Boolean</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mergify">mergify</a></code> | <code>java.lang.Boolean</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mergifyOptions">mergifyOptions</a></code> | <code>io.github.cdklabs.projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projectType">projectType</a></code> | <code>io.github.cdklabs.projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenCredentials">projenCredentials</a></code> | <code>io.github.cdklabs.projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenTokenSecret">projenTokenSecret</a></code> | <code>java.lang.String</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.readme">readme</a></code> | <code>io.github.cdklabs.projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.stale">stale</a></code> | <code>java.lang.Boolean</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.staleOptions">staleOptions</a></code> | <code>io.github.cdklabs.projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.vscode">vscode</a></code> | <code>java.lang.Boolean</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.allowLibraryDependencies">allowLibraryDependencies</a></code> | <code>java.lang.Boolean</code> | Allow the project to include `peerDependencies` and `bundledDependencies`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorEmail">authorEmail</a></code> | <code>java.lang.String</code> | Author's e-mail. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorName">authorName</a></code> | <code>java.lang.String</code> | Author's name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorOrganization">authorOrganization</a></code> | <code>java.lang.Boolean</code> | Is the author an organization. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorUrl">authorUrl</a></code> | <code>java.lang.String</code> | Author's URL / Website. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoDetectBin">autoDetectBin</a></code> | <code>java.lang.Boolean</code> | Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bin">bin</a></code> | <code>java.util.Map<java.lang.String, java.lang.String></code> | Binary programs vended with your module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bugsEmail">bugsEmail</a></code> | <code>java.lang.String</code> | The email address to which issues should be reported. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bugsUrl">bugsUrl</a></code> | <code>java.lang.String</code> | The url to your project's issue tracker. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bundledDeps">bundledDeps</a></code> | <code>java.util.List<java.lang.String></code> | List of dependencies to bundle into this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeArtifactOptions">codeArtifactOptions</a></code> | <code>io.github.cdklabs.projen.javascript.CodeArtifactOptions</code> | Options for npm packages using AWS CodeArtifact. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.deps">deps</a></code> | <code>java.util.List<java.lang.String></code> | Runtime dependencies of this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.description">description</a></code> | <code>java.lang.String</code> | The description is just a string that helps people understand the purpose of the package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.devDeps">devDeps</a></code> | <code>java.util.List<java.lang.String></code> | Build dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.entrypoint">entrypoint</a></code> | <code>java.lang.String</code> | Module entrypoint (`main` in `package.json`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.homepage">homepage</a></code> | <code>java.lang.String</code> | Package's Homepage / Website. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.keywords">keywords</a></code> | <code>java.util.List<java.lang.String></code> | Keywords to include in `package.json`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.license">license</a></code> | <code>java.lang.String</code> | License's SPDX identifier. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.licensed">licensed</a></code> | <code>java.lang.Boolean</code> | Indicates if a license should be added. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.maxNodeVersion">maxNodeVersion</a></code> | <code>java.lang.String</code> | Minimum node.js version to require via `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.minNodeVersion">minNodeVersion</a></code> | <code>java.lang.String</code> | Minimum Node.js version to require via package.json `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmAccess">npmAccess</a></code> | <code>io.github.cdklabs.projen.javascript.NpmAccess</code> | Access level of the npm package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmRegistry">npmRegistry</a></code> | <code>java.lang.String</code> | The host name of the npm registry to publish to. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmRegistryUrl">npmRegistryUrl</a></code> | <code>java.lang.String</code> | The base URL of the npm package registry. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmTokenSecret">npmTokenSecret</a></code> | <code>java.lang.String</code> | GitHub secret which contains the NPM token to use when publishing packages. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.packageManager">packageManager</a></code> | <code>io.github.cdklabs.projen.javascript.NodePackageManager</code> | The Node Package Manager used to execute scripts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.packageName">packageName</a></code> | <code>java.lang.String</code> | The "name" in package.json. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.peerDependencyOptions">peerDependencyOptions</a></code> | <code>io.github.cdklabs.projen.javascript.PeerDependencyOptions</code> | Options for `peerDeps`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.peerDeps">peerDeps</a></code> | <code>java.util.List<java.lang.String></code> | Peer dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pnpmVersion">pnpmVersion</a></code> | <code>java.lang.String</code> | The version of PNPM to use if using PNPM as a package manager. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.repository">repository</a></code> | <code>java.lang.String</code> | The repository is the location where the actual code for your package lives. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.repositoryDirectory">repositoryDirectory</a></code> | <code>java.lang.String</code> | If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.scopedPackagesOptions">scopedPackagesOptions</a></code> | <code>java.util.List<io.github.cdklabs.projen.javascript.ScopedPackagesOptions></code> | Options for privately hosted scoped packages. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.scripts">scripts</a></code> | <code>java.util.Map<java.lang.String, java.lang.String></code> | npm scripts to include. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.stability">stability</a></code> | <code>java.lang.String</code> | Package's Stability. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jsiiReleaseVersion">jsiiReleaseVersion</a></code> | <code>java.lang.String</code> | Version requirement of `publib` which is used to publish modules to npm. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.majorVersion">majorVersion</a></code> | <code>java.lang.Number</code> | Major version to release from the default branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.minMajorVersion">minMajorVersion</a></code> | <code>java.lang.Number</code> | Minimal Major version to release. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmDistTag">npmDistTag</a></code> | <code>java.lang.String</code> | The npmDistTag to use when publishing from the default branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.postBuildSteps">postBuildSteps</a></code> | <code>java.util.List<io.github.cdklabs.projen.github.workflows.JobStep></code> | Steps to execute after build as part of the release workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prerelease">prerelease</a></code> | <code>java.lang.String</code> | Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre"). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publishDryRun">publishDryRun</a></code> | <code>java.lang.Boolean</code> | Instead of actually publishing to package managers, just print the publishing command. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publishTasks">publishTasks</a></code> | <code>java.lang.Boolean</code> | Define publishing tasks that can be executed manually as well as workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseBranches">releaseBranches</a></code> | <code>java.util.Map<java.lang.String, io.github.cdklabs.projen.release.BranchOptions></code> | Defines additional release branches. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseEveryCommit">releaseEveryCommit</a></code> | <code>java.lang.Boolean</code> | Automatically release new versions every commit to one of branches in `releaseBranches`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseFailureIssue">releaseFailureIssue</a></code> | <code>java.lang.Boolean</code> | Create a github issue on every failed publishing task. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseFailureIssueLabel">releaseFailureIssueLabel</a></code> | <code>java.lang.String</code> | The label to apply to issues indicating publish failures. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseSchedule">releaseSchedule</a></code> | <code>java.lang.String</code> | CRON schedule to trigger new releases. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseTagPrefix">releaseTagPrefix</a></code> | <code>java.lang.String</code> | Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseTrigger">releaseTrigger</a></code> | <code>io.github.cdklabs.projen.release.ReleaseTrigger</code> | The release trigger to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflowName">releaseWorkflowName</a></code> | <code>java.lang.String</code> | The name of the default release workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflowSetupSteps">releaseWorkflowSetupSteps</a></code> | <code>java.util.List<io.github.cdklabs.projen.github.workflows.JobStep></code> | A set of workflow steps to execute in order to setup the workflow container. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.versionrcOptions">versionrcOptions</a></code> | <code>java.util.Map<java.lang.String, java.lang.Object></code> | Custom configuration used when creating changelog with standard-version package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowContainerImage">workflowContainerImage</a></code> | <code>java.lang.String</code> | Container image to use for GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowRunsOn">workflowRunsOn</a></code> | <code>java.util.List<java.lang.String></code> | Github Runner selection labels. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.defaultReleaseBranch">defaultReleaseBranch</a></code> | <code>java.lang.String</code> | The name of the main release branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.artifactsDirectory">artifactsDirectory</a></code> | <code>java.lang.String</code> | A directory which will contain build artifacts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoApproveUpgrades">autoApproveUpgrades</a></code> | <code>java.lang.Boolean</code> | Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.buildWorkflow">buildWorkflow</a></code> | <code>java.lang.Boolean</code> | Define a GitHub workflow for building PRs. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.buildWorkflowTriggers">buildWorkflowTriggers</a></code> | <code>io.github.cdklabs.projen.github.workflows.Triggers</code> | Build workflow triggers. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bundlerOptions">bundlerOptions</a></code> | <code>io.github.cdklabs.projen.javascript.BundlerOptions</code> | Options for `Bundler`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeCov">codeCov</a></code> | <code>java.lang.Boolean</code> | Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with @codeCovTokenSecret. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeCovTokenSecret">codeCovTokenSecret</a></code> | <code>java.lang.String</code> | Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.copyrightOwner">copyrightOwner</a></code> | <code>java.lang.String</code> | License copyright owner. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.copyrightPeriod">copyrightPeriod</a></code> | <code>java.lang.String</code> | The copyright years to put in the LICENSE file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.dependabot">dependabot</a></code> | <code>java.lang.Boolean</code> | Use dependabot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.dependabotOptions">dependabotOptions</a></code> | <code>io.github.cdklabs.projen.github.DependabotOptions</code> | Options for dependabot. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.depsUpgrade">depsUpgrade</a></code> | <code>java.lang.Boolean</code> | Use github workflows to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.depsUpgradeOptions">depsUpgradeOptions</a></code> | <code>io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions</code> | Options for `UpgradeDependencies`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitignore">gitignore</a></code> | <code>java.util.List<java.lang.String></code> | Additional entries to .gitignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jest">jest</a></code> | <code>java.lang.Boolean</code> | Setup jest unit tests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jestOptions">jestOptions</a></code> | <code>io.github.cdklabs.projen.javascript.JestOptions</code> | Jest options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mutableBuild">mutableBuild</a></code> | <code>java.lang.Boolean</code> | Automatically update files modified during builds to pull-request branches. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmignore">npmignore</a></code> | <code>java.util.List<java.lang.String></code> | Additional entries to .npmignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmignoreEnabled">npmignoreEnabled</a></code> | <code>java.lang.Boolean</code> | Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmIgnoreOptions">npmIgnoreOptions</a></code> | <code>io.github.cdklabs.projen.IgnoreFileOptions</code> | Configuration options for .npmignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.package">package</a></code> | <code>java.lang.Boolean</code> | Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prettier">prettier</a></code> | <code>java.lang.Boolean</code> | Setup prettier. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prettierOptions">prettierOptions</a></code> | <code>io.github.cdklabs.projen.javascript.PrettierOptions</code> | Prettier options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenDevDependency">projenDevDependency</a></code> | <code>java.lang.Boolean</code> | Indicates of "projen" should be installed as a devDependency. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJs">projenrcJs</a></code> | <code>java.lang.Boolean</code> | Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJsOptions">projenrcJsOptions</a></code> | <code>io.github.cdklabs.projen.javascript.ProjenrcOptions</code> | Options for .projenrc.js. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenVersion">projenVersion</a></code> | <code>java.lang.String</code> | Version of projen to install. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pullRequestTemplate">pullRequestTemplate</a></code> | <code>java.lang.Boolean</code> | Include a GitHub pull request template. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pullRequestTemplateContents">pullRequestTemplateContents</a></code> | <code>java.util.List<java.lang.String></code> | The contents of the pull request template. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.release">release</a></code> | <code>java.lang.Boolean</code> | Add release management to this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseToNpm">releaseToNpm</a></code> | <code>java.lang.Boolean</code> | Automatically release to npm when new versions are introduced. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflow">releaseWorkflow</a></code> | <code>java.lang.Boolean</code> | DEPRECATED: renamed to `release`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowBootstrapSteps">workflowBootstrapSteps</a></code> | <code>java.util.List<io.github.cdklabs.projen.github.workflows.JobStep></code> | Workflow steps to use in order to bootstrap this repo. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowGitIdentity">workflowGitIdentity</a></code> | <code>io.github.cdklabs.projen.github.GitIdentity</code> | The git identity to use in workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowNodeVersion">workflowNodeVersion</a></code> | <code>java.lang.String</code> | The node version to use in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.disableTsconfig">disableTsconfig</a></code> | <code>java.lang.Boolean</code> | Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.disableTsconfigDev">disableTsconfigDev</a></code> | <code>java.lang.Boolean</code> | Do not generate a `tsconfig.dev.json` file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.docgen">docgen</a></code> | <code>java.lang.Boolean</code> | Docgen by Typedoc. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.docsDirectory">docsDirectory</a></code> | <code>java.lang.String</code> | Docs directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.entrypointTypes">entrypointTypes</a></code> | <code>java.lang.String</code> | The .d.ts file that includes the type declarations for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.eslint">eslint</a></code> | <code>java.lang.Boolean</code> | Setup eslint. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.eslintOptions">eslintOptions</a></code> | <code>io.github.cdklabs.projen.javascript.EslintOptions</code> | Eslint options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.libdir">libdir</a></code> | <code>java.lang.String</code> | Typescript  artifacts output directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcTs">projenrcTs</a></code> | <code>java.lang.Boolean</code> | Use TypeScript for your projenrc file (`.projenrc.ts`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcTsOptions">projenrcTsOptions</a></code> | <code>io.github.cdklabs.projen.typescript.ProjenrcOptions</code> | Options for .projenrc.ts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.sampleCode">sampleCode</a></code> | <code>java.lang.Boolean</code> | Generate one-time sample in `src/` and `test/` if there are no files there. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.srcdir">srcdir</a></code> | <code>java.lang.String</code> | Typescript sources directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.testdir">testdir</a></code> | <code>java.lang.String</code> | Jest tests directory. Tests files should be named `xxx.test.ts`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfig">tsconfig</a></code> | <code>io.github.cdklabs.projen.javascript.TypescriptConfigOptions</code> | Custom TSConfig. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfigDev">tsconfigDev</a></code> | <code>io.github.cdklabs.projen.javascript.TypescriptConfigOptions</code> | Custom tsconfig options for the development tsconfig.json file (used for testing). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfigDevFile">tsconfigDevFile</a></code> | <code>java.lang.String</code> | The name of the development tsconfig.json file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.typescriptVersion">typescriptVersion</a></code> | <code>java.lang.String</code> | TypeScript version to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.rewire">rewire</a></code> | <code>java.util.Map<java.lang.String, java.lang.Object></code> | Rewire webpack configuration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.applicationName">applicationName</a></code> | <code>java.lang.String</code> | Name of the application name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publicDir">publicDir</a></code> | <code>java.lang.String</code> | Public directory. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.name"></a>

- *Type:* java.lang.String
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commitGenerated`<sup>Optional</sup> <a name="commitGenerated" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.commitGenerated"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Whether to commit the managed files by default.

---

##### `gitIgnoreOptions`<sup>Optional</sup> <a name="gitIgnoreOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitIgnoreOptions"></a>

- *Type:* io.github.cdklabs.projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `gitOptions`<sup>Optional</sup> <a name="gitOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitOptions"></a>

- *Type:* io.github.cdklabs.projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.logging"></a>

- *Type:* io.github.cdklabs.projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.outdir"></a>

- *Type:* java.lang.String
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.parent"></a>

- *Type:* io.github.cdklabs.projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projenCommand`<sup>Optional</sup> <a name="projenCommand" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenCommand"></a>

- *Type:* java.lang.String
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrcJson`<sup>Optional</sup> <a name="projenrcJson" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJson"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrcJsonOptions`<sup>Optional</sup> <a name="projenrcJsonOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJsonOptions"></a>

- *Type:* io.github.cdklabs.projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.renovatebot"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebotOptions`<sup>Optional</sup> <a name="renovatebotOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.renovatebotOptions"></a>

- *Type:* io.github.cdklabs.projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `autoApproveOptions`<sup>Optional</sup> <a name="autoApproveOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoApproveOptions"></a>

- *Type:* io.github.cdklabs.projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `autoMerge`<sup>Optional</sup> <a name="autoMerge" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoMerge"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `autoMergeOptions`<sup>Optional</sup> <a name="autoMergeOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoMergeOptions"></a>

- *Type:* io.github.cdklabs.projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.clobber"></a>

- *Type:* java.lang.Boolean
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `devContainer`<sup>Optional</sup> <a name="devContainer" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.devContainer"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.github"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `githubOptions`<sup>Optional</sup> <a name="githubOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.githubOptions"></a>

- *Type:* io.github.cdklabs.projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitpod"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

- *Type:* java.lang.Boolean
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergifyOptions`~~<sup>Optional</sup> <a name="mergifyOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

- *Type:* io.github.cdklabs.projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`projectType`~~<sup>Optional</sup> <a name="projectType" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projectType"></a>

- *Deprecated:* no longer supported at the base project level

- *Type:* io.github.cdklabs.projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projenCredentials`<sup>Optional</sup> <a name="projenCredentials" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenCredentials"></a>

- *Type:* io.github.cdklabs.projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projenTokenSecret`~~<sup>Optional</sup> <a name="projenTokenSecret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

- *Type:* java.lang.String
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.readme"></a>

- *Type:* io.github.cdklabs.projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```java
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.stale"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `staleOptions`<sup>Optional</sup> <a name="staleOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.staleOptions"></a>

- *Type:* io.github.cdklabs.projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.vscode"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `allowLibraryDependencies`<sup>Optional</sup> <a name="allowLibraryDependencies" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.allowLibraryDependencies"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Allow the project to include `peerDependencies` and `bundledDependencies`.

This is normally only allowed for libraries. For apps, there's no meaning
for specifying these.

---

##### `authorEmail`<sup>Optional</sup> <a name="authorEmail" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorEmail"></a>

- *Type:* java.lang.String

Author's e-mail.

---

##### `authorName`<sup>Optional</sup> <a name="authorName" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorName"></a>

- *Type:* java.lang.String

Author's name.

---

##### `authorOrganization`<sup>Optional</sup> <a name="authorOrganization" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorOrganization"></a>

- *Type:* java.lang.Boolean

Is the author an organization.

---

##### `authorUrl`<sup>Optional</sup> <a name="authorUrl" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorUrl"></a>

- *Type:* java.lang.String

Author's URL / Website.

---

##### `autoDetectBin`<sup>Optional</sup> <a name="autoDetectBin" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoDetectBin"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section.

---

##### `bin`<sup>Optional</sup> <a name="bin" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bin"></a>

- *Type:* java.util.Map<java.lang.String, java.lang.String>

Binary programs vended with your module.

You can use this option to add/customize how binaries are represented in
your `package.json`, but unless `autoDetectBin` is `false`, every
executable file under `bin` will automatically be added to this section.

---

##### `bugsEmail`<sup>Optional</sup> <a name="bugsEmail" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bugsEmail"></a>

- *Type:* java.lang.String

The email address to which issues should be reported.

---

##### `bugsUrl`<sup>Optional</sup> <a name="bugsUrl" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bugsUrl"></a>

- *Type:* java.lang.String

The url to your project's issue tracker.

---

##### `bundledDeps`<sup>Optional</sup> <a name="bundledDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bundledDeps"></a>

- *Type:* java.util.List<java.lang.String>

List of dependencies to bundle into this module.

These modules will be
added both to the `dependencies` section and `bundledDependencies` section of
your `package.json`.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

##### `codeArtifactOptions`<sup>Optional</sup> <a name="codeArtifactOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeArtifactOptions"></a>

- *Type:* io.github.cdklabs.projen.javascript.CodeArtifactOptions
- *Default:* undefined

Options for npm packages using AWS CodeArtifact.

This is required if publishing packages to, or installing scoped packages from AWS CodeArtifact

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.deps"></a>

- *Type:* java.util.List<java.lang.String>
- *Default:* []

Runtime dependencies of this module.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```java
[ 'express', 'lodash', 'foo@^2' ]
```


##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.description"></a>

- *Type:* java.lang.String

The description is just a string that helps people understand the purpose of the package.

It can be used when searching for packages in a package manager as well.
See https://classic.yarnpkg.com/en/docs/package-json/#toc-description

---

##### `devDeps`<sup>Optional</sup> <a name="devDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.devDeps"></a>

- *Type:* java.util.List<java.lang.String>
- *Default:* []

Build dependencies for this module.

These dependencies will only be
available in your build environment but will not be fetched when this
module is consumed.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```java
[ 'typescript', '@types/express' ]
```


##### `entrypoint`<sup>Optional</sup> <a name="entrypoint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.entrypoint"></a>

- *Type:* java.lang.String
- *Default:* "lib/index.js"

Module entrypoint (`main` in `package.json`).

Set to an empty string to not include `main` in your package.json

---

##### `homepage`<sup>Optional</sup> <a name="homepage" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.homepage"></a>

- *Type:* java.lang.String

Package's Homepage / Website.

---

##### `keywords`<sup>Optional</sup> <a name="keywords" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.keywords"></a>

- *Type:* java.util.List<java.lang.String>

Keywords to include in `package.json`.

---

##### `license`<sup>Optional</sup> <a name="license" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.license"></a>

- *Type:* java.lang.String
- *Default:* "Apache-2.0"

License's SPDX identifier.

See https://github.com/projen/projen/tree/main/license-text for a list of supported licenses.
Use the `licensed` option if you want to no license to be specified.

---

##### `licensed`<sup>Optional</sup> <a name="licensed" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.licensed"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Indicates if a license should be added.

---

##### `maxNodeVersion`<sup>Optional</sup> <a name="maxNodeVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.maxNodeVersion"></a>

- *Type:* java.lang.String
- *Default:* no max

Minimum node.js version to require via `engines` (inclusive).

---

##### `minNodeVersion`<sup>Optional</sup> <a name="minNodeVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.minNodeVersion"></a>

- *Type:* java.lang.String
- *Default:* no "engines" specified

Minimum Node.js version to require via package.json `engines` (inclusive).

---

##### `npmAccess`<sup>Optional</sup> <a name="npmAccess" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmAccess"></a>

- *Type:* io.github.cdklabs.projen.javascript.NpmAccess
- *Default:* for scoped packages (e.g. `foo@bar`), the default is `NpmAccess.RESTRICTED`, for non-scoped packages, the default is `NpmAccess.PUBLIC`.

Access level of the npm package.

---

##### ~~`npmRegistry`~~<sup>Optional</sup> <a name="npmRegistry" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmRegistry"></a>

- *Deprecated:* use `npmRegistryUrl` instead

- *Type:* java.lang.String

The host name of the npm registry to publish to.

Cannot be set together with `npmRegistryUrl`.

---

##### `npmRegistryUrl`<sup>Optional</sup> <a name="npmRegistryUrl" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmRegistryUrl"></a>

- *Type:* java.lang.String
- *Default:* "https://registry.npmjs.org"

The base URL of the npm package registry.

Must be a URL (e.g. start with "https://" or "http://")

---

##### `npmTokenSecret`<sup>Optional</sup> <a name="npmTokenSecret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmTokenSecret"></a>

- *Type:* java.lang.String
- *Default:* "NPM_TOKEN"

GitHub secret which contains the NPM token to use when publishing packages.

---

##### `packageManager`<sup>Optional</sup> <a name="packageManager" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.packageManager"></a>

- *Type:* io.github.cdklabs.projen.javascript.NodePackageManager
- *Default:* NodePackageManager.YARN

The Node Package Manager used to execute scripts.

---

##### `packageName`<sup>Optional</sup> <a name="packageName" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.packageName"></a>

- *Type:* java.lang.String
- *Default:* defaults to project name

The "name" in package.json.

---

##### `peerDependencyOptions`<sup>Optional</sup> <a name="peerDependencyOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.peerDependencyOptions"></a>

- *Type:* io.github.cdklabs.projen.javascript.PeerDependencyOptions

Options for `peerDeps`.

---

##### `peerDeps`<sup>Optional</sup> <a name="peerDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.peerDeps"></a>

- *Type:* java.util.List<java.lang.String>
- *Default:* []

Peer dependencies for this module.

Dependencies listed here are required to
be installed (and satisfied) by the _consumer_ of this library. Using peer
dependencies allows you to ensure that only a single module of a certain
library exists in the `node_modules` tree of your consumers.

Note that prior to npm@7, peer dependencies are _not_ automatically
installed, which means that adding peer dependencies to a library will be a
breaking change for your customers.

Unless `peerDependencyOptions.pinnedDevDependency` is disabled (it is
enabled by default), projen will automatically add a dev dependency with a
pinned version for each peer dependency. This will ensure that you build &
test your module against the lowest peer version required.

---

##### `pnpmVersion`<sup>Optional</sup> <a name="pnpmVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pnpmVersion"></a>

- *Type:* java.lang.String
- *Default:* "7"

The version of PNPM to use if using PNPM as a package manager.

---

##### `repository`<sup>Optional</sup> <a name="repository" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.repository"></a>

- *Type:* java.lang.String

The repository is the location where the actual code for your package lives.

See https://classic.yarnpkg.com/en/docs/package-json/#toc-repository

---

##### `repositoryDirectory`<sup>Optional</sup> <a name="repositoryDirectory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.repositoryDirectory"></a>

- *Type:* java.lang.String

If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives.

---

##### `scopedPackagesOptions`<sup>Optional</sup> <a name="scopedPackagesOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.scopedPackagesOptions"></a>

- *Type:* java.util.List<io.github.cdklabs.projen.javascript.ScopedPackagesOptions>
- *Default:* fetch all scoped packages from the public npm registry

Options for privately hosted scoped packages.

---

##### `scripts`<sup>Optional</sup> <a name="scripts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.scripts"></a>

- *Type:* java.util.Map<java.lang.String, java.lang.String>
- *Default:* {}

npm scripts to include.

If a script has the same name as a standard script,
the standard script will be overwritten.

---

##### `stability`<sup>Optional</sup> <a name="stability" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.stability"></a>

- *Type:* java.lang.String

Package's Stability.

---

##### `jsiiReleaseVersion`<sup>Optional</sup> <a name="jsiiReleaseVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jsiiReleaseVersion"></a>

- *Type:* java.lang.String
- *Default:* "latest"

Version requirement of `publib` which is used to publish modules to npm.

---

##### `majorVersion`<sup>Optional</sup> <a name="majorVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.majorVersion"></a>

- *Type:* java.lang.Number
- *Default:* Major version is not enforced.

Major version to release from the default branch.

If this is specified, we bump the latest version of this major version line.
If not specified, we bump the global latest version.

---

##### `minMajorVersion`<sup>Optional</sup> <a name="minMajorVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.minMajorVersion"></a>

- *Type:* java.lang.Number
- *Default:* No minimum version is being enforced

Minimal Major version to release.

This can be useful to set to 1, as breaking changes before the 1.x major
release are not incrementing the major version number.

Can not be set together with `majorVersion`.

---

##### `npmDistTag`<sup>Optional</sup> <a name="npmDistTag" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmDistTag"></a>

- *Type:* java.lang.String
- *Default:* "latest"

The npmDistTag to use when publishing from the default branch.

To set the npm dist-tag for release branches, set the `npmDistTag` property
for each branch.

---

##### `postBuildSteps`<sup>Optional</sup> <a name="postBuildSteps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.postBuildSteps"></a>

- *Type:* java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>
- *Default:* []

Steps to execute after build as part of the release workflow.

---

##### `prerelease`<sup>Optional</sup> <a name="prerelease" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prerelease"></a>

- *Type:* java.lang.String
- *Default:* normal semantic versions

Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre").

---

##### `publishDryRun`<sup>Optional</sup> <a name="publishDryRun" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publishDryRun"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Instead of actually publishing to package managers, just print the publishing command.

---

##### `publishTasks`<sup>Optional</sup> <a name="publishTasks" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publishTasks"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Define publishing tasks that can be executed manually as well as workflows.

Normally, publishing only happens within automated workflows. Enable this
in order to create a publishing task for each publishing activity.

---

##### `releaseBranches`<sup>Optional</sup> <a name="releaseBranches" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseBranches"></a>

- *Type:* java.util.Map<java.lang.String, io.github.cdklabs.projen.release.BranchOptions>
- *Default:* no additional branches are used for release. you can use `addBranch()` to add additional branches.

Defines additional release branches.

A workflow will be created for each
release branch which will publish releases from commits in this branch.
Each release branch _must_ be assigned a major version number which is used
to enforce that versions published from that branch always use that major
version. If multiple branches are used, the `majorVersion` field must also
be provided for the default branch.

---

##### ~~`releaseEveryCommit`~~<sup>Optional</sup> <a name="releaseEveryCommit" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseEveryCommit"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.continuous()` instead

- *Type:* java.lang.Boolean
- *Default:* true

Automatically release new versions every commit to one of branches in `releaseBranches`.

---

##### `releaseFailureIssue`<sup>Optional</sup> <a name="releaseFailureIssue" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseFailureIssue"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Create a github issue on every failed publishing task.

---

##### `releaseFailureIssueLabel`<sup>Optional</sup> <a name="releaseFailureIssueLabel" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseFailureIssueLabel"></a>

- *Type:* java.lang.String
- *Default:* "failed-release"

The label to apply to issues indicating publish failures.

Only applies if `releaseFailureIssue` is true.

---

##### ~~`releaseSchedule`~~<sup>Optional</sup> <a name="releaseSchedule" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseSchedule"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.scheduled()` instead

- *Type:* java.lang.String
- *Default:* no scheduled releases

CRON schedule to trigger new releases.

---

##### `releaseTagPrefix`<sup>Optional</sup> <a name="releaseTagPrefix" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseTagPrefix"></a>

- *Type:* java.lang.String
- *Default:* "v"

Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers.

Note: this prefix is used to detect the latest tagged version
when bumping, so if you change this on a project with an existing version
history, you may need to manually tag your latest release
with the new prefix.

---

##### `releaseTrigger`<sup>Optional</sup> <a name="releaseTrigger" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseTrigger"></a>

- *Type:* io.github.cdklabs.projen.release.ReleaseTrigger
- *Default:* Continuous releases (`ReleaseTrigger.continuous()`)

The release trigger to use.

---

##### `releaseWorkflowName`<sup>Optional</sup> <a name="releaseWorkflowName" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflowName"></a>

- *Type:* java.lang.String
- *Default:* "Release"

The name of the default release workflow.

---

##### `releaseWorkflowSetupSteps`<sup>Optional</sup> <a name="releaseWorkflowSetupSteps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflowSetupSteps"></a>

- *Type:* java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>

A set of workflow steps to execute in order to setup the workflow container.

---

##### `versionrcOptions`<sup>Optional</sup> <a name="versionrcOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.versionrcOptions"></a>

- *Type:* java.util.Map<java.lang.String, java.lang.Object>
- *Default:* standard configuration applicable for GitHub repositories

Custom configuration used when creating changelog with standard-version package.

Given values either append to default configuration or overwrite values in it.

---

##### `workflowContainerImage`<sup>Optional</sup> <a name="workflowContainerImage" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowContainerImage"></a>

- *Type:* java.lang.String
- *Default:* default image

Container image to use for GitHub workflows.

---

##### `workflowRunsOn`<sup>Optional</sup> <a name="workflowRunsOn" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowRunsOn"></a>

- *Type:* java.util.List<java.lang.String>
- *Default:* ["ubuntu-latest"]

Github Runner selection labels.

---

##### `defaultReleaseBranch`<sup>Required</sup> <a name="defaultReleaseBranch" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.defaultReleaseBranch"></a>

- *Type:* java.lang.String
- *Default:* "main"

The name of the main release branch.

---

##### `artifactsDirectory`<sup>Optional</sup> <a name="artifactsDirectory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.artifactsDirectory"></a>

- *Type:* java.lang.String
- *Default:* "dist"

A directory which will contain build artifacts.

---

##### `autoApproveUpgrades`<sup>Optional</sup> <a name="autoApproveUpgrades" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoApproveUpgrades"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued).

Throw if set to true but `autoApproveOptions` are not defined.

---

##### `buildWorkflow`<sup>Optional</sup> <a name="buildWorkflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.buildWorkflow"></a>

- *Type:* java.lang.Boolean
- *Default:* true if not a subproject

Define a GitHub workflow for building PRs.

---

##### `buildWorkflowTriggers`<sup>Optional</sup> <a name="buildWorkflowTriggers" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.buildWorkflowTriggers"></a>

- *Type:* io.github.cdklabs.projen.github.workflows.Triggers
- *Default:* "{ pullRequest: {}, workflowDispatch: {} }"

Build workflow triggers.

---

##### `bundlerOptions`<sup>Optional</sup> <a name="bundlerOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bundlerOptions"></a>

- *Type:* io.github.cdklabs.projen.javascript.BundlerOptions

Options for `Bundler`.

---

##### `codeCov`<sup>Optional</sup> <a name="codeCov" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeCov"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with @codeCovTokenSecret.

---

##### `codeCovTokenSecret`<sup>Optional</sup> <a name="codeCovTokenSecret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeCovTokenSecret"></a>

- *Type:* java.lang.String
- *Default:* if this option is not specified, only public repositories are supported

Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories.

---

##### `copyrightOwner`<sup>Optional</sup> <a name="copyrightOwner" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.copyrightOwner"></a>

- *Type:* java.lang.String
- *Default:* defaults to the value of authorName or "" if `authorName` is undefined.

License copyright owner.

---

##### `copyrightPeriod`<sup>Optional</sup> <a name="copyrightPeriod" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.copyrightPeriod"></a>

- *Type:* java.lang.String
- *Default:* current year

The copyright years to put in the LICENSE file.

---

##### `dependabot`<sup>Optional</sup> <a name="dependabot" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.dependabot"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Use dependabot to handle dependency upgrades.

Cannot be used in conjunction with `depsUpgrade`.

---

##### `dependabotOptions`<sup>Optional</sup> <a name="dependabotOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.dependabotOptions"></a>

- *Type:* io.github.cdklabs.projen.github.DependabotOptions
- *Default:* default options

Options for dependabot.

---

##### `depsUpgrade`<sup>Optional</sup> <a name="depsUpgrade" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.depsUpgrade"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Use github workflows to handle dependency upgrades.

Cannot be used in conjunction with `dependabot`.

---

##### `depsUpgradeOptions`<sup>Optional</sup> <a name="depsUpgradeOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.depsUpgradeOptions"></a>

- *Type:* io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions
- *Default:* default options

Options for `UpgradeDependencies`.

---

##### `gitignore`<sup>Optional</sup> <a name="gitignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitignore"></a>

- *Type:* java.util.List<java.lang.String>

Additional entries to .gitignore.

---

##### `jest`<sup>Optional</sup> <a name="jest" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jest"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Setup jest unit tests.

---

##### `jestOptions`<sup>Optional</sup> <a name="jestOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jestOptions"></a>

- *Type:* io.github.cdklabs.projen.javascript.JestOptions
- *Default:* default options

Jest options.

---

##### `mutableBuild`<sup>Optional</sup> <a name="mutableBuild" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mutableBuild"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Automatically update files modified during builds to pull-request branches.

This means
that any files synthesized by projen or e.g. test snapshots will always be up-to-date
before a PR is merged.

Implies that PR builds do not have anti-tamper checks.

---

##### ~~`npmignore`~~<sup>Optional</sup> <a name="npmignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmignore"></a>

- *Deprecated:* - use `project.addPackageIgnore`

- *Type:* java.util.List<java.lang.String>

Additional entries to .npmignore.

---

##### `npmignoreEnabled`<sup>Optional</sup> <a name="npmignoreEnabled" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmignoreEnabled"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs.

---

##### `npmIgnoreOptions`<sup>Optional</sup> <a name="npmIgnoreOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmIgnoreOptions"></a>

- *Type:* io.github.cdklabs.projen.IgnoreFileOptions

Configuration options for .npmignore file.

---

##### `package`<sup>Optional</sup> <a name="package" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.package"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`).

---

##### `prettier`<sup>Optional</sup> <a name="prettier" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prettier"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Setup prettier.

---

##### `prettierOptions`<sup>Optional</sup> <a name="prettierOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prettierOptions"></a>

- *Type:* io.github.cdklabs.projen.javascript.PrettierOptions
- *Default:* default options

Prettier options.

---

##### `projenDevDependency`<sup>Optional</sup> <a name="projenDevDependency" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenDevDependency"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Indicates of "projen" should be installed as a devDependency.

---

##### `projenrcJs`<sup>Optional</sup> <a name="projenrcJs" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJs"></a>

- *Type:* java.lang.Boolean
- *Default:* true if projenrcJson is false

Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation.

---

##### `projenrcJsOptions`<sup>Optional</sup> <a name="projenrcJsOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJsOptions"></a>

- *Type:* io.github.cdklabs.projen.javascript.ProjenrcOptions
- *Default:* default options

Options for .projenrc.js.

---

##### `projenVersion`<sup>Optional</sup> <a name="projenVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenVersion"></a>

- *Type:* java.lang.String
- *Default:* Defaults to the latest version.

Version of projen to install.

---

##### `pullRequestTemplate`<sup>Optional</sup> <a name="pullRequestTemplate" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pullRequestTemplate"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Include a GitHub pull request template.

---

##### `pullRequestTemplateContents`<sup>Optional</sup> <a name="pullRequestTemplateContents" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pullRequestTemplateContents"></a>

- *Type:* java.util.List<java.lang.String>
- *Default:* default content

The contents of the pull request template.

---

##### `release`<sup>Optional</sup> <a name="release" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.release"></a>

- *Type:* java.lang.Boolean
- *Default:* true (false for subprojects)

Add release management to this project.

---

##### `releaseToNpm`<sup>Optional</sup> <a name="releaseToNpm" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseToNpm"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Automatically release to npm when new versions are introduced.

---

##### ~~`releaseWorkflow`~~<sup>Optional</sup> <a name="releaseWorkflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflow"></a>

- *Deprecated:* see `release`.

- *Type:* java.lang.Boolean
- *Default:* true if not a subproject

DEPRECATED: renamed to `release`.

---

##### `workflowBootstrapSteps`<sup>Optional</sup> <a name="workflowBootstrapSteps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowBootstrapSteps"></a>

- *Type:* java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>
- *Default:* "yarn install --frozen-lockfile && yarn projen"

Workflow steps to use in order to bootstrap this repo.

---

##### `workflowGitIdentity`<sup>Optional</sup> <a name="workflowGitIdentity" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowGitIdentity"></a>

- *Type:* io.github.cdklabs.projen.github.GitIdentity
- *Default:* GitHub Actions

The git identity to use in workflows.

---

##### `workflowNodeVersion`<sup>Optional</sup> <a name="workflowNodeVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowNodeVersion"></a>

- *Type:* java.lang.String
- *Default:* same as `minNodeVersion`

The node version to use in GitHub workflows.

---

##### `disableTsconfig`<sup>Optional</sup> <a name="disableTsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.disableTsconfig"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler).

---

##### `disableTsconfigDev`<sup>Optional</sup> <a name="disableTsconfigDev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.disableTsconfigDev"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Do not generate a `tsconfig.dev.json` file.

---

##### `docgen`<sup>Optional</sup> <a name="docgen" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.docgen"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Docgen by Typedoc.

---

##### `docsDirectory`<sup>Optional</sup> <a name="docsDirectory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.docsDirectory"></a>

- *Type:* java.lang.String
- *Default:* "docs"

Docs directory.

---

##### `entrypointTypes`<sup>Optional</sup> <a name="entrypointTypes" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.entrypointTypes"></a>

- *Type:* java.lang.String
- *Default:* .d.ts file derived from the project's entrypoint (usually lib/index.d.ts)

The .d.ts file that includes the type declarations for this module.

---

##### `eslint`<sup>Optional</sup> <a name="eslint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.eslint"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Setup eslint.

---

##### `eslintOptions`<sup>Optional</sup> <a name="eslintOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.eslintOptions"></a>

- *Type:* io.github.cdklabs.projen.javascript.EslintOptions
- *Default:* opinionated default options

Eslint options.

---

##### `libdir`<sup>Optional</sup> <a name="libdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.libdir"></a>

- *Type:* java.lang.String
- *Default:* "lib"

Typescript  artifacts output directory.

---

##### `projenrcTs`<sup>Optional</sup> <a name="projenrcTs" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcTs"></a>

- *Type:* java.lang.Boolean
- *Default:* false

Use TypeScript for your projenrc file (`.projenrc.ts`).

---

##### `projenrcTsOptions`<sup>Optional</sup> <a name="projenrcTsOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcTsOptions"></a>

- *Type:* io.github.cdklabs.projen.typescript.ProjenrcOptions

Options for .projenrc.ts.

---

##### `sampleCode`<sup>Optional</sup> <a name="sampleCode" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.sampleCode"></a>

- *Type:* java.lang.Boolean
- *Default:* true

Generate one-time sample in `src/` and `test/` if there are no files there.

---

##### `srcdir`<sup>Optional</sup> <a name="srcdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.srcdir"></a>

- *Type:* java.lang.String
- *Default:* "src"

Typescript sources directory.

---

##### `testdir`<sup>Optional</sup> <a name="testdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.testdir"></a>

- *Type:* java.lang.String
- *Default:* "test"

Jest tests directory. Tests files should be named `xxx.test.ts`.

If this directory is under `srcdir` (e.g. `src/test`, `src/__tests__`),
then tests are going to be compiled into `lib/` and executed as javascript.
If the test directory is outside of `src`, then we configure jest to
compile the code in-memory.

---

##### `tsconfig`<sup>Optional</sup> <a name="tsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfig"></a>

- *Type:* io.github.cdklabs.projen.javascript.TypescriptConfigOptions
- *Default:* default options

Custom TSConfig.

---

##### `tsconfigDev`<sup>Optional</sup> <a name="tsconfigDev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfigDev"></a>

- *Type:* io.github.cdklabs.projen.javascript.TypescriptConfigOptions
- *Default:* use the production tsconfig options

Custom tsconfig options for the development tsconfig.json file (used for testing).

---

##### `tsconfigDevFile`<sup>Optional</sup> <a name="tsconfigDevFile" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfigDevFile"></a>

- *Type:* java.lang.String
- *Default:* "tsconfig.dev.json"

The name of the development tsconfig.json file.

---

##### `typescriptVersion`<sup>Optional</sup> <a name="typescriptVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.typescriptVersion"></a>

- *Type:* java.lang.String
- *Default:* "latest"

TypeScript version to use.

NOTE: Typescript is not semantically versioned and should remain on the
same minor, so we recommend using a `~` dependency (e.g. `~1.2.3`).

---

##### `rewire`<sup>Optional</sup> <a name="rewire" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.rewire"></a>

- *Type:* java.util.Map<java.lang.String, java.lang.Object>
- *Default:* No rewired config.

Rewire webpack configuration.

Use this property to override webpack configuration properties provided
by create-react-app, without needing to eject.

This property will create a `config-overrides.js` file in your root directory,
which will contain the desired rewiring code.

To **override** the configuration, you can provide simple key value pairs.
Keys take the form of js code directives that traverse to the desired property.
Values should be JSON serializable objects.

For example, the following config:

```json
rewire: { "module.unknownContextCritical": false }
```

Will translate to the following `config-overrides.js` file:

```js
module.exports = function override(config, env) {
  config.module.unknownContextCritical = false;
}
```

> [https://github.com/timarney/react-app-rewired](https://github.com/timarney/react-app-rewired)

---

##### `applicationName`<sup>Optional</sup> <a name="applicationName" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.applicationName"></a>

- *Type:* java.lang.String
- *Default:* "Sample App"

Name of the application name.

---

##### `publicDir`<sup>Optional</sup> <a name="publicDir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publicDir"></a>

- *Type:* java.lang.String
- *Default:* "public"

Public directory.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addExcludeFromCleanup">addExcludeFromCleanup</a></code> | Exclude the matching files from pre-synth cleanup. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addGitIgnore">addGitIgnore</a></code> | Adds a .gitignore pattern. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPackageIgnore">addPackageIgnore</a></code> | Exclude these files from the bundled package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask">addTask</a></code> | Adds a new task to this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTip">addTip</a></code> | Prints a "tip" message during synthesis. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.annotateGenerated">annotateGenerated</a></code> | Marks the provided file(s) as being generated. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.postSynthesize">postSynthesize</a></code> | Called after all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.preSynthesize">preSynthesize</a></code> | Called before all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeTask">removeTask</a></code> | Removes a task from a project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.runTaskCommand">runTaskCommand</a></code> | Returns the shell command to execute in order to run a task. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.synth">synth</a></code> | Synthesize all project files into `outdir`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindFile">tryFindFile</a></code> | Finds a file at the specified relative path within this project and all its subprojects. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindJsonFile">tryFindJsonFile</a></code> | Finds a json file by name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindObjectFile">tryFindObjectFile</a></code> | Finds an object file (like JsonFile, YamlFile, etc.) by name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryRemoveFile">tryRemoveFile</a></code> | Finds a file at the specified relative path within this project and removes it. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBins">addBins</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBundledDeps">addBundledDeps</a></code> | Defines bundled dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addCompileCommand">addCompileCommand</a></code> | DEPRECATED. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDeps">addDeps</a></code> | Defines normal dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDevDeps">addDevDeps</a></code> | Defines development/test dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addFields">addFields</a></code> | Directly set fields in `package.json`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addKeywords">addKeywords</a></code> | Adds keywords to package.json (deduplicated). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPeerDeps">addPeerDeps</a></code> | Defines peer dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addScripts">addScripts</a></code> | Replaces the contents of multiple npm package.json scripts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTestCommand">addTestCommand</a></code> | DEPRECATED. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.hasScript">hasScript</a></code> | Indicates if a script by the name name is defined. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeScript">removeScript</a></code> | Removes the npm script (always successful). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.renderWorkflowSetup">renderWorkflowSetup</a></code> | Returns the set of workflow steps which should be executed to bootstrap a workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.setScript">setScript</a></code> | Replaces the contents of an npm package.json script. |

---

##### `addExcludeFromCleanup` <a name="addExcludeFromCleanup" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addExcludeFromCleanup"></a>

```java
public void addExcludeFromCleanup(java.lang.String globs)
```

Exclude the matching files from pre-synth cleanup.

Can be used when, for example, some
source files include the projen marker and we don't want them to be erased during synth.

###### `globs`<sup>Required</sup> <a name="globs" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addExcludeFromCleanup.parameter.globs"></a>

- *Type:* java.lang.String

The glob patterns to match.

---

##### `addGitIgnore` <a name="addGitIgnore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addGitIgnore"></a>

```java
public void addGitIgnore(java.lang.String pattern)
```

Adds a .gitignore pattern.

###### `pattern`<sup>Required</sup> <a name="pattern" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addGitIgnore.parameter.pattern"></a>

- *Type:* java.lang.String

The glob pattern to ignore.

---

##### `addPackageIgnore` <a name="addPackageIgnore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPackageIgnore"></a>

```java
public void addPackageIgnore(java.lang.String pattern)
```

Exclude these files from the bundled package.

Implemented by project types based on the
packaging mechanism. For example, `NodeProject` delegates this to `.npmignore`.

###### `pattern`<sup>Required</sup> <a name="pattern" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPackageIgnore.parameter.pattern"></a>

- *Type:* java.lang.String

---

##### `addTask` <a name="addTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask"></a>

```java
public Task addTask(java.lang.String name)
public Task addTask(java.lang.String name, TaskOptions props)
```

Adds a new task to this project.

This will fail if the project already has
a task with this name.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.name"></a>

- *Type:* java.lang.String

The task name to add.

---

###### `props`<sup>Optional</sup> <a name="props" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.props"></a>

- *Type:* io.github.cdklabs.projen.TaskOptions

Task properties.

---

##### ~~`addTip`~~ <a name="addTip" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTip"></a>

```java
public void addTip(java.lang.String message)
```

Prints a "tip" message during synthesis.

###### `message`<sup>Required</sup> <a name="message" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTip.parameter.message"></a>

- *Type:* java.lang.String

The message.

---

##### `annotateGenerated` <a name="annotateGenerated" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.annotateGenerated"></a>

```java
public void annotateGenerated(java.lang.String glob)
```

Marks the provided file(s) as being generated.

This is achieved using the
github-linguist attributes. Generated files do not count against the
repository statistics and language breakdown.

> [https://github.com/github/linguist/blob/master/docs/overrides.md](https://github.com/github/linguist/blob/master/docs/overrides.md)

###### `glob`<sup>Required</sup> <a name="glob" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.annotateGenerated.parameter.glob"></a>

- *Type:* java.lang.String

the glob pattern to match (could be a file path).

---

##### `postSynthesize` <a name="postSynthesize" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.postSynthesize"></a>

```java
public void postSynthesize()
```

Called after all components are synthesized.

Order is *not* guaranteed.

##### `preSynthesize` <a name="preSynthesize" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.preSynthesize"></a>

```java
public void preSynthesize()
```

Called before all components are synthesized.

##### `removeTask` <a name="removeTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeTask"></a>

```java
public Task removeTask(java.lang.String name)
```

Removes a task from a project.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeTask.parameter.name"></a>

- *Type:* java.lang.String

The name of the task to remove.

---

##### `runTaskCommand` <a name="runTaskCommand" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.runTaskCommand"></a>

```java
public java.lang.String runTaskCommand(Task task)
```

Returns the shell command to execute in order to run a task.

This will
typically be `npx projen TASK`.

###### `task`<sup>Required</sup> <a name="task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.runTaskCommand.parameter.task"></a>

- *Type:* io.github.cdklabs.projen.Task

The task for which the command is required.

---

##### `synth` <a name="synth" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.synth"></a>

```java
public void synth()
```

Synthesize all project files into `outdir`.

1. Call "this.preSynthesize()"
2. Delete all generated files
3. Synthesize all sub-projects
4. Synthesize all components of this project
5. Call "postSynthesize()" for all components of this project
6. Call "this.postSynthesize()"

##### `tryFindFile` <a name="tryFindFile" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindFile"></a>

```java
public FileBase tryFindFile(java.lang.String filePath)
```

Finds a file at the specified relative path within this project and all its subprojects.

###### `filePath`<sup>Required</sup> <a name="filePath" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindFile.parameter.filePath"></a>

- *Type:* java.lang.String

The file path.

If this path is relative, it will be resolved
from the root of _this_ project.

---

##### ~~`tryFindJsonFile`~~ <a name="tryFindJsonFile" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindJsonFile"></a>

```java
public JsonFile tryFindJsonFile(java.lang.String filePath)
```

Finds a json file by name.

###### `filePath`<sup>Required</sup> <a name="filePath" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindJsonFile.parameter.filePath"></a>

- *Type:* java.lang.String

The file path.

---

##### `tryFindObjectFile` <a name="tryFindObjectFile" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindObjectFile"></a>

```java
public ObjectFile tryFindObjectFile(java.lang.String filePath)
```

Finds an object file (like JsonFile, YamlFile, etc.) by name.

###### `filePath`<sup>Required</sup> <a name="filePath" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindObjectFile.parameter.filePath"></a>

- *Type:* java.lang.String

The file path.

---

##### `tryRemoveFile` <a name="tryRemoveFile" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryRemoveFile"></a>

```java
public FileBase tryRemoveFile(java.lang.String filePath)
```

Finds a file at the specified relative path within this project and removes it.

###### `filePath`<sup>Required</sup> <a name="filePath" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryRemoveFile.parameter.filePath"></a>

- *Type:* java.lang.String

The file path.

If this path is relative, it will be
resolved from the root of _this_ project.

---

##### `addBins` <a name="addBins" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBins"></a>

```java
public void addBins(java.util.Map<java.lang.String, java.lang.String> bins)
```

###### `bins`<sup>Required</sup> <a name="bins" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBins.parameter.bins"></a>

- *Type:* java.util.Map<java.lang.String, java.lang.String>

---

##### `addBundledDeps` <a name="addBundledDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBundledDeps"></a>

```java
public void addBundledDeps(java.lang.String deps)
```

Defines bundled dependencies.

Bundled dependencies will be added as normal dependencies as well as to the
`bundledDependencies` section of your `package.json`.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBundledDeps.parameter.deps"></a>

- *Type:* java.lang.String

Names modules to install.

By default, the the dependency will
be installed in the next `npx projen` run and the version will be recorded
in your `package.json` file. You can upgrade manually or using `yarn
add/upgrade`. If you wish to specify a version range use this syntax:
`module@^7`.

---

##### ~~`addCompileCommand`~~ <a name="addCompileCommand" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addCompileCommand"></a>

```java
public void addCompileCommand(java.lang.String commands)
```

DEPRECATED.

###### `commands`<sup>Required</sup> <a name="commands" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addCompileCommand.parameter.commands"></a>

- *Type:* java.lang.String

---

##### `addDeps` <a name="addDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDeps"></a>

```java
public void addDeps(java.lang.String deps)
```

Defines normal dependencies.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDeps.parameter.deps"></a>

- *Type:* java.lang.String

Names modules to install.

By default, the the dependency will
be installed in the next `npx projen` run and the version will be recorded
in your `package.json` file. You can upgrade manually or using `yarn
add/upgrade`. If you wish to specify a version range use this syntax:
`module@^7`.

---

##### `addDevDeps` <a name="addDevDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDevDeps"></a>

```java
public void addDevDeps(java.lang.String deps)
```

Defines development/test dependencies.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDevDeps.parameter.deps"></a>

- *Type:* java.lang.String

Names modules to install.

By default, the the dependency will
be installed in the next `npx projen` run and the version will be recorded
in your `package.json` file. You can upgrade manually or using `yarn
add/upgrade`. If you wish to specify a version range use this syntax:
`module@^7`.

---

##### `addFields` <a name="addFields" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addFields"></a>

```java
public void addFields(java.util.Map<java.lang.String, java.lang.Object> fields)
```

Directly set fields in `package.json`.

###### `fields`<sup>Required</sup> <a name="fields" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addFields.parameter.fields"></a>

- *Type:* java.util.Map<java.lang.String, java.lang.Object>

The fields to set.

---

##### `addKeywords` <a name="addKeywords" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addKeywords"></a>

```java
public void addKeywords(java.lang.String keywords)
```

Adds keywords to package.json (deduplicated).

###### `keywords`<sup>Required</sup> <a name="keywords" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addKeywords.parameter.keywords"></a>

- *Type:* java.lang.String

The keywords to add.

---

##### `addPeerDeps` <a name="addPeerDeps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPeerDeps"></a>

```java
public void addPeerDeps(java.lang.String deps)
```

Defines peer dependencies.

When adding peer dependencies, a devDependency will also be added on the
pinned version of the declared peer. This will ensure that you are testing
your code against the minimum version required from your consumers.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPeerDeps.parameter.deps"></a>

- *Type:* java.lang.String

Names modules to install.

By default, the the dependency will
be installed in the next `npx projen` run and the version will be recorded
in your `package.json` file. You can upgrade manually or using `yarn
add/upgrade`. If you wish to specify a version range use this syntax:
`module@^7`.

---

##### `addScripts` <a name="addScripts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addScripts"></a>

```java
public void addScripts(java.util.Map<java.lang.String, java.lang.String> scripts)
```

Replaces the contents of multiple npm package.json scripts.

###### `scripts`<sup>Required</sup> <a name="scripts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addScripts.parameter.scripts"></a>

- *Type:* java.util.Map<java.lang.String, java.lang.String>

The scripts to set.

---

##### ~~`addTestCommand`~~ <a name="addTestCommand" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTestCommand"></a>

```java
public void addTestCommand(java.lang.String commands)
```

DEPRECATED.

###### `commands`<sup>Required</sup> <a name="commands" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTestCommand.parameter.commands"></a>

- *Type:* java.lang.String

---

##### `hasScript` <a name="hasScript" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.hasScript"></a>

```java
public java.lang.Boolean hasScript(java.lang.String name)
```

Indicates if a script by the name name is defined.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.hasScript.parameter.name"></a>

- *Type:* java.lang.String

The name of the script.

---

##### `removeScript` <a name="removeScript" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeScript"></a>

```java
public void removeScript(java.lang.String name)
```

Removes the npm script (always successful).

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeScript.parameter.name"></a>

- *Type:* java.lang.String

The name of the script.

---

##### `renderWorkflowSetup` <a name="renderWorkflowSetup" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.renderWorkflowSetup"></a>

```java
public java.util.List<JobStep> renderWorkflowSetup()
public java.util.List<JobStep> renderWorkflowSetup(RenderWorkflowSetupOptions options)
```

Returns the set of workflow steps which should be executed to bootstrap a workflow.

###### `options`<sup>Optional</sup> <a name="options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.renderWorkflowSetup.parameter.options"></a>

- *Type:* io.github.cdklabs.projen.javascript.RenderWorkflowSetupOptions

Options.

---

##### `setScript` <a name="setScript" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.setScript"></a>

```java
public void setScript(java.lang.String name, java.lang.String command)
```

Replaces the contents of an npm package.json script.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.setScript.parameter.name"></a>

- *Type:* java.lang.String

The script name.

---

###### `command`<sup>Required</sup> <a name="command" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.setScript.parameter.command"></a>

- *Type:* java.lang.String

The command to execute.

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildTask">buildTask</a></code> | <code>io.github.cdklabs.projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.commitGenerated">commitGenerated</a></code> | <code>java.lang.Boolean</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.compileTask">compileTask</a></code> | <code>io.github.cdklabs.projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.components">components</a></code> | <code>java.util.List<io.github.cdklabs.projen.Component></code> | Returns all the components within this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.deps">deps</a></code> | <code>io.github.cdklabs.projen.Dependencies</code> | Project dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.ejected">ejected</a></code> | <code>java.lang.Boolean</code> | Whether or not the project is being ejected. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.files">files</a></code> | <code>java.util.List<io.github.cdklabs.projen.FileBase></code> | All files in this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitattributes">gitattributes</a></code> | <code>io.github.cdklabs.projen.GitAttributesFile</code> | The .gitattributes file for this repository. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitignore">gitignore</a></code> | <code>io.github.cdklabs.projen.IgnoreFile</code> | .gitignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.logger">logger</a></code> | <code>io.github.cdklabs.projen.Logger</code> | Logging utilities. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.name">name</a></code> | <code>java.lang.String</code> | Project name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.outdir">outdir</a></code> | <code>java.lang.String</code> | Absolute output directory of this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.packageTask">packageTask</a></code> | <code>io.github.cdklabs.projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.postCompileTask">postCompileTask</a></code> | <code>io.github.cdklabs.projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.preCompileTask">preCompileTask</a></code> | <code>io.github.cdklabs.projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projectBuild">projectBuild</a></code> | <code>io.github.cdklabs.projen.ProjectBuild</code> | Manages the build process of the project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projenCommand">projenCommand</a></code> | <code>java.lang.String</code> | The command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.root">root</a></code> | <code>io.github.cdklabs.projen.Project</code> | The root project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tasks">tasks</a></code> | <code>io.github.cdklabs.projen.Tasks</code> | Project tasks. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.testTask">testTask</a></code> | <code>io.github.cdklabs.projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.defaultTask">defaultTask</a></code> | <code>io.github.cdklabs.projen.Task</code> | This is the "default" task, the one that executes "projen". |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.initProject">initProject</a></code> | <code>io.github.cdklabs.projen.InitProject</code> | The options used when this project is bootstrapped via `projen new`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.parent">parent</a></code> | <code>io.github.cdklabs.projen.Project</code> | A parent project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projectType">projectType</a></code> | <code>io.github.cdklabs.projen.ProjectType</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.autoApprove">autoApprove</a></code> | <code>io.github.cdklabs.projen.github.AutoApprove</code> | Auto approve set up for this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.devContainer">devContainer</a></code> | <code>io.github.cdklabs.projen.vscode.DevContainer</code> | Access for .devcontainer.json (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.github">github</a></code> | <code>io.github.cdklabs.projen.github.GitHub</code> | Access all github components. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitpod">gitpod</a></code> | <code>io.github.cdklabs.projen.Gitpod</code> | Access for Gitpod. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.vscode">vscode</a></code> | <code>io.github.cdklabs.projen.vscode.VsCode</code> | Access all VSCode components. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.allowLibraryDependencies">allowLibraryDependencies</a></code> | <code>java.lang.Boolean</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.artifactsDirectory">artifactsDirectory</a></code> | <code>java.lang.String</code> | The build output directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.artifactsJavascriptDirectory">artifactsJavascriptDirectory</a></code> | <code>java.lang.String</code> | The location of the npm tarball after build (`${artifactsDirectory}/js`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.bundler">bundler</a></code> | <code>io.github.cdklabs.projen.javascript.Bundler</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.entrypoint">entrypoint</a></code> | <code>java.lang.String</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.manifest">manifest</a></code> | <code>java.lang.Object</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.package">package</a></code> | <code>io.github.cdklabs.projen.javascript.NodePackage</code> | API for managing the node package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.packageManager">packageManager</a></code> | <code>io.github.cdklabs.projen.javascript.NodePackageManager</code> | The package manager to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.runScriptCommand">runScriptCommand</a></code> | <code>java.lang.String</code> | The command to use to run scripts (e.g. `yarn run` or `npm run` depends on the package manager). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.autoMerge">autoMerge</a></code> | <code>io.github.cdklabs.projen.github.AutoMerge</code> | Component that sets up mergify for merging approved pull requests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildWorkflow">buildWorkflow</a></code> | <code>io.github.cdklabs.projen.build.BuildWorkflow</code> | The PR build GitHub workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildWorkflowJobId">buildWorkflowJobId</a></code> | <code>java.lang.String</code> | The job ID of the build workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.jest">jest</a></code> | <code>io.github.cdklabs.projen.javascript.Jest</code> | The Jest configuration (if enabled). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.maxNodeVersion">maxNodeVersion</a></code> | <code>java.lang.String</code> | Maximum node version required by this package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.minNodeVersion">minNodeVersion</a></code> | <code>java.lang.String</code> | Minimum node.js version required by this package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.npmignore">npmignore</a></code> | <code>io.github.cdklabs.projen.IgnoreFile</code> | The .npmignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.prettier">prettier</a></code> | <code>io.github.cdklabs.projen.javascript.Prettier</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.publisher">publisher</a></code> | <code>io.github.cdklabs.projen.release.Publisher</code> | Package publisher. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.release">release</a></code> | <code>io.github.cdklabs.projen.release.Release</code> | Release management. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.upgradeWorkflow">upgradeWorkflow</a></code> | <code>io.github.cdklabs.projen.javascript.UpgradeDependencies</code> | The upgrade workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.docsDirectory">docsDirectory</a></code> | <code>java.lang.String</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.libdir">libdir</a></code> | <code>java.lang.String</code> | The directory in which compiled .js files reside. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.srcdir">srcdir</a></code> | <code>java.lang.String</code> | The directory in which source files reside. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.testdir">testdir</a></code> | <code>java.lang.String</code> | The directory in which tests reside. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfigDev">tsconfigDev</a></code> | <code>io.github.cdklabs.projen.javascript.TypescriptConfig</code> | A typescript configuration file which covers all files (sources, tests, projen). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.watchTask">watchTask</a></code> | <code>io.github.cdklabs.projen.Task</code> | The "watch" task. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.docgen">docgen</a></code> | <code>java.lang.Boolean</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.eslint">eslint</a></code> | <code>io.github.cdklabs.projen.javascript.Eslint</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfig">tsconfig</a></code> | <code>io.github.cdklabs.projen.javascript.TypescriptConfig</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfigEslint">tsconfigEslint</a></code> | <code>io.github.cdklabs.projen.javascript.TypescriptConfig</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.applicationName">applicationName</a></code> | <code>java.lang.String</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.publicDir">publicDir</a></code> | <code>java.lang.String</code> | *No description.* |

---

##### `buildTask`<sup>Required</sup> <a name="buildTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildTask"></a>

```java
public Task getBuildTask();
```

- *Type:* io.github.cdklabs.projen.Task

---

##### `commitGenerated`<sup>Required</sup> <a name="commitGenerated" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.commitGenerated"></a>

```java
public java.lang.Boolean getCommitGenerated();
```

- *Type:* java.lang.Boolean

Whether to commit the managed files by default.

---

##### `compileTask`<sup>Required</sup> <a name="compileTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.compileTask"></a>

```java
public Task getCompileTask();
```

- *Type:* io.github.cdklabs.projen.Task

---

##### `components`<sup>Required</sup> <a name="components" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.components"></a>

```java
public java.util.List<Component> getComponents();
```

- *Type:* java.util.List<io.github.cdklabs.projen.Component>

Returns all the components within this project.

---

##### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.deps"></a>

```java
public Dependencies getDeps();
```

- *Type:* io.github.cdklabs.projen.Dependencies

Project dependencies.

---

##### `ejected`<sup>Required</sup> <a name="ejected" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.ejected"></a>

```java
public java.lang.Boolean getEjected();
```

- *Type:* java.lang.Boolean

Whether or not the project is being ejected.

---

##### `files`<sup>Required</sup> <a name="files" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.files"></a>

```java
public java.util.List<FileBase> getFiles();
```

- *Type:* java.util.List<io.github.cdklabs.projen.FileBase>

All files in this project.

---

##### `gitattributes`<sup>Required</sup> <a name="gitattributes" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitattributes"></a>

```java
public GitAttributesFile getGitattributes();
```

- *Type:* io.github.cdklabs.projen.GitAttributesFile

The .gitattributes file for this repository.

---

##### `gitignore`<sup>Required</sup> <a name="gitignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitignore"></a>

```java
public IgnoreFile getGitignore();
```

- *Type:* io.github.cdklabs.projen.IgnoreFile

.gitignore.

---

##### `logger`<sup>Required</sup> <a name="logger" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.logger"></a>

```java
public Logger getLogger();
```

- *Type:* io.github.cdklabs.projen.Logger

Logging utilities.

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.name"></a>

```java
public java.lang.String getName();
```

- *Type:* java.lang.String

Project name.

---

##### `outdir`<sup>Required</sup> <a name="outdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.outdir"></a>

```java
public java.lang.String getOutdir();
```

- *Type:* java.lang.String

Absolute output directory of this project.

---

##### `packageTask`<sup>Required</sup> <a name="packageTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.packageTask"></a>

```java
public Task getPackageTask();
```

- *Type:* io.github.cdklabs.projen.Task

---

##### `postCompileTask`<sup>Required</sup> <a name="postCompileTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.postCompileTask"></a>

```java
public Task getPostCompileTask();
```

- *Type:* io.github.cdklabs.projen.Task

---

##### `preCompileTask`<sup>Required</sup> <a name="preCompileTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.preCompileTask"></a>

```java
public Task getPreCompileTask();
```

- *Type:* io.github.cdklabs.projen.Task

---

##### `projectBuild`<sup>Required</sup> <a name="projectBuild" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projectBuild"></a>

```java
public ProjectBuild getProjectBuild();
```

- *Type:* io.github.cdklabs.projen.ProjectBuild

Manages the build process of the project.

---

##### `projenCommand`<sup>Required</sup> <a name="projenCommand" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projenCommand"></a>

```java
public java.lang.String getProjenCommand();
```

- *Type:* java.lang.String

The command to use in order to run the projen CLI.

---

##### `root`<sup>Required</sup> <a name="root" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.root"></a>

```java
public Project getRoot();
```

- *Type:* io.github.cdklabs.projen.Project

The root project.

---

##### `tasks`<sup>Required</sup> <a name="tasks" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tasks"></a>

```java
public Tasks getTasks();
```

- *Type:* io.github.cdklabs.projen.Tasks

Project tasks.

---

##### `testTask`<sup>Required</sup> <a name="testTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.testTask"></a>

```java
public Task getTestTask();
```

- *Type:* io.github.cdklabs.projen.Task

---

##### `defaultTask`<sup>Optional</sup> <a name="defaultTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.defaultTask"></a>

```java
public Task getDefaultTask();
```

- *Type:* io.github.cdklabs.projen.Task

This is the "default" task, the one that executes "projen".

Undefined if
the project is being ejected.

---

##### `initProject`<sup>Optional</sup> <a name="initProject" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.initProject"></a>

```java
public InitProject getInitProject();
```

- *Type:* io.github.cdklabs.projen.InitProject

The options used when this project is bootstrapped via `projen new`.

It
includes the original set of options passed to the CLI and also the JSII
FQN of the project type.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.parent"></a>

```java
public Project getParent();
```

- *Type:* io.github.cdklabs.projen.Project

A parent project.

If undefined, this is the root project.

---

##### `projectType`<sup>Required</sup> <a name="projectType" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projectType"></a>

```java
public ProjectType getProjectType();
```

- *Type:* io.github.cdklabs.projen.ProjectType

---

##### `autoApprove`<sup>Optional</sup> <a name="autoApprove" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.autoApprove"></a>

```java
public AutoApprove getAutoApprove();
```

- *Type:* io.github.cdklabs.projen.github.AutoApprove

Auto approve set up for this project.

---

##### `devContainer`<sup>Optional</sup> <a name="devContainer" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.devContainer"></a>

```java
public DevContainer getDevContainer();
```

- *Type:* io.github.cdklabs.projen.vscode.DevContainer

Access for .devcontainer.json (used for GitHub Codespaces).

This will be `undefined` if devContainer boolean is false

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.github"></a>

```java
public GitHub getGithub();
```

- *Type:* io.github.cdklabs.projen.github.GitHub

Access all github components.

This will be `undefined` for subprojects.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitpod"></a>

```java
public Gitpod getGitpod();
```

- *Type:* io.github.cdklabs.projen.Gitpod

Access for Gitpod.

This will be `undefined` if gitpod boolean is false

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.vscode"></a>

```java
public VsCode getVscode();
```

- *Type:* io.github.cdklabs.projen.vscode.VsCode

Access all VSCode components.

This will be `undefined` for subprojects.

---

##### ~~`allowLibraryDependencies`~~<sup>Required</sup> <a name="allowLibraryDependencies" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.allowLibraryDependencies"></a>

- *Deprecated:* use `package.allowLibraryDependencies`

```java
public java.lang.Boolean getAllowLibraryDependencies();
```

- *Type:* java.lang.Boolean

---

##### `artifactsDirectory`<sup>Required</sup> <a name="artifactsDirectory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.artifactsDirectory"></a>

```java
public java.lang.String getArtifactsDirectory();
```

- *Type:* java.lang.String

The build output directory.

An npm tarball will be created under the `js`
subdirectory. For example, if this is set to `dist` (the default), the npm
tarball will be placed under `dist/js/boom-boom-1.2.3.tg`.

---

##### `artifactsJavascriptDirectory`<sup>Required</sup> <a name="artifactsJavascriptDirectory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.artifactsJavascriptDirectory"></a>

```java
public java.lang.String getArtifactsJavascriptDirectory();
```

- *Type:* java.lang.String

The location of the npm tarball after build (`${artifactsDirectory}/js`).

---

##### `bundler`<sup>Required</sup> <a name="bundler" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.bundler"></a>

```java
public Bundler getBundler();
```

- *Type:* io.github.cdklabs.projen.javascript.Bundler

---

##### ~~`entrypoint`~~<sup>Required</sup> <a name="entrypoint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.entrypoint"></a>

- *Deprecated:* use `package.entrypoint`

```java
public java.lang.String getEntrypoint();
```

- *Type:* java.lang.String

---

##### ~~`manifest`~~<sup>Required</sup> <a name="manifest" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.manifest"></a>

- *Deprecated:* use `package.addField(x, y)`

```java
public java.lang.Object getManifest();
```

- *Type:* java.lang.Object

---

##### `package`<sup>Required</sup> <a name="package" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.package"></a>

```java
public NodePackage getPackage();
```

- *Type:* io.github.cdklabs.projen.javascript.NodePackage

API for managing the node package.

---

##### ~~`packageManager`~~<sup>Required</sup> <a name="packageManager" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.packageManager"></a>

- *Deprecated:* use `package.packageManager`

```java
public NodePackageManager getPackageManager();
```

- *Type:* io.github.cdklabs.projen.javascript.NodePackageManager

The package manager to use.

---

##### `runScriptCommand`<sup>Required</sup> <a name="runScriptCommand" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.runScriptCommand"></a>

```java
public java.lang.String getRunScriptCommand();
```

- *Type:* java.lang.String

The command to use to run scripts (e.g. `yarn run` or `npm run` depends on the package manager).

---

##### `autoMerge`<sup>Optional</sup> <a name="autoMerge" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.autoMerge"></a>

```java
public AutoMerge getAutoMerge();
```

- *Type:* io.github.cdklabs.projen.github.AutoMerge

Component that sets up mergify for merging approved pull requests.

---

##### `buildWorkflow`<sup>Optional</sup> <a name="buildWorkflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildWorkflow"></a>

```java
public BuildWorkflow getBuildWorkflow();
```

- *Type:* io.github.cdklabs.projen.build.BuildWorkflow

The PR build GitHub workflow.

`undefined` if `buildWorkflow` is disabled.

---

##### `buildWorkflowJobId`<sup>Optional</sup> <a name="buildWorkflowJobId" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildWorkflowJobId"></a>

```java
public java.lang.String getBuildWorkflowJobId();
```

- *Type:* java.lang.String

The job ID of the build workflow.

---

##### `jest`<sup>Optional</sup> <a name="jest" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.jest"></a>

```java
public Jest getJest();
```

- *Type:* io.github.cdklabs.projen.javascript.Jest

The Jest configuration (if enabled).

---

##### `maxNodeVersion`<sup>Optional</sup> <a name="maxNodeVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.maxNodeVersion"></a>

```java
public java.lang.String getMaxNodeVersion();
```

- *Type:* java.lang.String

Maximum node version required by this package.

---

##### `minNodeVersion`<sup>Optional</sup> <a name="minNodeVersion" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.minNodeVersion"></a>

```java
public java.lang.String getMinNodeVersion();
```

- *Type:* java.lang.String

Minimum node.js version required by this package.

---

##### `npmignore`<sup>Optional</sup> <a name="npmignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.npmignore"></a>

```java
public IgnoreFile getNpmignore();
```

- *Type:* io.github.cdklabs.projen.IgnoreFile

The .npmignore file.

---

##### `prettier`<sup>Optional</sup> <a name="prettier" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.prettier"></a>

```java
public Prettier getPrettier();
```

- *Type:* io.github.cdklabs.projen.javascript.Prettier

---

##### ~~`publisher`~~<sup>Optional</sup> <a name="publisher" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.publisher"></a>

- *Deprecated:* use `release.publisher`.

```java
public Publisher getPublisher();
```

- *Type:* io.github.cdklabs.projen.release.Publisher

Package publisher.

This will be `undefined` if the project does not have a
release workflow.

---

##### `release`<sup>Optional</sup> <a name="release" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.release"></a>

```java
public Release getRelease();
```

- *Type:* io.github.cdklabs.projen.release.Release

Release management.

---

##### `upgradeWorkflow`<sup>Optional</sup> <a name="upgradeWorkflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.upgradeWorkflow"></a>

```java
public UpgradeDependencies getUpgradeWorkflow();
```

- *Type:* io.github.cdklabs.projen.javascript.UpgradeDependencies

The upgrade workflow.

---

##### `docsDirectory`<sup>Required</sup> <a name="docsDirectory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.docsDirectory"></a>

```java
public java.lang.String getDocsDirectory();
```

- *Type:* java.lang.String

---

##### `libdir`<sup>Required</sup> <a name="libdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.libdir"></a>

```java
public java.lang.String getLibdir();
```

- *Type:* java.lang.String

The directory in which compiled .js files reside.

---

##### `srcdir`<sup>Required</sup> <a name="srcdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.srcdir"></a>

```java
public java.lang.String getSrcdir();
```

- *Type:* java.lang.String

The directory in which source files reside.

---

##### `testdir`<sup>Required</sup> <a name="testdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.testdir"></a>

```java
public java.lang.String getTestdir();
```

- *Type:* java.lang.String

The directory in which tests reside.

---

##### `tsconfigDev`<sup>Required</sup> <a name="tsconfigDev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfigDev"></a>

```java
public TypescriptConfig getTsconfigDev();
```

- *Type:* io.github.cdklabs.projen.javascript.TypescriptConfig

A typescript configuration file which covers all files (sources, tests, projen).

---

##### `watchTask`<sup>Required</sup> <a name="watchTask" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.watchTask"></a>

```java
public Task getWatchTask();
```

- *Type:* io.github.cdklabs.projen.Task

The "watch" task.

---

##### `docgen`<sup>Optional</sup> <a name="docgen" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.docgen"></a>

```java
public java.lang.Boolean getDocgen();
```

- *Type:* java.lang.Boolean

---

##### `eslint`<sup>Optional</sup> <a name="eslint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.eslint"></a>

```java
public Eslint getEslint();
```

- *Type:* io.github.cdklabs.projen.javascript.Eslint

---

##### `tsconfig`<sup>Optional</sup> <a name="tsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfig"></a>

```java
public TypescriptConfig getTsconfig();
```

- *Type:* io.github.cdklabs.projen.javascript.TypescriptConfig

---

##### `tsconfigEslint`<sup>Optional</sup> <a name="tsconfigEslint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfigEslint"></a>

```java
public TypescriptConfig getTsconfigEslint();
```

- *Type:* io.github.cdklabs.projen.javascript.TypescriptConfig

---

##### `applicationName`<sup>Required</sup> <a name="applicationName" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.applicationName"></a>

```java
public java.lang.String getApplicationName();
```

- *Type:* java.lang.String

---

##### `publicDir`<sup>Required</sup> <a name="publicDir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.publicDir"></a>

```java
public java.lang.String getPublicDir();
```

- *Type:* java.lang.String

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.DEFAULT_TASK">DEFAULT_TASK</a></code> | <code>java.lang.String</code> | The name of the default task (the task executed when `projen` is run without arguments). |

---

##### `DEFAULT_TASK`<sup>Required</sup> <a name="DEFAULT_TASK" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.DEFAULT_TASK"></a>

```java
public java.lang.String getDefaultTask();
```

- *Type:* java.lang.String

The name of the default task (the task executed when `projen` is run without arguments).

Normally
this task should synthesize the project files.

---


