## Getting started

To create a new [Cloudscape](https://cloudscape.design/) React Typescript Project, there are a couple of options:

### Via Projen CLI

```
npx projen new --from @aws-prototyping-sdk/cloudscape-react-ts-website cloudscape-react-ts-website [--application-name <your-app>]
```

### Programmatically

```python
# Example automatically generated from non-compiling source. May contain errors.
CloudscapeReactTsWebsiteProject(
    default_release_branch="mainline",
    name="<name-of-package>",
    application_name="<name-of-app>"
)
```

### Running your synthesized Application

To run your synthesized application locally, run `npx projen dev`.

## Developer Notes

To enable Cognito auth, ensure you have a runtime-config.json file in the root of your deployed project which at least contains the following:

```json
{
    "region": "<aws-region>",
    "identityPoolId":"<identity-pool-id>",
    "userPoolId":"<user-pool-id>",
    "userPoolWebClientId":"<user-pool-web-client-id>"
}
```

The easiest way to get this set up is to use the static-website + identity packages to deploy your website.

An example of how to do this is as follows:

```python
# Example automatically generated from non-compiling source. May contain errors.
user_identity = UserIdentity(self, "UserIdentity")
StaticWebsite(self, "StaticWebsite",
    website_content_path="<relative>/<path>/<to>/<built>/<website>",
    runtime_options={
        "json_payload": {
            "region": Stack.of(self).region,
            "identity_pool_id": user_identity.identity_pool.identity_pool_id,
            "user_pool_id": user_identity.user_pool.user_pool_id,
            "user_pool_web_client_id": user_identity.user_pool_client.user_pool_client_id
        }
    }
)
```

For local development, you will need to copy the generated runtime-config.json file into your /public directory. An example on how to do this is as follows:

```
curl https://dxxxxxxxxxx.cloudfront.net/runtime-config.json > public/runtime-config.json
```
# API Reference <a name="API Reference" id="api-reference"></a>


## Structs <a name="Structs" id="Structs"></a>

### CloudscapeReactTsWebsiteProjectOptions <a name="CloudscapeReactTsWebsiteProjectOptions" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions"></a>

Configuration options for the CloudscapeReactTsWebsiteProject.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.Initializer"></a>

```python
import aws_prototyping_sdk.cloudscape_react_ts_website

aws_prototyping_sdk.cloudscape_react_ts_website.CloudscapeReactTsWebsiteProjectOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  auto_approve_options: AutoApproveOptions = None,
  auto_merge: bool = None,
  auto_merge_options: AutoMergeOptions = None,
  clobber: bool = None,
  dev_container: bool = None,
  github: bool = None,
  github_options: GitHubOptions = None,
  gitpod: bool = None,
  mergify: bool = None,
  mergify_options: MergifyOptions = None,
  project_type: ProjectType = None,
  projen_credentials: GithubCredentials = None,
  projen_token_secret: str = None,
  readme: SampleReadmeProps = None,
  stale: bool = None,
  stale_options: StaleOptions = None,
  vscode: bool = None,
  allow_library_dependencies: bool = None,
  author_email: str = None,
  author_name: str = None,
  author_organization: bool = None,
  author_url: str = None,
  auto_detect_bin: bool = None,
  bin: typing.Mapping[str] = None,
  bugs_email: str = None,
  bugs_url: str = None,
  bundled_deps: typing.List[str] = None,
  code_artifact_options: CodeArtifactOptions = None,
  deps: typing.List[str] = None,
  description: str = None,
  dev_deps: typing.List[str] = None,
  entrypoint: str = None,
  homepage: str = None,
  keywords: typing.List[str] = None,
  license: str = None,
  licensed: bool = None,
  max_node_version: str = None,
  min_node_version: str = None,
  npm_access: NpmAccess = None,
  npm_registry: str = None,
  npm_registry_url: str = None,
  npm_token_secret: str = None,
  package_manager: NodePackageManager = None,
  package_name: str = None,
  peer_dependency_options: PeerDependencyOptions = None,
  peer_deps: typing.List[str] = None,
  pnpm_version: str = None,
  repository: str = None,
  repository_directory: str = None,
  scoped_packages_options: typing.List[ScopedPackagesOptions] = None,
  scripts: typing.Mapping[str] = None,
  stability: str = None,
  jsii_release_version: str = None,
  major_version: typing.Union[int, float] = None,
  min_major_version: typing.Union[int, float] = None,
  npm_dist_tag: str = None,
  post_build_steps: typing.List[JobStep] = None,
  prerelease: str = None,
  publish_dry_run: bool = None,
  publish_tasks: bool = None,
  release_branches: typing.Mapping[BranchOptions] = None,
  release_every_commit: bool = None,
  release_failure_issue: bool = None,
  release_failure_issue_label: str = None,
  release_schedule: str = None,
  release_tag_prefix: str = None,
  release_trigger: ReleaseTrigger = None,
  release_workflow_name: str = None,
  release_workflow_setup_steps: typing.List[JobStep] = None,
  versionrc_options: typing.Mapping[typing.Any] = None,
  workflow_container_image: str = None,
  workflow_runs_on: typing.List[str] = None,
  default_release_branch: str,
  artifacts_directory: str = None,
  auto_approve_upgrades: bool = None,
  build_workflow: bool = None,
  build_workflow_triggers: Triggers = None,
  bundler_options: BundlerOptions = None,
  code_cov: bool = None,
  code_cov_token_secret: str = None,
  copyright_owner: str = None,
  copyright_period: str = None,
  dependabot: bool = None,
  dependabot_options: DependabotOptions = None,
  deps_upgrade: bool = None,
  deps_upgrade_options: UpgradeDependenciesOptions = None,
  gitignore: typing.List[str] = None,
  jest: bool = None,
  jest_options: JestOptions = None,
  mutable_build: bool = None,
  npmignore: typing.List[str] = None,
  npmignore_enabled: bool = None,
  npm_ignore_options: IgnoreFileOptions = None,
  package: bool = None,
  prettier: bool = None,
  prettier_options: PrettierOptions = None,
  projen_dev_dependency: bool = None,
  projenrc_js: bool = None,
  projenrc_js_options: ProjenrcOptions = None,
  projen_version: str = None,
  pull_request_template: bool = None,
  pull_request_template_contents: typing.List[str] = None,
  release: bool = None,
  release_to_npm: bool = None,
  release_workflow: bool = None,
  workflow_bootstrap_steps: typing.List[JobStep] = None,
  workflow_git_identity: GitIdentity = None,
  workflow_node_version: str = None,
  disable_tsconfig: bool = None,
  disable_tsconfig_dev: bool = None,
  docgen: bool = None,
  docs_directory: str = None,
  entrypoint_types: str = None,
  eslint: bool = None,
  eslint_options: EslintOptions = None,
  libdir: str = None,
  projenrc_ts: bool = None,
  projenrc_ts_options: ProjenrcOptions = None,
  sample_code: bool = None,
  srcdir: str = None,
  testdir: str = None,
  tsconfig: TypescriptConfigOptions = None,
  tsconfig_dev: TypescriptConfigOptions = None,
  tsconfig_dev_file: str = None,
  typescript_version: str = None,
  rewire: typing.Mapping[typing.Any] = None,
  application_name: str = None,
  public_dir: str = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoApproveOptions">auto_approve_options</a></code> | <code>projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoMerge">auto_merge</a></code> | <code>bool</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoMergeOptions">auto_merge_options</a></code> | <code>projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.clobber">clobber</a></code> | <code>bool</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.devContainer">dev_container</a></code> | <code>bool</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.github">github</a></code> | <code>bool</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.githubOptions">github_options</a></code> | <code>projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitpod">gitpod</a></code> | <code>bool</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mergify">mergify</a></code> | <code>bool</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mergifyOptions">mergify_options</a></code> | <code>projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projectType">project_type</a></code> | <code>projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenCredentials">projen_credentials</a></code> | <code>projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenTokenSecret">projen_token_secret</a></code> | <code>str</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.readme">readme</a></code> | <code>projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.stale">stale</a></code> | <code>bool</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.staleOptions">stale_options</a></code> | <code>projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.vscode">vscode</a></code> | <code>bool</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.allowLibraryDependencies">allow_library_dependencies</a></code> | <code>bool</code> | Allow the project to include `peerDependencies` and `bundledDependencies`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorEmail">author_email</a></code> | <code>str</code> | Author's e-mail. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorName">author_name</a></code> | <code>str</code> | Author's name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorOrganization">author_organization</a></code> | <code>bool</code> | Is the author an organization. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorUrl">author_url</a></code> | <code>str</code> | Author's URL / Website. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoDetectBin">auto_detect_bin</a></code> | <code>bool</code> | Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bin">bin</a></code> | <code>typing.Mapping[str]</code> | Binary programs vended with your module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bugsEmail">bugs_email</a></code> | <code>str</code> | The email address to which issues should be reported. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bugsUrl">bugs_url</a></code> | <code>str</code> | The url to your project's issue tracker. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bundledDeps">bundled_deps</a></code> | <code>typing.List[str]</code> | List of dependencies to bundle into this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeArtifactOptions">code_artifact_options</a></code> | <code>projen.javascript.CodeArtifactOptions</code> | Options for npm packages using AWS CodeArtifact. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.deps">deps</a></code> | <code>typing.List[str]</code> | Runtime dependencies of this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.description">description</a></code> | <code>str</code> | The description is just a string that helps people understand the purpose of the package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.devDeps">dev_deps</a></code> | <code>typing.List[str]</code> | Build dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.entrypoint">entrypoint</a></code> | <code>str</code> | Module entrypoint (`main` in `package.json`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.homepage">homepage</a></code> | <code>str</code> | Package's Homepage / Website. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.keywords">keywords</a></code> | <code>typing.List[str]</code> | Keywords to include in `package.json`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.license">license</a></code> | <code>str</code> | License's SPDX identifier. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.licensed">licensed</a></code> | <code>bool</code> | Indicates if a license should be added. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.maxNodeVersion">max_node_version</a></code> | <code>str</code> | Minimum node.js version to require via `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.minNodeVersion">min_node_version</a></code> | <code>str</code> | Minimum Node.js version to require via package.json `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmAccess">npm_access</a></code> | <code>projen.javascript.NpmAccess</code> | Access level of the npm package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmRegistry">npm_registry</a></code> | <code>str</code> | The host name of the npm registry to publish to. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmRegistryUrl">npm_registry_url</a></code> | <code>str</code> | The base URL of the npm package registry. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmTokenSecret">npm_token_secret</a></code> | <code>str</code> | GitHub secret which contains the NPM token to use when publishing packages. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.packageManager">package_manager</a></code> | <code>projen.javascript.NodePackageManager</code> | The Node Package Manager used to execute scripts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.packageName">package_name</a></code> | <code>str</code> | The "name" in package.json. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.peerDependencyOptions">peer_dependency_options</a></code> | <code>projen.javascript.PeerDependencyOptions</code> | Options for `peerDeps`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.peerDeps">peer_deps</a></code> | <code>typing.List[str]</code> | Peer dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pnpmVersion">pnpm_version</a></code> | <code>str</code> | The version of PNPM to use if using PNPM as a package manager. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.repository">repository</a></code> | <code>str</code> | The repository is the location where the actual code for your package lives. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.repositoryDirectory">repository_directory</a></code> | <code>str</code> | If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.scopedPackagesOptions">scoped_packages_options</a></code> | <code>typing.List[projen.javascript.ScopedPackagesOptions]</code> | Options for privately hosted scoped packages. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.scripts">scripts</a></code> | <code>typing.Mapping[str]</code> | npm scripts to include. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.stability">stability</a></code> | <code>str</code> | Package's Stability. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jsiiReleaseVersion">jsii_release_version</a></code> | <code>str</code> | Version requirement of `publib` which is used to publish modules to npm. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.majorVersion">major_version</a></code> | <code>typing.Union[int, float]</code> | Major version to release from the default branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.minMajorVersion">min_major_version</a></code> | <code>typing.Union[int, float]</code> | Minimal Major version to release. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmDistTag">npm_dist_tag</a></code> | <code>str</code> | The npmDistTag to use when publishing from the default branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.postBuildSteps">post_build_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Steps to execute after build as part of the release workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prerelease">prerelease</a></code> | <code>str</code> | Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre"). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publishDryRun">publish_dry_run</a></code> | <code>bool</code> | Instead of actually publishing to package managers, just print the publishing command. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publishTasks">publish_tasks</a></code> | <code>bool</code> | Define publishing tasks that can be executed manually as well as workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseBranches">release_branches</a></code> | <code>typing.Mapping[projen.release.BranchOptions]</code> | Defines additional release branches. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseEveryCommit">release_every_commit</a></code> | <code>bool</code> | Automatically release new versions every commit to one of branches in `releaseBranches`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseFailureIssue">release_failure_issue</a></code> | <code>bool</code> | Create a github issue on every failed publishing task. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseFailureIssueLabel">release_failure_issue_label</a></code> | <code>str</code> | The label to apply to issues indicating publish failures. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseSchedule">release_schedule</a></code> | <code>str</code> | CRON schedule to trigger new releases. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseTagPrefix">release_tag_prefix</a></code> | <code>str</code> | Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseTrigger">release_trigger</a></code> | <code>projen.release.ReleaseTrigger</code> | The release trigger to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflowName">release_workflow_name</a></code> | <code>str</code> | The name of the default release workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflowSetupSteps">release_workflow_setup_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | A set of workflow steps to execute in order to setup the workflow container. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.versionrcOptions">versionrc_options</a></code> | <code>typing.Mapping[typing.Any]</code> | Custom configuration used when creating changelog with standard-version package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowContainerImage">workflow_container_image</a></code> | <code>str</code> | Container image to use for GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowRunsOn">workflow_runs_on</a></code> | <code>typing.List[str]</code> | Github Runner selection labels. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.defaultReleaseBranch">default_release_branch</a></code> | <code>str</code> | The name of the main release branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.artifactsDirectory">artifacts_directory</a></code> | <code>str</code> | A directory which will contain build artifacts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoApproveUpgrades">auto_approve_upgrades</a></code> | <code>bool</code> | Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.buildWorkflow">build_workflow</a></code> | <code>bool</code> | Define a GitHub workflow for building PRs. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.buildWorkflowTriggers">build_workflow_triggers</a></code> | <code>projen.github.workflows.Triggers</code> | Build workflow triggers. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bundlerOptions">bundler_options</a></code> | <code>projen.javascript.BundlerOptions</code> | Options for `Bundler`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeCov">code_cov</a></code> | <code>bool</code> | Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with @codeCovTokenSecret. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeCovTokenSecret">code_cov_token_secret</a></code> | <code>str</code> | Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.copyrightOwner">copyright_owner</a></code> | <code>str</code> | License copyright owner. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.copyrightPeriod">copyright_period</a></code> | <code>str</code> | The copyright years to put in the LICENSE file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.dependabot">dependabot</a></code> | <code>bool</code> | Use dependabot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.dependabotOptions">dependabot_options</a></code> | <code>projen.github.DependabotOptions</code> | Options for dependabot. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.depsUpgrade">deps_upgrade</a></code> | <code>bool</code> | Use github workflows to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.depsUpgradeOptions">deps_upgrade_options</a></code> | <code>projen.javascript.UpgradeDependenciesOptions</code> | Options for `UpgradeDependencies`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitignore">gitignore</a></code> | <code>typing.List[str]</code> | Additional entries to .gitignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jest">jest</a></code> | <code>bool</code> | Setup jest unit tests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jestOptions">jest_options</a></code> | <code>projen.javascript.JestOptions</code> | Jest options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mutableBuild">mutable_build</a></code> | <code>bool</code> | Automatically update files modified during builds to pull-request branches. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmignore">npmignore</a></code> | <code>typing.List[str]</code> | Additional entries to .npmignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmignoreEnabled">npmignore_enabled</a></code> | <code>bool</code> | Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmIgnoreOptions">npm_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .npmignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.package">package</a></code> | <code>bool</code> | Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prettier">prettier</a></code> | <code>bool</code> | Setup prettier. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prettierOptions">prettier_options</a></code> | <code>projen.javascript.PrettierOptions</code> | Prettier options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenDevDependency">projen_dev_dependency</a></code> | <code>bool</code> | Indicates of "projen" should be installed as a devDependency. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJs">projenrc_js</a></code> | <code>bool</code> | Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJsOptions">projenrc_js_options</a></code> | <code>projen.javascript.ProjenrcOptions</code> | Options for .projenrc.js. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenVersion">projen_version</a></code> | <code>str</code> | Version of projen to install. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pullRequestTemplate">pull_request_template</a></code> | <code>bool</code> | Include a GitHub pull request template. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pullRequestTemplateContents">pull_request_template_contents</a></code> | <code>typing.List[str]</code> | The contents of the pull request template. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.release">release</a></code> | <code>bool</code> | Add release management to this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseToNpm">release_to_npm</a></code> | <code>bool</code> | Automatically release to npm when new versions are introduced. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflow">release_workflow</a></code> | <code>bool</code> | DEPRECATED: renamed to `release`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowBootstrapSteps">workflow_bootstrap_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Workflow steps to use in order to bootstrap this repo. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowGitIdentity">workflow_git_identity</a></code> | <code>projen.github.GitIdentity</code> | The git identity to use in workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowNodeVersion">workflow_node_version</a></code> | <code>str</code> | The node version to use in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.disableTsconfig">disable_tsconfig</a></code> | <code>bool</code> | Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.disableTsconfigDev">disable_tsconfig_dev</a></code> | <code>bool</code> | Do not generate a `tsconfig.dev.json` file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.docgen">docgen</a></code> | <code>bool</code> | Docgen by Typedoc. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.docsDirectory">docs_directory</a></code> | <code>str</code> | Docs directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.entrypointTypes">entrypoint_types</a></code> | <code>str</code> | The .d.ts file that includes the type declarations for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.eslint">eslint</a></code> | <code>bool</code> | Setup eslint. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.eslintOptions">eslint_options</a></code> | <code>projen.javascript.EslintOptions</code> | Eslint options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.libdir">libdir</a></code> | <code>str</code> | Typescript  artifacts output directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcTs">projenrc_ts</a></code> | <code>bool</code> | Use TypeScript for your projenrc file (`.projenrc.ts`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcTsOptions">projenrc_ts_options</a></code> | <code>projen.typescript.ProjenrcOptions</code> | Options for .projenrc.ts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.sampleCode">sample_code</a></code> | <code>bool</code> | Generate one-time sample in `src/` and `test/` if there are no files there. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.srcdir">srcdir</a></code> | <code>str</code> | Typescript sources directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.testdir">testdir</a></code> | <code>str</code> | Jest tests directory. Tests files should be named `xxx.test.ts`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfig">tsconfig</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom TSConfig. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfigDev">tsconfig_dev</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom tsconfig options for the development tsconfig.json file (used for testing). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfigDevFile">tsconfig_dev_file</a></code> | <code>str</code> | The name of the development tsconfig.json file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.typescriptVersion">typescript_version</a></code> | <code>str</code> | TypeScript version to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.rewire">rewire</a></code> | <code>typing.Mapping[typing.Any]</code> | Rewire webpack configuration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.applicationName">application_name</a></code> | <code>str</code> | Name of the application name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publicDir">public_dir</a></code> | <code>str</code> | Public directory. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `auto_approve_options`<sup>Optional</sup> <a name="auto_approve_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoApproveOptions"></a>

```python
auto_approve_options: AutoApproveOptions
```

- *Type:* projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoMerge"></a>

```python
auto_merge: bool
```

- *Type:* bool
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `auto_merge_options`<sup>Optional</sup> <a name="auto_merge_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoMergeOptions"></a>

```python
auto_merge_options: AutoMergeOptions
```

- *Type:* projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.clobber"></a>

```python
clobber: bool
```

- *Type:* bool
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.devContainer"></a>

```python
dev_container: bool
```

- *Type:* bool
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.github"></a>

```python
github: bool
```

- *Type:* bool
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `github_options`<sup>Optional</sup> <a name="github_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.githubOptions"></a>

```python
github_options: GitHubOptions
```

- *Type:* projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitpod"></a>

```python
gitpod: bool
```

- *Type:* bool
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

```python
mergify: bool
```

- *Type:* bool
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergify_options`~~<sup>Optional</sup> <a name="mergify_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

```python
mergify_options: MergifyOptions
```

- *Type:* projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`project_type`~~<sup>Optional</sup> <a name="project_type" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projectType"></a>

- *Deprecated:* no longer supported at the base project level

```python
project_type: ProjectType
```

- *Type:* projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projen_credentials`<sup>Optional</sup> <a name="projen_credentials" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenCredentials"></a>

```python
projen_credentials: GithubCredentials
```

- *Type:* projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projen_token_secret`~~<sup>Optional</sup> <a name="projen_token_secret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

```python
projen_token_secret: str
```

- *Type:* str
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.readme"></a>

```python
readme: SampleReadmeProps
```

- *Type:* projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```python
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.stale"></a>

```python
stale: bool
```

- *Type:* bool
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `stale_options`<sup>Optional</sup> <a name="stale_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.staleOptions"></a>

```python
stale_options: StaleOptions
```

- *Type:* projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.vscode"></a>

```python
vscode: bool
```

- *Type:* bool
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `allow_library_dependencies`<sup>Optional</sup> <a name="allow_library_dependencies" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.allowLibraryDependencies"></a>

```python
allow_library_dependencies: bool
```

- *Type:* bool
- *Default:* true

Allow the project to include `peerDependencies` and `bundledDependencies`.

This is normally only allowed for libraries. For apps, there's no meaning
for specifying these.

---

##### `author_email`<sup>Optional</sup> <a name="author_email" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorEmail"></a>

```python
author_email: str
```

- *Type:* str

Author's e-mail.

---

##### `author_name`<sup>Optional</sup> <a name="author_name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorName"></a>

```python
author_name: str
```

- *Type:* str

Author's name.

---

##### `author_organization`<sup>Optional</sup> <a name="author_organization" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorOrganization"></a>

```python
author_organization: bool
```

- *Type:* bool

Is the author an organization.

---

##### `author_url`<sup>Optional</sup> <a name="author_url" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.authorUrl"></a>

```python
author_url: str
```

- *Type:* str

Author's URL / Website.

---

##### `auto_detect_bin`<sup>Optional</sup> <a name="auto_detect_bin" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoDetectBin"></a>

```python
auto_detect_bin: bool
```

- *Type:* bool
- *Default:* true

Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section.

---

##### `bin`<sup>Optional</sup> <a name="bin" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bin"></a>

```python
bin: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Binary programs vended with your module.

You can use this option to add/customize how binaries are represented in
your `package.json`, but unless `autoDetectBin` is `false`, every
executable file under `bin` will automatically be added to this section.

---

##### `bugs_email`<sup>Optional</sup> <a name="bugs_email" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bugsEmail"></a>

```python
bugs_email: str
```

- *Type:* str

The email address to which issues should be reported.

---

##### `bugs_url`<sup>Optional</sup> <a name="bugs_url" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bugsUrl"></a>

```python
bugs_url: str
```

- *Type:* str

The url to your project's issue tracker.

---

##### `bundled_deps`<sup>Optional</sup> <a name="bundled_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bundledDeps"></a>

```python
bundled_deps: typing.List[str]
```

- *Type:* typing.List[str]

List of dependencies to bundle into this module.

These modules will be
added both to the `dependencies` section and `bundledDependencies` section of
your `package.json`.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

##### `code_artifact_options`<sup>Optional</sup> <a name="code_artifact_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeArtifactOptions"></a>

```python
code_artifact_options: CodeArtifactOptions
```

- *Type:* projen.javascript.CodeArtifactOptions
- *Default:* undefined

Options for npm packages using AWS CodeArtifact.

This is required if publishing packages to, or installing scoped packages from AWS CodeArtifact

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.deps"></a>

```python
deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Runtime dependencies of this module.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'express', 'lodash', 'foo@^2' ]
```


##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.description"></a>

```python
description: str
```

- *Type:* str

The description is just a string that helps people understand the purpose of the package.

It can be used when searching for packages in a package manager as well.
See https://classic.yarnpkg.com/en/docs/package-json/#toc-description

---

##### `dev_deps`<sup>Optional</sup> <a name="dev_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.devDeps"></a>

```python
dev_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Build dependencies for this module.

These dependencies will only be
available in your build environment but will not be fetched when this
module is consumed.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'typescript', '@types/express' ]
```


##### `entrypoint`<sup>Optional</sup> <a name="entrypoint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.entrypoint"></a>

```python
entrypoint: str
```

- *Type:* str
- *Default:* "lib/index.js"

Module entrypoint (`main` in `package.json`).

Set to an empty string to not include `main` in your package.json

---

##### `homepage`<sup>Optional</sup> <a name="homepage" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.homepage"></a>

```python
homepage: str
```

- *Type:* str

Package's Homepage / Website.

---

##### `keywords`<sup>Optional</sup> <a name="keywords" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.keywords"></a>

```python
keywords: typing.List[str]
```

- *Type:* typing.List[str]

Keywords to include in `package.json`.

---

##### `license`<sup>Optional</sup> <a name="license" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.license"></a>

```python
license: str
```

- *Type:* str
- *Default:* "Apache-2.0"

License's SPDX identifier.

See https://github.com/projen/projen/tree/main/license-text for a list of supported licenses.
Use the `licensed` option if you want to no license to be specified.

---

##### `licensed`<sup>Optional</sup> <a name="licensed" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.licensed"></a>

```python
licensed: bool
```

- *Type:* bool
- *Default:* true

Indicates if a license should be added.

---

##### `max_node_version`<sup>Optional</sup> <a name="max_node_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.maxNodeVersion"></a>

```python
max_node_version: str
```

- *Type:* str
- *Default:* no max

Minimum node.js version to require via `engines` (inclusive).

---

##### `min_node_version`<sup>Optional</sup> <a name="min_node_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.minNodeVersion"></a>

```python
min_node_version: str
```

- *Type:* str
- *Default:* no "engines" specified

Minimum Node.js version to require via package.json `engines` (inclusive).

---

##### `npm_access`<sup>Optional</sup> <a name="npm_access" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmAccess"></a>

```python
npm_access: NpmAccess
```

- *Type:* projen.javascript.NpmAccess
- *Default:* for scoped packages (e.g. `foo@bar`), the default is `NpmAccess.RESTRICTED`, for non-scoped packages, the default is `NpmAccess.PUBLIC`.

Access level of the npm package.

---

##### ~~`npm_registry`~~<sup>Optional</sup> <a name="npm_registry" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmRegistry"></a>

- *Deprecated:* use `npmRegistryUrl` instead

```python
npm_registry: str
```

- *Type:* str

The host name of the npm registry to publish to.

Cannot be set together with `npmRegistryUrl`.

---

##### `npm_registry_url`<sup>Optional</sup> <a name="npm_registry_url" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmRegistryUrl"></a>

```python
npm_registry_url: str
```

- *Type:* str
- *Default:* "https://registry.npmjs.org"

The base URL of the npm package registry.

Must be a URL (e.g. start with "https://" or "http://")

---

##### `npm_token_secret`<sup>Optional</sup> <a name="npm_token_secret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmTokenSecret"></a>

```python
npm_token_secret: str
```

- *Type:* str
- *Default:* "NPM_TOKEN"

GitHub secret which contains the NPM token to use when publishing packages.

---

##### `package_manager`<sup>Optional</sup> <a name="package_manager" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.packageManager"></a>

```python
package_manager: NodePackageManager
```

- *Type:* projen.javascript.NodePackageManager
- *Default:* NodePackageManager.YARN

The Node Package Manager used to execute scripts.

---

##### `package_name`<sup>Optional</sup> <a name="package_name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.packageName"></a>

```python
package_name: str
```

- *Type:* str
- *Default:* defaults to project name

The "name" in package.json.

---

##### `peer_dependency_options`<sup>Optional</sup> <a name="peer_dependency_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.peerDependencyOptions"></a>

```python
peer_dependency_options: PeerDependencyOptions
```

- *Type:* projen.javascript.PeerDependencyOptions

Options for `peerDeps`.

---

##### `peer_deps`<sup>Optional</sup> <a name="peer_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.peerDeps"></a>

```python
peer_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Peer dependencies for this module.

Dependencies listed here are required to
be installed (and satisfied) by the _consumer_ of this library. Using peer
dependencies allows you to ensure that only a single module of a certain
library exists in the `node_modules` tree of your consumers.

Note that prior to npm@7, peer dependencies are _not_ automatically
installed, which means that adding peer dependencies to a library will be a
breaking change for your customers.

Unless `peerDependencyOptions.pinnedDevDependency` is disabled (it is
enabled by default), projen will automatically add a dev dependency with a
pinned version for each peer dependency. This will ensure that you build &
test your module against the lowest peer version required.

---

##### `pnpm_version`<sup>Optional</sup> <a name="pnpm_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pnpmVersion"></a>

```python
pnpm_version: str
```

- *Type:* str
- *Default:* "7"

The version of PNPM to use if using PNPM as a package manager.

---

##### `repository`<sup>Optional</sup> <a name="repository" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.repository"></a>

```python
repository: str
```

- *Type:* str

The repository is the location where the actual code for your package lives.

See https://classic.yarnpkg.com/en/docs/package-json/#toc-repository

---

##### `repository_directory`<sup>Optional</sup> <a name="repository_directory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.repositoryDirectory"></a>

```python
repository_directory: str
```

- *Type:* str

If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives.

---

##### `scoped_packages_options`<sup>Optional</sup> <a name="scoped_packages_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.scopedPackagesOptions"></a>

```python
scoped_packages_options: typing.List[ScopedPackagesOptions]
```

- *Type:* typing.List[projen.javascript.ScopedPackagesOptions]
- *Default:* fetch all scoped packages from the public npm registry

Options for privately hosted scoped packages.

---

##### `scripts`<sup>Optional</sup> <a name="scripts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.scripts"></a>

```python
scripts: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]
- *Default:* {}

npm scripts to include.

If a script has the same name as a standard script,
the standard script will be overwritten.

---

##### `stability`<sup>Optional</sup> <a name="stability" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.stability"></a>

```python
stability: str
```

- *Type:* str

Package's Stability.

---

##### `jsii_release_version`<sup>Optional</sup> <a name="jsii_release_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jsiiReleaseVersion"></a>

```python
jsii_release_version: str
```

- *Type:* str
- *Default:* "latest"

Version requirement of `publib` which is used to publish modules to npm.

---

##### `major_version`<sup>Optional</sup> <a name="major_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.majorVersion"></a>

```python
major_version: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* Major version is not enforced.

Major version to release from the default branch.

If this is specified, we bump the latest version of this major version line.
If not specified, we bump the global latest version.

---

##### `min_major_version`<sup>Optional</sup> <a name="min_major_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.minMajorVersion"></a>

```python
min_major_version: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* No minimum version is being enforced

Minimal Major version to release.

This can be useful to set to 1, as breaking changes before the 1.x major
release are not incrementing the major version number.

Can not be set together with `majorVersion`.

---

##### `npm_dist_tag`<sup>Optional</sup> <a name="npm_dist_tag" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmDistTag"></a>

```python
npm_dist_tag: str
```

- *Type:* str
- *Default:* "latest"

The npmDistTag to use when publishing from the default branch.

To set the npm dist-tag for release branches, set the `npmDistTag` property
for each branch.

---

##### `post_build_steps`<sup>Optional</sup> <a name="post_build_steps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.postBuildSteps"></a>

```python
post_build_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* []

Steps to execute after build as part of the release workflow.

---

##### `prerelease`<sup>Optional</sup> <a name="prerelease" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prerelease"></a>

```python
prerelease: str
```

- *Type:* str
- *Default:* normal semantic versions

Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre").

---

##### `publish_dry_run`<sup>Optional</sup> <a name="publish_dry_run" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publishDryRun"></a>

```python
publish_dry_run: bool
```

- *Type:* bool
- *Default:* false

Instead of actually publishing to package managers, just print the publishing command.

---

##### `publish_tasks`<sup>Optional</sup> <a name="publish_tasks" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publishTasks"></a>

```python
publish_tasks: bool
```

- *Type:* bool
- *Default:* false

Define publishing tasks that can be executed manually as well as workflows.

Normally, publishing only happens within automated workflows. Enable this
in order to create a publishing task for each publishing activity.

---

##### `release_branches`<sup>Optional</sup> <a name="release_branches" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseBranches"></a>

```python
release_branches: typing.Mapping[BranchOptions]
```

- *Type:* typing.Mapping[projen.release.BranchOptions]
- *Default:* no additional branches are used for release. you can use `addBranch()` to add additional branches.

Defines additional release branches.

A workflow will be created for each
release branch which will publish releases from commits in this branch.
Each release branch _must_ be assigned a major version number which is used
to enforce that versions published from that branch always use that major
version. If multiple branches are used, the `majorVersion` field must also
be provided for the default branch.

---

##### ~~`release_every_commit`~~<sup>Optional</sup> <a name="release_every_commit" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseEveryCommit"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.continuous()` instead

```python
release_every_commit: bool
```

- *Type:* bool
- *Default:* true

Automatically release new versions every commit to one of branches in `releaseBranches`.

---

##### `release_failure_issue`<sup>Optional</sup> <a name="release_failure_issue" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseFailureIssue"></a>

```python
release_failure_issue: bool
```

- *Type:* bool
- *Default:* false

Create a github issue on every failed publishing task.

---

##### `release_failure_issue_label`<sup>Optional</sup> <a name="release_failure_issue_label" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseFailureIssueLabel"></a>

```python
release_failure_issue_label: str
```

- *Type:* str
- *Default:* "failed-release"

The label to apply to issues indicating publish failures.

Only applies if `releaseFailureIssue` is true.

---

##### ~~`release_schedule`~~<sup>Optional</sup> <a name="release_schedule" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseSchedule"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.scheduled()` instead

```python
release_schedule: str
```

- *Type:* str
- *Default:* no scheduled releases

CRON schedule to trigger new releases.

---

##### `release_tag_prefix`<sup>Optional</sup> <a name="release_tag_prefix" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseTagPrefix"></a>

```python
release_tag_prefix: str
```

- *Type:* str
- *Default:* "v"

Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers.

Note: this prefix is used to detect the latest tagged version
when bumping, so if you change this on a project with an existing version
history, you may need to manually tag your latest release
with the new prefix.

---

##### `release_trigger`<sup>Optional</sup> <a name="release_trigger" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseTrigger"></a>

```python
release_trigger: ReleaseTrigger
```

- *Type:* projen.release.ReleaseTrigger
- *Default:* Continuous releases (`ReleaseTrigger.continuous()`)

The release trigger to use.

---

##### `release_workflow_name`<sup>Optional</sup> <a name="release_workflow_name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflowName"></a>

```python
release_workflow_name: str
```

- *Type:* str
- *Default:* "Release"

The name of the default release workflow.

---

##### `release_workflow_setup_steps`<sup>Optional</sup> <a name="release_workflow_setup_steps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflowSetupSteps"></a>

```python
release_workflow_setup_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]

A set of workflow steps to execute in order to setup the workflow container.

---

##### `versionrc_options`<sup>Optional</sup> <a name="versionrc_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.versionrcOptions"></a>

```python
versionrc_options: typing.Mapping[typing.Any]
```

- *Type:* typing.Mapping[typing.Any]
- *Default:* standard configuration applicable for GitHub repositories

Custom configuration used when creating changelog with standard-version package.

Given values either append to default configuration or overwrite values in it.

---

##### `workflow_container_image`<sup>Optional</sup> <a name="workflow_container_image" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowContainerImage"></a>

```python
workflow_container_image: str
```

- *Type:* str
- *Default:* default image

Container image to use for GitHub workflows.

---

##### `workflow_runs_on`<sup>Optional</sup> <a name="workflow_runs_on" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowRunsOn"></a>

```python
workflow_runs_on: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* ["ubuntu-latest"]

Github Runner selection labels.

---

##### `default_release_branch`<sup>Required</sup> <a name="default_release_branch" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.defaultReleaseBranch"></a>

```python
default_release_branch: str
```

- *Type:* str
- *Default:* "main"

The name of the main release branch.

---

##### `artifacts_directory`<sup>Optional</sup> <a name="artifacts_directory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.artifactsDirectory"></a>

```python
artifacts_directory: str
```

- *Type:* str
- *Default:* "dist"

A directory which will contain build artifacts.

---

##### `auto_approve_upgrades`<sup>Optional</sup> <a name="auto_approve_upgrades" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.autoApproveUpgrades"></a>

```python
auto_approve_upgrades: bool
```

- *Type:* bool
- *Default:* true

Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued).

Throw if set to true but `autoApproveOptions` are not defined.

---

##### `build_workflow`<sup>Optional</sup> <a name="build_workflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.buildWorkflow"></a>

```python
build_workflow: bool
```

- *Type:* bool
- *Default:* true if not a subproject

Define a GitHub workflow for building PRs.

---

##### `build_workflow_triggers`<sup>Optional</sup> <a name="build_workflow_triggers" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.buildWorkflowTriggers"></a>

```python
build_workflow_triggers: Triggers
```

- *Type:* projen.github.workflows.Triggers
- *Default:* "{ pullRequest: {}, workflowDispatch: {} }"

Build workflow triggers.

---

##### `bundler_options`<sup>Optional</sup> <a name="bundler_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.bundlerOptions"></a>

```python
bundler_options: BundlerOptions
```

- *Type:* projen.javascript.BundlerOptions

Options for `Bundler`.

---

##### `code_cov`<sup>Optional</sup> <a name="code_cov" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeCov"></a>

```python
code_cov: bool
```

- *Type:* bool
- *Default:* false

Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with @codeCovTokenSecret.

---

##### `code_cov_token_secret`<sup>Optional</sup> <a name="code_cov_token_secret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.codeCovTokenSecret"></a>

```python
code_cov_token_secret: str
```

- *Type:* str
- *Default:* if this option is not specified, only public repositories are supported

Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories.

---

##### `copyright_owner`<sup>Optional</sup> <a name="copyright_owner" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.copyrightOwner"></a>

```python
copyright_owner: str
```

- *Type:* str
- *Default:* defaults to the value of authorName or "" if `authorName` is undefined.

License copyright owner.

---

##### `copyright_period`<sup>Optional</sup> <a name="copyright_period" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.copyrightPeriod"></a>

```python
copyright_period: str
```

- *Type:* str
- *Default:* current year

The copyright years to put in the LICENSE file.

---

##### `dependabot`<sup>Optional</sup> <a name="dependabot" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.dependabot"></a>

```python
dependabot: bool
```

- *Type:* bool
- *Default:* false

Use dependabot to handle dependency upgrades.

Cannot be used in conjunction with `depsUpgrade`.

---

##### `dependabot_options`<sup>Optional</sup> <a name="dependabot_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.dependabotOptions"></a>

```python
dependabot_options: DependabotOptions
```

- *Type:* projen.github.DependabotOptions
- *Default:* default options

Options for dependabot.

---

##### `deps_upgrade`<sup>Optional</sup> <a name="deps_upgrade" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.depsUpgrade"></a>

```python
deps_upgrade: bool
```

- *Type:* bool
- *Default:* true

Use github workflows to handle dependency upgrades.

Cannot be used in conjunction with `dependabot`.

---

##### `deps_upgrade_options`<sup>Optional</sup> <a name="deps_upgrade_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.depsUpgradeOptions"></a>

```python
deps_upgrade_options: UpgradeDependenciesOptions
```

- *Type:* projen.javascript.UpgradeDependenciesOptions
- *Default:* default options

Options for `UpgradeDependencies`.

---

##### `gitignore`<sup>Optional</sup> <a name="gitignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.gitignore"></a>

```python
gitignore: typing.List[str]
```

- *Type:* typing.List[str]

Additional entries to .gitignore.

---

##### `jest`<sup>Optional</sup> <a name="jest" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jest"></a>

```python
jest: bool
```

- *Type:* bool
- *Default:* true

Setup jest unit tests.

---

##### `jest_options`<sup>Optional</sup> <a name="jest_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.jestOptions"></a>

```python
jest_options: JestOptions
```

- *Type:* projen.javascript.JestOptions
- *Default:* default options

Jest options.

---

##### `mutable_build`<sup>Optional</sup> <a name="mutable_build" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.mutableBuild"></a>

```python
mutable_build: bool
```

- *Type:* bool
- *Default:* true

Automatically update files modified during builds to pull-request branches.

This means
that any files synthesized by projen or e.g. test snapshots will always be up-to-date
before a PR is merged.

Implies that PR builds do not have anti-tamper checks.

---

##### ~~`npmignore`~~<sup>Optional</sup> <a name="npmignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmignore"></a>

- *Deprecated:* - use `project.addPackageIgnore`

```python
npmignore: typing.List[str]
```

- *Type:* typing.List[str]

Additional entries to .npmignore.

---

##### `npmignore_enabled`<sup>Optional</sup> <a name="npmignore_enabled" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmignoreEnabled"></a>

```python
npmignore_enabled: bool
```

- *Type:* bool
- *Default:* true

Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs.

---

##### `npm_ignore_options`<sup>Optional</sup> <a name="npm_ignore_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.npmIgnoreOptions"></a>

```python
npm_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .npmignore file.

---

##### `package`<sup>Optional</sup> <a name="package" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.package"></a>

```python
package: bool
```

- *Type:* bool
- *Default:* true

Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`).

---

##### `prettier`<sup>Optional</sup> <a name="prettier" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prettier"></a>

```python
prettier: bool
```

- *Type:* bool
- *Default:* false

Setup prettier.

---

##### `prettier_options`<sup>Optional</sup> <a name="prettier_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.prettierOptions"></a>

```python
prettier_options: PrettierOptions
```

- *Type:* projen.javascript.PrettierOptions
- *Default:* default options

Prettier options.

---

##### `projen_dev_dependency`<sup>Optional</sup> <a name="projen_dev_dependency" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenDevDependency"></a>

```python
projen_dev_dependency: bool
```

- *Type:* bool
- *Default:* true

Indicates of "projen" should be installed as a devDependency.

---

##### `projenrc_js`<sup>Optional</sup> <a name="projenrc_js" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJs"></a>

```python
projenrc_js: bool
```

- *Type:* bool
- *Default:* true if projenrcJson is false

Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation.

---

##### `projenrc_js_options`<sup>Optional</sup> <a name="projenrc_js_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcJsOptions"></a>

```python
projenrc_js_options: ProjenrcOptions
```

- *Type:* projen.javascript.ProjenrcOptions
- *Default:* default options

Options for .projenrc.js.

---

##### `projen_version`<sup>Optional</sup> <a name="projen_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenVersion"></a>

```python
projen_version: str
```

- *Type:* str
- *Default:* Defaults to the latest version.

Version of projen to install.

---

##### `pull_request_template`<sup>Optional</sup> <a name="pull_request_template" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pullRequestTemplate"></a>

```python
pull_request_template: bool
```

- *Type:* bool
- *Default:* true

Include a GitHub pull request template.

---

##### `pull_request_template_contents`<sup>Optional</sup> <a name="pull_request_template_contents" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.pullRequestTemplateContents"></a>

```python
pull_request_template_contents: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* default content

The contents of the pull request template.

---

##### `release`<sup>Optional</sup> <a name="release" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.release"></a>

```python
release: bool
```

- *Type:* bool
- *Default:* true (false for subprojects)

Add release management to this project.

---

##### `release_to_npm`<sup>Optional</sup> <a name="release_to_npm" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseToNpm"></a>

```python
release_to_npm: bool
```

- *Type:* bool
- *Default:* false

Automatically release to npm when new versions are introduced.

---

##### ~~`release_workflow`~~<sup>Optional</sup> <a name="release_workflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.releaseWorkflow"></a>

- *Deprecated:* see `release`.

```python
release_workflow: bool
```

- *Type:* bool
- *Default:* true if not a subproject

DEPRECATED: renamed to `release`.

---

##### `workflow_bootstrap_steps`<sup>Optional</sup> <a name="workflow_bootstrap_steps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowBootstrapSteps"></a>

```python
workflow_bootstrap_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* "yarn install --frozen-lockfile && yarn projen"

Workflow steps to use in order to bootstrap this repo.

---

##### `workflow_git_identity`<sup>Optional</sup> <a name="workflow_git_identity" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowGitIdentity"></a>

```python
workflow_git_identity: GitIdentity
```

- *Type:* projen.github.GitIdentity
- *Default:* GitHub Actions

The git identity to use in workflows.

---

##### `workflow_node_version`<sup>Optional</sup> <a name="workflow_node_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.workflowNodeVersion"></a>

```python
workflow_node_version: str
```

- *Type:* str
- *Default:* same as `minNodeVersion`

The node version to use in GitHub workflows.

---

##### `disable_tsconfig`<sup>Optional</sup> <a name="disable_tsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.disableTsconfig"></a>

```python
disable_tsconfig: bool
```

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler).

---

##### `disable_tsconfig_dev`<sup>Optional</sup> <a name="disable_tsconfig_dev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.disableTsconfigDev"></a>

```python
disable_tsconfig_dev: bool
```

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.dev.json` file.

---

##### `docgen`<sup>Optional</sup> <a name="docgen" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.docgen"></a>

```python
docgen: bool
```

- *Type:* bool
- *Default:* false

Docgen by Typedoc.

---

##### `docs_directory`<sup>Optional</sup> <a name="docs_directory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.docsDirectory"></a>

```python
docs_directory: str
```

- *Type:* str
- *Default:* "docs"

Docs directory.

---

##### `entrypoint_types`<sup>Optional</sup> <a name="entrypoint_types" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.entrypointTypes"></a>

```python
entrypoint_types: str
```

- *Type:* str
- *Default:* .d.ts file derived from the project's entrypoint (usually lib/index.d.ts)

The .d.ts file that includes the type declarations for this module.

---

##### `eslint`<sup>Optional</sup> <a name="eslint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.eslint"></a>

```python
eslint: bool
```

- *Type:* bool
- *Default:* true

Setup eslint.

---

##### `eslint_options`<sup>Optional</sup> <a name="eslint_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.eslintOptions"></a>

```python
eslint_options: EslintOptions
```

- *Type:* projen.javascript.EslintOptions
- *Default:* opinionated default options

Eslint options.

---

##### `libdir`<sup>Optional</sup> <a name="libdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.libdir"></a>

```python
libdir: str
```

- *Type:* str
- *Default:* "lib"

Typescript  artifacts output directory.

---

##### `projenrc_ts`<sup>Optional</sup> <a name="projenrc_ts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcTs"></a>

```python
projenrc_ts: bool
```

- *Type:* bool
- *Default:* false

Use TypeScript for your projenrc file (`.projenrc.ts`).

---

##### `projenrc_ts_options`<sup>Optional</sup> <a name="projenrc_ts_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.projenrcTsOptions"></a>

```python
projenrc_ts_options: ProjenrcOptions
```

- *Type:* projen.typescript.ProjenrcOptions

Options for .projenrc.ts.

---

##### `sample_code`<sup>Optional</sup> <a name="sample_code" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.sampleCode"></a>

```python
sample_code: bool
```

- *Type:* bool
- *Default:* true

Generate one-time sample in `src/` and `test/` if there are no files there.

---

##### `srcdir`<sup>Optional</sup> <a name="srcdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.srcdir"></a>

```python
srcdir: str
```

- *Type:* str
- *Default:* "src"

Typescript sources directory.

---

##### `testdir`<sup>Optional</sup> <a name="testdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.testdir"></a>

```python
testdir: str
```

- *Type:* str
- *Default:* "test"

Jest tests directory. Tests files should be named `xxx.test.ts`.

If this directory is under `srcdir` (e.g. `src/test`, `src/__tests__`),
then tests are going to be compiled into `lib/` and executed as javascript.
If the test directory is outside of `src`, then we configure jest to
compile the code in-memory.

---

##### `tsconfig`<sup>Optional</sup> <a name="tsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfig"></a>

```python
tsconfig: TypescriptConfigOptions
```

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* default options

Custom TSConfig.

---

##### `tsconfig_dev`<sup>Optional</sup> <a name="tsconfig_dev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfigDev"></a>

```python
tsconfig_dev: TypescriptConfigOptions
```

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* use the production tsconfig options

Custom tsconfig options for the development tsconfig.json file (used for testing).

---

##### `tsconfig_dev_file`<sup>Optional</sup> <a name="tsconfig_dev_file" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.tsconfigDevFile"></a>

```python
tsconfig_dev_file: str
```

- *Type:* str
- *Default:* "tsconfig.dev.json"

The name of the development tsconfig.json file.

---

##### `typescript_version`<sup>Optional</sup> <a name="typescript_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.typescriptVersion"></a>

```python
typescript_version: str
```

- *Type:* str
- *Default:* "latest"

TypeScript version to use.

NOTE: Typescript is not semantically versioned and should remain on the
same minor, so we recommend using a `~` dependency (e.g. `~1.2.3`).

---

##### `rewire`<sup>Optional</sup> <a name="rewire" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.rewire"></a>

```python
rewire: typing.Mapping[typing.Any]
```

- *Type:* typing.Mapping[typing.Any]
- *Default:* No rewired config.

Rewire webpack configuration.

Use this property to override webpack configuration properties provided
by create-react-app, without needing to eject.

This property will create a `config-overrides.js` file in your root directory,
which will contain the desired rewiring code.

To **override** the configuration, you can provide simple key value pairs.
Keys take the form of js code directives that traverse to the desired property.
Values should be JSON serializable objects.

For example, the following config:

```json
rewire: { "module.unknownContextCritical": false }
```

Will translate to the following `config-overrides.js` file:

```js
module.exports = function override(config, env) {
  config.module.unknownContextCritical = false;
}
```

> [https://github.com/timarney/react-app-rewired](https://github.com/timarney/react-app-rewired)

---

##### `application_name`<sup>Optional</sup> <a name="application_name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.applicationName"></a>

```python
application_name: str
```

- *Type:* str
- *Default:* "Sample App"

Name of the application name.

---

##### `public_dir`<sup>Optional</sup> <a name="public_dir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProjectOptions.property.publicDir"></a>

```python
public_dir: str
```

- *Type:* str
- *Default:* "public"

Public directory.

---

## Classes <a name="Classes" id="Classes"></a>

### CloudscapeReactTsWebsiteProject <a name="CloudscapeReactTsWebsiteProject" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject"></a>

Synthesizes a Cloudscape React Typescript Website Project.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer"></a>

```python
import aws_prototyping_sdk.cloudscape_react_ts_website

aws_prototyping_sdk.cloudscape_react_ts_website.CloudscapeReactTsWebsiteProject(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  auto_approve_options: AutoApproveOptions = None,
  auto_merge: bool = None,
  auto_merge_options: AutoMergeOptions = None,
  clobber: bool = None,
  dev_container: bool = None,
  github: bool = None,
  github_options: GitHubOptions = None,
  gitpod: bool = None,
  mergify: bool = None,
  mergify_options: MergifyOptions = None,
  project_type: ProjectType = None,
  projen_credentials: GithubCredentials = None,
  projen_token_secret: str = None,
  readme: SampleReadmeProps = None,
  stale: bool = None,
  stale_options: StaleOptions = None,
  vscode: bool = None,
  allow_library_dependencies: bool = None,
  author_email: str = None,
  author_name: str = None,
  author_organization: bool = None,
  author_url: str = None,
  auto_detect_bin: bool = None,
  bin: typing.Mapping[str] = None,
  bugs_email: str = None,
  bugs_url: str = None,
  bundled_deps: typing.List[str] = None,
  code_artifact_options: CodeArtifactOptions = None,
  deps: typing.List[str] = None,
  description: str = None,
  dev_deps: typing.List[str] = None,
  entrypoint: str = None,
  homepage: str = None,
  keywords: typing.List[str] = None,
  license: str = None,
  licensed: bool = None,
  max_node_version: str = None,
  min_node_version: str = None,
  npm_access: NpmAccess = None,
  npm_registry: str = None,
  npm_registry_url: str = None,
  npm_token_secret: str = None,
  package_manager: NodePackageManager = None,
  package_name: str = None,
  peer_dependency_options: PeerDependencyOptions = None,
  peer_deps: typing.List[str] = None,
  pnpm_version: str = None,
  repository: str = None,
  repository_directory: str = None,
  scoped_packages_options: typing.List[ScopedPackagesOptions] = None,
  scripts: typing.Mapping[str] = None,
  stability: str = None,
  jsii_release_version: str = None,
  major_version: typing.Union[int, float] = None,
  min_major_version: typing.Union[int, float] = None,
  npm_dist_tag: str = None,
  post_build_steps: typing.List[JobStep] = None,
  prerelease: str = None,
  publish_dry_run: bool = None,
  publish_tasks: bool = None,
  release_branches: typing.Mapping[BranchOptions] = None,
  release_every_commit: bool = None,
  release_failure_issue: bool = None,
  release_failure_issue_label: str = None,
  release_schedule: str = None,
  release_tag_prefix: str = None,
  release_trigger: ReleaseTrigger = None,
  release_workflow_name: str = None,
  release_workflow_setup_steps: typing.List[JobStep] = None,
  versionrc_options: typing.Mapping[typing.Any] = None,
  workflow_container_image: str = None,
  workflow_runs_on: typing.List[str] = None,
  default_release_branch: str,
  artifacts_directory: str = None,
  auto_approve_upgrades: bool = None,
  build_workflow: bool = None,
  build_workflow_triggers: Triggers = None,
  bundler_options: BundlerOptions = None,
  code_cov: bool = None,
  code_cov_token_secret: str = None,
  copyright_owner: str = None,
  copyright_period: str = None,
  dependabot: bool = None,
  dependabot_options: DependabotOptions = None,
  deps_upgrade: bool = None,
  deps_upgrade_options: UpgradeDependenciesOptions = None,
  gitignore: typing.List[str] = None,
  jest: bool = None,
  jest_options: JestOptions = None,
  mutable_build: bool = None,
  npmignore: typing.List[str] = None,
  npmignore_enabled: bool = None,
  npm_ignore_options: IgnoreFileOptions = None,
  package: bool = None,
  prettier: bool = None,
  prettier_options: PrettierOptions = None,
  projen_dev_dependency: bool = None,
  projenrc_js: bool = None,
  projenrc_js_options: ProjenrcOptions = None,
  projen_version: str = None,
  pull_request_template: bool = None,
  pull_request_template_contents: typing.List[str] = None,
  release: bool = None,
  release_to_npm: bool = None,
  release_workflow: bool = None,
  workflow_bootstrap_steps: typing.List[JobStep] = None,
  workflow_git_identity: GitIdentity = None,
  workflow_node_version: str = None,
  disable_tsconfig: bool = None,
  disable_tsconfig_dev: bool = None,
  docgen: bool = None,
  docs_directory: str = None,
  entrypoint_types: str = None,
  eslint: bool = None,
  eslint_options: EslintOptions = None,
  libdir: str = None,
  projenrc_ts: bool = None,
  projenrc_ts_options: ProjenrcOptions = None,
  sample_code: bool = None,
  srcdir: str = None,
  testdir: str = None,
  tsconfig: TypescriptConfigOptions = None,
  tsconfig_dev: TypescriptConfigOptions = None,
  tsconfig_dev_file: str = None,
  typescript_version: str = None,
  rewire: typing.Mapping[typing.Any] = None,
  application_name: str = None,
  public_dir: str = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoApproveOptions">auto_approve_options</a></code> | <code>projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoMerge">auto_merge</a></code> | <code>bool</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoMergeOptions">auto_merge_options</a></code> | <code>projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.clobber">clobber</a></code> | <code>bool</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.devContainer">dev_container</a></code> | <code>bool</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.github">github</a></code> | <code>bool</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.githubOptions">github_options</a></code> | <code>projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitpod">gitpod</a></code> | <code>bool</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mergify">mergify</a></code> | <code>bool</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mergifyOptions">mergify_options</a></code> | <code>projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projectType">project_type</a></code> | <code>projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenCredentials">projen_credentials</a></code> | <code>projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenTokenSecret">projen_token_secret</a></code> | <code>str</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.readme">readme</a></code> | <code>projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.stale">stale</a></code> | <code>bool</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.staleOptions">stale_options</a></code> | <code>projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.vscode">vscode</a></code> | <code>bool</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.allowLibraryDependencies">allow_library_dependencies</a></code> | <code>bool</code> | Allow the project to include `peerDependencies` and `bundledDependencies`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorEmail">author_email</a></code> | <code>str</code> | Author's e-mail. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorName">author_name</a></code> | <code>str</code> | Author's name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorOrganization">author_organization</a></code> | <code>bool</code> | Is the author an organization. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorUrl">author_url</a></code> | <code>str</code> | Author's URL / Website. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoDetectBin">auto_detect_bin</a></code> | <code>bool</code> | Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bin">bin</a></code> | <code>typing.Mapping[str]</code> | Binary programs vended with your module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bugsEmail">bugs_email</a></code> | <code>str</code> | The email address to which issues should be reported. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bugsUrl">bugs_url</a></code> | <code>str</code> | The url to your project's issue tracker. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bundledDeps">bundled_deps</a></code> | <code>typing.List[str]</code> | List of dependencies to bundle into this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeArtifactOptions">code_artifact_options</a></code> | <code>projen.javascript.CodeArtifactOptions</code> | Options for npm packages using AWS CodeArtifact. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.deps">deps</a></code> | <code>typing.List[str]</code> | Runtime dependencies of this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.description">description</a></code> | <code>str</code> | The description is just a string that helps people understand the purpose of the package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.devDeps">dev_deps</a></code> | <code>typing.List[str]</code> | Build dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.entrypoint">entrypoint</a></code> | <code>str</code> | Module entrypoint (`main` in `package.json`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.homepage">homepage</a></code> | <code>str</code> | Package's Homepage / Website. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.keywords">keywords</a></code> | <code>typing.List[str]</code> | Keywords to include in `package.json`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.license">license</a></code> | <code>str</code> | License's SPDX identifier. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.licensed">licensed</a></code> | <code>bool</code> | Indicates if a license should be added. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.maxNodeVersion">max_node_version</a></code> | <code>str</code> | Minimum node.js version to require via `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.minNodeVersion">min_node_version</a></code> | <code>str</code> | Minimum Node.js version to require via package.json `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmAccess">npm_access</a></code> | <code>projen.javascript.NpmAccess</code> | Access level of the npm package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmRegistry">npm_registry</a></code> | <code>str</code> | The host name of the npm registry to publish to. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmRegistryUrl">npm_registry_url</a></code> | <code>str</code> | The base URL of the npm package registry. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmTokenSecret">npm_token_secret</a></code> | <code>str</code> | GitHub secret which contains the NPM token to use when publishing packages. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.packageManager">package_manager</a></code> | <code>projen.javascript.NodePackageManager</code> | The Node Package Manager used to execute scripts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.packageName">package_name</a></code> | <code>str</code> | The "name" in package.json. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.peerDependencyOptions">peer_dependency_options</a></code> | <code>projen.javascript.PeerDependencyOptions</code> | Options for `peerDeps`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.peerDeps">peer_deps</a></code> | <code>typing.List[str]</code> | Peer dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pnpmVersion">pnpm_version</a></code> | <code>str</code> | The version of PNPM to use if using PNPM as a package manager. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.repository">repository</a></code> | <code>str</code> | The repository is the location where the actual code for your package lives. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.repositoryDirectory">repository_directory</a></code> | <code>str</code> | If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.scopedPackagesOptions">scoped_packages_options</a></code> | <code>typing.List[projen.javascript.ScopedPackagesOptions]</code> | Options for privately hosted scoped packages. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.scripts">scripts</a></code> | <code>typing.Mapping[str]</code> | npm scripts to include. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.stability">stability</a></code> | <code>str</code> | Package's Stability. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jsiiReleaseVersion">jsii_release_version</a></code> | <code>str</code> | Version requirement of `publib` which is used to publish modules to npm. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.majorVersion">major_version</a></code> | <code>typing.Union[int, float]</code> | Major version to release from the default branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.minMajorVersion">min_major_version</a></code> | <code>typing.Union[int, float]</code> | Minimal Major version to release. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmDistTag">npm_dist_tag</a></code> | <code>str</code> | The npmDistTag to use when publishing from the default branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.postBuildSteps">post_build_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Steps to execute after build as part of the release workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prerelease">prerelease</a></code> | <code>str</code> | Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre"). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publishDryRun">publish_dry_run</a></code> | <code>bool</code> | Instead of actually publishing to package managers, just print the publishing command. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publishTasks">publish_tasks</a></code> | <code>bool</code> | Define publishing tasks that can be executed manually as well as workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseBranches">release_branches</a></code> | <code>typing.Mapping[projen.release.BranchOptions]</code> | Defines additional release branches. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseEveryCommit">release_every_commit</a></code> | <code>bool</code> | Automatically release new versions every commit to one of branches in `releaseBranches`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseFailureIssue">release_failure_issue</a></code> | <code>bool</code> | Create a github issue on every failed publishing task. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseFailureIssueLabel">release_failure_issue_label</a></code> | <code>str</code> | The label to apply to issues indicating publish failures. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseSchedule">release_schedule</a></code> | <code>str</code> | CRON schedule to trigger new releases. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseTagPrefix">release_tag_prefix</a></code> | <code>str</code> | Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseTrigger">release_trigger</a></code> | <code>projen.release.ReleaseTrigger</code> | The release trigger to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflowName">release_workflow_name</a></code> | <code>str</code> | The name of the default release workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflowSetupSteps">release_workflow_setup_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | A set of workflow steps to execute in order to setup the workflow container. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.versionrcOptions">versionrc_options</a></code> | <code>typing.Mapping[typing.Any]</code> | Custom configuration used when creating changelog with standard-version package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowContainerImage">workflow_container_image</a></code> | <code>str</code> | Container image to use for GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowRunsOn">workflow_runs_on</a></code> | <code>typing.List[str]</code> | Github Runner selection labels. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.defaultReleaseBranch">default_release_branch</a></code> | <code>str</code> | The name of the main release branch. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.artifactsDirectory">artifacts_directory</a></code> | <code>str</code> | A directory which will contain build artifacts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoApproveUpgrades">auto_approve_upgrades</a></code> | <code>bool</code> | Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.buildWorkflow">build_workflow</a></code> | <code>bool</code> | Define a GitHub workflow for building PRs. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.buildWorkflowTriggers">build_workflow_triggers</a></code> | <code>projen.github.workflows.Triggers</code> | Build workflow triggers. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bundlerOptions">bundler_options</a></code> | <code>projen.javascript.BundlerOptions</code> | Options for `Bundler`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeCov">code_cov</a></code> | <code>bool</code> | Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with @codeCovTokenSecret. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeCovTokenSecret">code_cov_token_secret</a></code> | <code>str</code> | Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.copyrightOwner">copyright_owner</a></code> | <code>str</code> | License copyright owner. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.copyrightPeriod">copyright_period</a></code> | <code>str</code> | The copyright years to put in the LICENSE file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.dependabot">dependabot</a></code> | <code>bool</code> | Use dependabot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.dependabotOptions">dependabot_options</a></code> | <code>projen.github.DependabotOptions</code> | Options for dependabot. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.depsUpgrade">deps_upgrade</a></code> | <code>bool</code> | Use github workflows to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.depsUpgradeOptions">deps_upgrade_options</a></code> | <code>projen.javascript.UpgradeDependenciesOptions</code> | Options for `UpgradeDependencies`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitignore">gitignore</a></code> | <code>typing.List[str]</code> | Additional entries to .gitignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jest">jest</a></code> | <code>bool</code> | Setup jest unit tests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jestOptions">jest_options</a></code> | <code>projen.javascript.JestOptions</code> | Jest options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mutableBuild">mutable_build</a></code> | <code>bool</code> | Automatically update files modified during builds to pull-request branches. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmignore">npmignore</a></code> | <code>typing.List[str]</code> | Additional entries to .npmignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmignoreEnabled">npmignore_enabled</a></code> | <code>bool</code> | Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmIgnoreOptions">npm_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .npmignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.package">package</a></code> | <code>bool</code> | Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prettier">prettier</a></code> | <code>bool</code> | Setup prettier. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prettierOptions">prettier_options</a></code> | <code>projen.javascript.PrettierOptions</code> | Prettier options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenDevDependency">projen_dev_dependency</a></code> | <code>bool</code> | Indicates of "projen" should be installed as a devDependency. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJs">projenrc_js</a></code> | <code>bool</code> | Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJsOptions">projenrc_js_options</a></code> | <code>projen.javascript.ProjenrcOptions</code> | Options for .projenrc.js. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenVersion">projen_version</a></code> | <code>str</code> | Version of projen to install. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pullRequestTemplate">pull_request_template</a></code> | <code>bool</code> | Include a GitHub pull request template. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pullRequestTemplateContents">pull_request_template_contents</a></code> | <code>typing.List[str]</code> | The contents of the pull request template. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.release">release</a></code> | <code>bool</code> | Add release management to this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseToNpm">release_to_npm</a></code> | <code>bool</code> | Automatically release to npm when new versions are introduced. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflow">release_workflow</a></code> | <code>bool</code> | DEPRECATED: renamed to `release`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowBootstrapSteps">workflow_bootstrap_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Workflow steps to use in order to bootstrap this repo. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowGitIdentity">workflow_git_identity</a></code> | <code>projen.github.GitIdentity</code> | The git identity to use in workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowNodeVersion">workflow_node_version</a></code> | <code>str</code> | The node version to use in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.disableTsconfig">disable_tsconfig</a></code> | <code>bool</code> | Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.disableTsconfigDev">disable_tsconfig_dev</a></code> | <code>bool</code> | Do not generate a `tsconfig.dev.json` file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.docgen">docgen</a></code> | <code>bool</code> | Docgen by Typedoc. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.docsDirectory">docs_directory</a></code> | <code>str</code> | Docs directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.entrypointTypes">entrypoint_types</a></code> | <code>str</code> | The .d.ts file that includes the type declarations for this module. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.eslint">eslint</a></code> | <code>bool</code> | Setup eslint. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.eslintOptions">eslint_options</a></code> | <code>projen.javascript.EslintOptions</code> | Eslint options. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.libdir">libdir</a></code> | <code>str</code> | Typescript  artifacts output directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcTs">projenrc_ts</a></code> | <code>bool</code> | Use TypeScript for your projenrc file (`.projenrc.ts`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcTsOptions">projenrc_ts_options</a></code> | <code>projen.typescript.ProjenrcOptions</code> | Options for .projenrc.ts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.sampleCode">sample_code</a></code> | <code>bool</code> | Generate one-time sample in `src/` and `test/` if there are no files there. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.srcdir">srcdir</a></code> | <code>str</code> | Typescript sources directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.testdir">testdir</a></code> | <code>str</code> | Jest tests directory. Tests files should be named `xxx.test.ts`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfig">tsconfig</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom TSConfig. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfigDev">tsconfig_dev</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom tsconfig options for the development tsconfig.json file (used for testing). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfigDevFile">tsconfig_dev_file</a></code> | <code>str</code> | The name of the development tsconfig.json file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.typescriptVersion">typescript_version</a></code> | <code>str</code> | TypeScript version to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.rewire">rewire</a></code> | <code>typing.Mapping[typing.Any]</code> | Rewire webpack configuration. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.applicationName">application_name</a></code> | <code>str</code> | Name of the application name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publicDir">public_dir</a></code> | <code>str</code> | Public directory. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.name"></a>

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.commitGenerated"></a>

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitIgnoreOptions"></a>

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitOptions"></a>

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.logging"></a>

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.outdir"></a>

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.parent"></a>

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenCommand"></a>

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJson"></a>

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJsonOptions"></a>

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.renovatebot"></a>

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.renovatebotOptions"></a>

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `auto_approve_options`<sup>Optional</sup> <a name="auto_approve_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoApproveOptions"></a>

- *Type:* projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoMerge"></a>

- *Type:* bool
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `auto_merge_options`<sup>Optional</sup> <a name="auto_merge_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoMergeOptions"></a>

- *Type:* projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.clobber"></a>

- *Type:* bool
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.devContainer"></a>

- *Type:* bool
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.github"></a>

- *Type:* bool
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `github_options`<sup>Optional</sup> <a name="github_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.githubOptions"></a>

- *Type:* projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitpod"></a>

- *Type:* bool
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

- *Type:* bool
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergify_options`~~<sup>Optional</sup> <a name="mergify_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

- *Type:* projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`project_type`~~<sup>Optional</sup> <a name="project_type" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projectType"></a>

- *Deprecated:* no longer supported at the base project level

- *Type:* projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projen_credentials`<sup>Optional</sup> <a name="projen_credentials" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenCredentials"></a>

- *Type:* projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projen_token_secret`~~<sup>Optional</sup> <a name="projen_token_secret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

- *Type:* str
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.readme"></a>

- *Type:* projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```python
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.stale"></a>

- *Type:* bool
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `stale_options`<sup>Optional</sup> <a name="stale_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.staleOptions"></a>

- *Type:* projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.vscode"></a>

- *Type:* bool
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `allow_library_dependencies`<sup>Optional</sup> <a name="allow_library_dependencies" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.allowLibraryDependencies"></a>

- *Type:* bool
- *Default:* true

Allow the project to include `peerDependencies` and `bundledDependencies`.

This is normally only allowed for libraries. For apps, there's no meaning
for specifying these.

---

##### `author_email`<sup>Optional</sup> <a name="author_email" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorEmail"></a>

- *Type:* str

Author's e-mail.

---

##### `author_name`<sup>Optional</sup> <a name="author_name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorName"></a>

- *Type:* str

Author's name.

---

##### `author_organization`<sup>Optional</sup> <a name="author_organization" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorOrganization"></a>

- *Type:* bool

Is the author an organization.

---

##### `author_url`<sup>Optional</sup> <a name="author_url" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.authorUrl"></a>

- *Type:* str

Author's URL / Website.

---

##### `auto_detect_bin`<sup>Optional</sup> <a name="auto_detect_bin" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoDetectBin"></a>

- *Type:* bool
- *Default:* true

Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section.

---

##### `bin`<sup>Optional</sup> <a name="bin" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bin"></a>

- *Type:* typing.Mapping[str]

Binary programs vended with your module.

You can use this option to add/customize how binaries are represented in
your `package.json`, but unless `autoDetectBin` is `false`, every
executable file under `bin` will automatically be added to this section.

---

##### `bugs_email`<sup>Optional</sup> <a name="bugs_email" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bugsEmail"></a>

- *Type:* str

The email address to which issues should be reported.

---

##### `bugs_url`<sup>Optional</sup> <a name="bugs_url" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bugsUrl"></a>

- *Type:* str

The url to your project's issue tracker.

---

##### `bundled_deps`<sup>Optional</sup> <a name="bundled_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bundledDeps"></a>

- *Type:* typing.List[str]

List of dependencies to bundle into this module.

These modules will be
added both to the `dependencies` section and `bundledDependencies` section of
your `package.json`.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

##### `code_artifact_options`<sup>Optional</sup> <a name="code_artifact_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeArtifactOptions"></a>

- *Type:* projen.javascript.CodeArtifactOptions
- *Default:* undefined

Options for npm packages using AWS CodeArtifact.

This is required if publishing packages to, or installing scoped packages from AWS CodeArtifact

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.deps"></a>

- *Type:* typing.List[str]
- *Default:* []

Runtime dependencies of this module.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'express', 'lodash', 'foo@^2' ]
```


##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.description"></a>

- *Type:* str

The description is just a string that helps people understand the purpose of the package.

It can be used when searching for packages in a package manager as well.
See https://classic.yarnpkg.com/en/docs/package-json/#toc-description

---

##### `dev_deps`<sup>Optional</sup> <a name="dev_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.devDeps"></a>

- *Type:* typing.List[str]
- *Default:* []

Build dependencies for this module.

These dependencies will only be
available in your build environment but will not be fetched when this
module is consumed.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'typescript', '@types/express' ]
```


##### `entrypoint`<sup>Optional</sup> <a name="entrypoint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.entrypoint"></a>

- *Type:* str
- *Default:* "lib/index.js"

Module entrypoint (`main` in `package.json`).

Set to an empty string to not include `main` in your package.json

---

##### `homepage`<sup>Optional</sup> <a name="homepage" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.homepage"></a>

- *Type:* str

Package's Homepage / Website.

---

##### `keywords`<sup>Optional</sup> <a name="keywords" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.keywords"></a>

- *Type:* typing.List[str]

Keywords to include in `package.json`.

---

##### `license`<sup>Optional</sup> <a name="license" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.license"></a>

- *Type:* str
- *Default:* "Apache-2.0"

License's SPDX identifier.

See https://github.com/projen/projen/tree/main/license-text for a list of supported licenses.
Use the `licensed` option if you want to no license to be specified.

---

##### `licensed`<sup>Optional</sup> <a name="licensed" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.licensed"></a>

- *Type:* bool
- *Default:* true

Indicates if a license should be added.

---

##### `max_node_version`<sup>Optional</sup> <a name="max_node_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.maxNodeVersion"></a>

- *Type:* str
- *Default:* no max

Minimum node.js version to require via `engines` (inclusive).

---

##### `min_node_version`<sup>Optional</sup> <a name="min_node_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.minNodeVersion"></a>

- *Type:* str
- *Default:* no "engines" specified

Minimum Node.js version to require via package.json `engines` (inclusive).

---

##### `npm_access`<sup>Optional</sup> <a name="npm_access" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmAccess"></a>

- *Type:* projen.javascript.NpmAccess
- *Default:* for scoped packages (e.g. `foo@bar`), the default is `NpmAccess.RESTRICTED`, for non-scoped packages, the default is `NpmAccess.PUBLIC`.

Access level of the npm package.

---

##### ~~`npm_registry`~~<sup>Optional</sup> <a name="npm_registry" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmRegistry"></a>

- *Deprecated:* use `npmRegistryUrl` instead

- *Type:* str

The host name of the npm registry to publish to.

Cannot be set together with `npmRegistryUrl`.

---

##### `npm_registry_url`<sup>Optional</sup> <a name="npm_registry_url" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmRegistryUrl"></a>

- *Type:* str
- *Default:* "https://registry.npmjs.org"

The base URL of the npm package registry.

Must be a URL (e.g. start with "https://" or "http://")

---

##### `npm_token_secret`<sup>Optional</sup> <a name="npm_token_secret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmTokenSecret"></a>

- *Type:* str
- *Default:* "NPM_TOKEN"

GitHub secret which contains the NPM token to use when publishing packages.

---

##### `package_manager`<sup>Optional</sup> <a name="package_manager" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.packageManager"></a>

- *Type:* projen.javascript.NodePackageManager
- *Default:* NodePackageManager.YARN

The Node Package Manager used to execute scripts.

---

##### `package_name`<sup>Optional</sup> <a name="package_name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.packageName"></a>

- *Type:* str
- *Default:* defaults to project name

The "name" in package.json.

---

##### `peer_dependency_options`<sup>Optional</sup> <a name="peer_dependency_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.peerDependencyOptions"></a>

- *Type:* projen.javascript.PeerDependencyOptions

Options for `peerDeps`.

---

##### `peer_deps`<sup>Optional</sup> <a name="peer_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.peerDeps"></a>

- *Type:* typing.List[str]
- *Default:* []

Peer dependencies for this module.

Dependencies listed here are required to
be installed (and satisfied) by the _consumer_ of this library. Using peer
dependencies allows you to ensure that only a single module of a certain
library exists in the `node_modules` tree of your consumers.

Note that prior to npm@7, peer dependencies are _not_ automatically
installed, which means that adding peer dependencies to a library will be a
breaking change for your customers.

Unless `peerDependencyOptions.pinnedDevDependency` is disabled (it is
enabled by default), projen will automatically add a dev dependency with a
pinned version for each peer dependency. This will ensure that you build &
test your module against the lowest peer version required.

---

##### `pnpm_version`<sup>Optional</sup> <a name="pnpm_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pnpmVersion"></a>

- *Type:* str
- *Default:* "7"

The version of PNPM to use if using PNPM as a package manager.

---

##### `repository`<sup>Optional</sup> <a name="repository" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.repository"></a>

- *Type:* str

The repository is the location where the actual code for your package lives.

See https://classic.yarnpkg.com/en/docs/package-json/#toc-repository

---

##### `repository_directory`<sup>Optional</sup> <a name="repository_directory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.repositoryDirectory"></a>

- *Type:* str

If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives.

---

##### `scoped_packages_options`<sup>Optional</sup> <a name="scoped_packages_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.scopedPackagesOptions"></a>

- *Type:* typing.List[projen.javascript.ScopedPackagesOptions]
- *Default:* fetch all scoped packages from the public npm registry

Options for privately hosted scoped packages.

---

##### `scripts`<sup>Optional</sup> <a name="scripts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.scripts"></a>

- *Type:* typing.Mapping[str]
- *Default:* {}

npm scripts to include.

If a script has the same name as a standard script,
the standard script will be overwritten.

---

##### `stability`<sup>Optional</sup> <a name="stability" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.stability"></a>

- *Type:* str

Package's Stability.

---

##### `jsii_release_version`<sup>Optional</sup> <a name="jsii_release_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jsiiReleaseVersion"></a>

- *Type:* str
- *Default:* "latest"

Version requirement of `publib` which is used to publish modules to npm.

---

##### `major_version`<sup>Optional</sup> <a name="major_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.majorVersion"></a>

- *Type:* typing.Union[int, float]
- *Default:* Major version is not enforced.

Major version to release from the default branch.

If this is specified, we bump the latest version of this major version line.
If not specified, we bump the global latest version.

---

##### `min_major_version`<sup>Optional</sup> <a name="min_major_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.minMajorVersion"></a>

- *Type:* typing.Union[int, float]
- *Default:* No minimum version is being enforced

Minimal Major version to release.

This can be useful to set to 1, as breaking changes before the 1.x major
release are not incrementing the major version number.

Can not be set together with `majorVersion`.

---

##### `npm_dist_tag`<sup>Optional</sup> <a name="npm_dist_tag" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmDistTag"></a>

- *Type:* str
- *Default:* "latest"

The npmDistTag to use when publishing from the default branch.

To set the npm dist-tag for release branches, set the `npmDistTag` property
for each branch.

---

##### `post_build_steps`<sup>Optional</sup> <a name="post_build_steps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.postBuildSteps"></a>

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* []

Steps to execute after build as part of the release workflow.

---

##### `prerelease`<sup>Optional</sup> <a name="prerelease" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prerelease"></a>

- *Type:* str
- *Default:* normal semantic versions

Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre").

---

##### `publish_dry_run`<sup>Optional</sup> <a name="publish_dry_run" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publishDryRun"></a>

- *Type:* bool
- *Default:* false

Instead of actually publishing to package managers, just print the publishing command.

---

##### `publish_tasks`<sup>Optional</sup> <a name="publish_tasks" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publishTasks"></a>

- *Type:* bool
- *Default:* false

Define publishing tasks that can be executed manually as well as workflows.

Normally, publishing only happens within automated workflows. Enable this
in order to create a publishing task for each publishing activity.

---

##### `release_branches`<sup>Optional</sup> <a name="release_branches" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseBranches"></a>

- *Type:* typing.Mapping[projen.release.BranchOptions]
- *Default:* no additional branches are used for release. you can use `addBranch()` to add additional branches.

Defines additional release branches.

A workflow will be created for each
release branch which will publish releases from commits in this branch.
Each release branch _must_ be assigned a major version number which is used
to enforce that versions published from that branch always use that major
version. If multiple branches are used, the `majorVersion` field must also
be provided for the default branch.

---

##### ~~`release_every_commit`~~<sup>Optional</sup> <a name="release_every_commit" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseEveryCommit"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.continuous()` instead

- *Type:* bool
- *Default:* true

Automatically release new versions every commit to one of branches in `releaseBranches`.

---

##### `release_failure_issue`<sup>Optional</sup> <a name="release_failure_issue" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseFailureIssue"></a>

- *Type:* bool
- *Default:* false

Create a github issue on every failed publishing task.

---

##### `release_failure_issue_label`<sup>Optional</sup> <a name="release_failure_issue_label" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseFailureIssueLabel"></a>

- *Type:* str
- *Default:* "failed-release"

The label to apply to issues indicating publish failures.

Only applies if `releaseFailureIssue` is true.

---

##### ~~`release_schedule`~~<sup>Optional</sup> <a name="release_schedule" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseSchedule"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.scheduled()` instead

- *Type:* str
- *Default:* no scheduled releases

CRON schedule to trigger new releases.

---

##### `release_tag_prefix`<sup>Optional</sup> <a name="release_tag_prefix" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseTagPrefix"></a>

- *Type:* str
- *Default:* "v"

Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers.

Note: this prefix is used to detect the latest tagged version
when bumping, so if you change this on a project with an existing version
history, you may need to manually tag your latest release
with the new prefix.

---

##### `release_trigger`<sup>Optional</sup> <a name="release_trigger" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseTrigger"></a>

- *Type:* projen.release.ReleaseTrigger
- *Default:* Continuous releases (`ReleaseTrigger.continuous()`)

The release trigger to use.

---

##### `release_workflow_name`<sup>Optional</sup> <a name="release_workflow_name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflowName"></a>

- *Type:* str
- *Default:* "Release"

The name of the default release workflow.

---

##### `release_workflow_setup_steps`<sup>Optional</sup> <a name="release_workflow_setup_steps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflowSetupSteps"></a>

- *Type:* typing.List[projen.github.workflows.JobStep]

A set of workflow steps to execute in order to setup the workflow container.

---

##### `versionrc_options`<sup>Optional</sup> <a name="versionrc_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.versionrcOptions"></a>

- *Type:* typing.Mapping[typing.Any]
- *Default:* standard configuration applicable for GitHub repositories

Custom configuration used when creating changelog with standard-version package.

Given values either append to default configuration or overwrite values in it.

---

##### `workflow_container_image`<sup>Optional</sup> <a name="workflow_container_image" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowContainerImage"></a>

- *Type:* str
- *Default:* default image

Container image to use for GitHub workflows.

---

##### `workflow_runs_on`<sup>Optional</sup> <a name="workflow_runs_on" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowRunsOn"></a>

- *Type:* typing.List[str]
- *Default:* ["ubuntu-latest"]

Github Runner selection labels.

---

##### `default_release_branch`<sup>Required</sup> <a name="default_release_branch" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.defaultReleaseBranch"></a>

- *Type:* str
- *Default:* "main"

The name of the main release branch.

---

##### `artifacts_directory`<sup>Optional</sup> <a name="artifacts_directory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.artifactsDirectory"></a>

- *Type:* str
- *Default:* "dist"

A directory which will contain build artifacts.

---

##### `auto_approve_upgrades`<sup>Optional</sup> <a name="auto_approve_upgrades" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.autoApproveUpgrades"></a>

- *Type:* bool
- *Default:* true

Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued).

Throw if set to true but `autoApproveOptions` are not defined.

---

##### `build_workflow`<sup>Optional</sup> <a name="build_workflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.buildWorkflow"></a>

- *Type:* bool
- *Default:* true if not a subproject

Define a GitHub workflow for building PRs.

---

##### `build_workflow_triggers`<sup>Optional</sup> <a name="build_workflow_triggers" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.buildWorkflowTriggers"></a>

- *Type:* projen.github.workflows.Triggers
- *Default:* "{ pullRequest: {}, workflowDispatch: {} }"

Build workflow triggers.

---

##### `bundler_options`<sup>Optional</sup> <a name="bundler_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.bundlerOptions"></a>

- *Type:* projen.javascript.BundlerOptions

Options for `Bundler`.

---

##### `code_cov`<sup>Optional</sup> <a name="code_cov" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeCov"></a>

- *Type:* bool
- *Default:* false

Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with @codeCovTokenSecret.

---

##### `code_cov_token_secret`<sup>Optional</sup> <a name="code_cov_token_secret" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.codeCovTokenSecret"></a>

- *Type:* str
- *Default:* if this option is not specified, only public repositories are supported

Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories.

---

##### `copyright_owner`<sup>Optional</sup> <a name="copyright_owner" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.copyrightOwner"></a>

- *Type:* str
- *Default:* defaults to the value of authorName or "" if `authorName` is undefined.

License copyright owner.

---

##### `copyright_period`<sup>Optional</sup> <a name="copyright_period" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.copyrightPeriod"></a>

- *Type:* str
- *Default:* current year

The copyright years to put in the LICENSE file.

---

##### `dependabot`<sup>Optional</sup> <a name="dependabot" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.dependabot"></a>

- *Type:* bool
- *Default:* false

Use dependabot to handle dependency upgrades.

Cannot be used in conjunction with `depsUpgrade`.

---

##### `dependabot_options`<sup>Optional</sup> <a name="dependabot_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.dependabotOptions"></a>

- *Type:* projen.github.DependabotOptions
- *Default:* default options

Options for dependabot.

---

##### `deps_upgrade`<sup>Optional</sup> <a name="deps_upgrade" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.depsUpgrade"></a>

- *Type:* bool
- *Default:* true

Use github workflows to handle dependency upgrades.

Cannot be used in conjunction with `dependabot`.

---

##### `deps_upgrade_options`<sup>Optional</sup> <a name="deps_upgrade_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.depsUpgradeOptions"></a>

- *Type:* projen.javascript.UpgradeDependenciesOptions
- *Default:* default options

Options for `UpgradeDependencies`.

---

##### `gitignore`<sup>Optional</sup> <a name="gitignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.gitignore"></a>

- *Type:* typing.List[str]

Additional entries to .gitignore.

---

##### `jest`<sup>Optional</sup> <a name="jest" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jest"></a>

- *Type:* bool
- *Default:* true

Setup jest unit tests.

---

##### `jest_options`<sup>Optional</sup> <a name="jest_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.jestOptions"></a>

- *Type:* projen.javascript.JestOptions
- *Default:* default options

Jest options.

---

##### `mutable_build`<sup>Optional</sup> <a name="mutable_build" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.mutableBuild"></a>

- *Type:* bool
- *Default:* true

Automatically update files modified during builds to pull-request branches.

This means
that any files synthesized by projen or e.g. test snapshots will always be up-to-date
before a PR is merged.

Implies that PR builds do not have anti-tamper checks.

---

##### ~~`npmignore`~~<sup>Optional</sup> <a name="npmignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmignore"></a>

- *Deprecated:* - use `project.addPackageIgnore`

- *Type:* typing.List[str]

Additional entries to .npmignore.

---

##### `npmignore_enabled`<sup>Optional</sup> <a name="npmignore_enabled" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmignoreEnabled"></a>

- *Type:* bool
- *Default:* true

Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs.

---

##### `npm_ignore_options`<sup>Optional</sup> <a name="npm_ignore_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.npmIgnoreOptions"></a>

- *Type:* projen.IgnoreFileOptions

Configuration options for .npmignore file.

---

##### `package`<sup>Optional</sup> <a name="package" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.package"></a>

- *Type:* bool
- *Default:* true

Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`).

---

##### `prettier`<sup>Optional</sup> <a name="prettier" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prettier"></a>

- *Type:* bool
- *Default:* false

Setup prettier.

---

##### `prettier_options`<sup>Optional</sup> <a name="prettier_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.prettierOptions"></a>

- *Type:* projen.javascript.PrettierOptions
- *Default:* default options

Prettier options.

---

##### `projen_dev_dependency`<sup>Optional</sup> <a name="projen_dev_dependency" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenDevDependency"></a>

- *Type:* bool
- *Default:* true

Indicates of "projen" should be installed as a devDependency.

---

##### `projenrc_js`<sup>Optional</sup> <a name="projenrc_js" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJs"></a>

- *Type:* bool
- *Default:* true if projenrcJson is false

Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation.

---

##### `projenrc_js_options`<sup>Optional</sup> <a name="projenrc_js_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcJsOptions"></a>

- *Type:* projen.javascript.ProjenrcOptions
- *Default:* default options

Options for .projenrc.js.

---

##### `projen_version`<sup>Optional</sup> <a name="projen_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenVersion"></a>

- *Type:* str
- *Default:* Defaults to the latest version.

Version of projen to install.

---

##### `pull_request_template`<sup>Optional</sup> <a name="pull_request_template" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pullRequestTemplate"></a>

- *Type:* bool
- *Default:* true

Include a GitHub pull request template.

---

##### `pull_request_template_contents`<sup>Optional</sup> <a name="pull_request_template_contents" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.pullRequestTemplateContents"></a>

- *Type:* typing.List[str]
- *Default:* default content

The contents of the pull request template.

---

##### `release`<sup>Optional</sup> <a name="release" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.release"></a>

- *Type:* bool
- *Default:* true (false for subprojects)

Add release management to this project.

---

##### `release_to_npm`<sup>Optional</sup> <a name="release_to_npm" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseToNpm"></a>

- *Type:* bool
- *Default:* false

Automatically release to npm when new versions are introduced.

---

##### ~~`release_workflow`~~<sup>Optional</sup> <a name="release_workflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.releaseWorkflow"></a>

- *Deprecated:* see `release`.

- *Type:* bool
- *Default:* true if not a subproject

DEPRECATED: renamed to `release`.

---

##### `workflow_bootstrap_steps`<sup>Optional</sup> <a name="workflow_bootstrap_steps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowBootstrapSteps"></a>

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* "yarn install --frozen-lockfile && yarn projen"

Workflow steps to use in order to bootstrap this repo.

---

##### `workflow_git_identity`<sup>Optional</sup> <a name="workflow_git_identity" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowGitIdentity"></a>

- *Type:* projen.github.GitIdentity
- *Default:* GitHub Actions

The git identity to use in workflows.

---

##### `workflow_node_version`<sup>Optional</sup> <a name="workflow_node_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.workflowNodeVersion"></a>

- *Type:* str
- *Default:* same as `minNodeVersion`

The node version to use in GitHub workflows.

---

##### `disable_tsconfig`<sup>Optional</sup> <a name="disable_tsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.disableTsconfig"></a>

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler).

---

##### `disable_tsconfig_dev`<sup>Optional</sup> <a name="disable_tsconfig_dev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.disableTsconfigDev"></a>

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.dev.json` file.

---

##### `docgen`<sup>Optional</sup> <a name="docgen" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.docgen"></a>

- *Type:* bool
- *Default:* false

Docgen by Typedoc.

---

##### `docs_directory`<sup>Optional</sup> <a name="docs_directory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.docsDirectory"></a>

- *Type:* str
- *Default:* "docs"

Docs directory.

---

##### `entrypoint_types`<sup>Optional</sup> <a name="entrypoint_types" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.entrypointTypes"></a>

- *Type:* str
- *Default:* .d.ts file derived from the project's entrypoint (usually lib/index.d.ts)

The .d.ts file that includes the type declarations for this module.

---

##### `eslint`<sup>Optional</sup> <a name="eslint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.eslint"></a>

- *Type:* bool
- *Default:* true

Setup eslint.

---

##### `eslint_options`<sup>Optional</sup> <a name="eslint_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.eslintOptions"></a>

- *Type:* projen.javascript.EslintOptions
- *Default:* opinionated default options

Eslint options.

---

##### `libdir`<sup>Optional</sup> <a name="libdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.libdir"></a>

- *Type:* str
- *Default:* "lib"

Typescript  artifacts output directory.

---

##### `projenrc_ts`<sup>Optional</sup> <a name="projenrc_ts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcTs"></a>

- *Type:* bool
- *Default:* false

Use TypeScript for your projenrc file (`.projenrc.ts`).

---

##### `projenrc_ts_options`<sup>Optional</sup> <a name="projenrc_ts_options" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.projenrcTsOptions"></a>

- *Type:* projen.typescript.ProjenrcOptions

Options for .projenrc.ts.

---

##### `sample_code`<sup>Optional</sup> <a name="sample_code" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.sampleCode"></a>

- *Type:* bool
- *Default:* true

Generate one-time sample in `src/` and `test/` if there are no files there.

---

##### `srcdir`<sup>Optional</sup> <a name="srcdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.srcdir"></a>

- *Type:* str
- *Default:* "src"

Typescript sources directory.

---

##### `testdir`<sup>Optional</sup> <a name="testdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.testdir"></a>

- *Type:* str
- *Default:* "test"

Jest tests directory. Tests files should be named `xxx.test.ts`.

If this directory is under `srcdir` (e.g. `src/test`, `src/__tests__`),
then tests are going to be compiled into `lib/` and executed as javascript.
If the test directory is outside of `src`, then we configure jest to
compile the code in-memory.

---

##### `tsconfig`<sup>Optional</sup> <a name="tsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfig"></a>

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* default options

Custom TSConfig.

---

##### `tsconfig_dev`<sup>Optional</sup> <a name="tsconfig_dev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfigDev"></a>

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* use the production tsconfig options

Custom tsconfig options for the development tsconfig.json file (used for testing).

---

##### `tsconfig_dev_file`<sup>Optional</sup> <a name="tsconfig_dev_file" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.tsconfigDevFile"></a>

- *Type:* str
- *Default:* "tsconfig.dev.json"

The name of the development tsconfig.json file.

---

##### `typescript_version`<sup>Optional</sup> <a name="typescript_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.typescriptVersion"></a>

- *Type:* str
- *Default:* "latest"

TypeScript version to use.

NOTE: Typescript is not semantically versioned and should remain on the
same minor, so we recommend using a `~` dependency (e.g. `~1.2.3`).

---

##### `rewire`<sup>Optional</sup> <a name="rewire" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.rewire"></a>

- *Type:* typing.Mapping[typing.Any]
- *Default:* No rewired config.

Rewire webpack configuration.

Use this property to override webpack configuration properties provided
by create-react-app, without needing to eject.

This property will create a `config-overrides.js` file in your root directory,
which will contain the desired rewiring code.

To **override** the configuration, you can provide simple key value pairs.
Keys take the form of js code directives that traverse to the desired property.
Values should be JSON serializable objects.

For example, the following config:

```json
rewire: { "module.unknownContextCritical": false }
```

Will translate to the following `config-overrides.js` file:

```js
module.exports = function override(config, env) {
  config.module.unknownContextCritical = false;
}
```

> [https://github.com/timarney/react-app-rewired](https://github.com/timarney/react-app-rewired)

---

##### `application_name`<sup>Optional</sup> <a name="application_name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.applicationName"></a>

- *Type:* str
- *Default:* "Sample App"

Name of the application name.

---

##### `public_dir`<sup>Optional</sup> <a name="public_dir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.Initializer.parameter.publicDir"></a>

- *Type:* str
- *Default:* "public"

Public directory.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addExcludeFromCleanup">add_exclude_from_cleanup</a></code> | Exclude the matching files from pre-synth cleanup. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addGitIgnore">add_git_ignore</a></code> | Adds a .gitignore pattern. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPackageIgnore">add_package_ignore</a></code> | Exclude these files from the bundled package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask">add_task</a></code> | Adds a new task to this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTip">add_tip</a></code> | Prints a "tip" message during synthesis. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.annotateGenerated">annotate_generated</a></code> | Marks the provided file(s) as being generated. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.postSynthesize">post_synthesize</a></code> | Called after all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.preSynthesize">pre_synthesize</a></code> | Called before all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeTask">remove_task</a></code> | Removes a task from a project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.runTaskCommand">run_task_command</a></code> | Returns the shell command to execute in order to run a task. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.synth">synth</a></code> | Synthesize all project files into `outdir`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindFile">try_find_file</a></code> | Finds a file at the specified relative path within this project and all its subprojects. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindJsonFile">try_find_json_file</a></code> | Finds a json file by name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindObjectFile">try_find_object_file</a></code> | Finds an object file (like JsonFile, YamlFile, etc.) by name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryRemoveFile">try_remove_file</a></code> | Finds a file at the specified relative path within this project and removes it. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBins">add_bins</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBundledDeps">add_bundled_deps</a></code> | Defines bundled dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addCompileCommand">add_compile_command</a></code> | DEPRECATED. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDeps">add_deps</a></code> | Defines normal dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDevDeps">add_dev_deps</a></code> | Defines development/test dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addFields">add_fields</a></code> | Directly set fields in `package.json`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addKeywords">add_keywords</a></code> | Adds keywords to package.json (deduplicated). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPeerDeps">add_peer_deps</a></code> | Defines peer dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addScripts">add_scripts</a></code> | Replaces the contents of multiple npm package.json scripts. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTestCommand">add_test_command</a></code> | DEPRECATED. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.hasScript">has_script</a></code> | Indicates if a script by the name name is defined. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeScript">remove_script</a></code> | Removes the npm script (always successful). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.renderWorkflowSetup">render_workflow_setup</a></code> | Returns the set of workflow steps which should be executed to bootstrap a workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.setScript">set_script</a></code> | Replaces the contents of an npm package.json script. |

---

##### `add_exclude_from_cleanup` <a name="add_exclude_from_cleanup" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addExcludeFromCleanup"></a>

```python
def add_exclude_from_cleanup(
  globs: str
) -> None
```

Exclude the matching files from pre-synth cleanup.

Can be used when, for example, some
source files include the projen marker and we don't want them to be erased during synth.

###### `globs`<sup>Required</sup> <a name="globs" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addExcludeFromCleanup.parameter.globs"></a>

- *Type:* str

The glob patterns to match.

---

##### `add_git_ignore` <a name="add_git_ignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addGitIgnore"></a>

```python
def add_git_ignore(
  pattern: str
) -> None
```

Adds a .gitignore pattern.

###### `pattern`<sup>Required</sup> <a name="pattern" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addGitIgnore.parameter.pattern"></a>

- *Type:* str

The glob pattern to ignore.

---

##### `add_package_ignore` <a name="add_package_ignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPackageIgnore"></a>

```python
def add_package_ignore(
  pattern: str
) -> None
```

Exclude these files from the bundled package.

Implemented by project types based on the
packaging mechanism. For example, `NodeProject` delegates this to `.npmignore`.

###### `pattern`<sup>Required</sup> <a name="pattern" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPackageIgnore.parameter.pattern"></a>

- *Type:* str

---

##### `add_task` <a name="add_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask"></a>

```python
def add_task(
  name: str,
  condition: str = None,
  cwd: str = None,
  description: str = None,
  env: typing.Mapping[str] = None,
  required_env: typing.List[str] = None,
  args: typing.List[str] = None,
  exec: str = None,
  receive_args: bool = None,
  steps: typing.List[TaskStep] = None
) -> Task
```

Adds a new task to this project.

This will fail if the project already has
a task with this name.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.name"></a>

- *Type:* str

The task name to add.

---

###### `condition`<sup>Optional</sup> <a name="condition" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.condition"></a>

- *Type:* str

A shell command which determines if the this task should be executed.

If
the program exits with a zero exit code, steps will be executed. A non-zero
code means that task will be skipped.

---

###### `cwd`<sup>Optional</sup> <a name="cwd" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.cwd"></a>

- *Type:* str
- *Default:* process.cwd()

The working directory for all steps in this task (unless overridden by the step).

---

###### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.description"></a>

- *Type:* str
- *Default:* the task name

The description of this build command.

---

###### `env`<sup>Optional</sup> <a name="env" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.env"></a>

- *Type:* typing.Mapping[str]
- *Default:* {}

Defines environment variables for the execution of this task.

Values in this map will be evaluated in a shell, so you can do stuff like `$(echo "foo")`.

---

###### `required_env`<sup>Optional</sup> <a name="required_env" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.requiredEnv"></a>

- *Type:* typing.List[str]

A set of environment variables that must be defined in order to execute this task.

Task execution will fail if one of these is not defined.

---

###### `args`<sup>Optional</sup> <a name="args" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.args"></a>

- *Type:* typing.List[str]
- *Default:* no arguments are passed to the step

Should the provided `exec` shell command receive fixed args.

> [{@link TaskStepOptions.args }]({@link TaskStepOptions.args })

---

###### `exec`<sup>Optional</sup> <a name="exec" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.exec"></a>

- *Type:* str
- *Default:* add steps using `task.exec(command)` or `task.spawn(subtask)`

Shell command to execute as the first command of the task.

---

###### `receive_args`<sup>Optional</sup> <a name="receive_args" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.receiveArgs"></a>

- *Type:* bool
- *Default:* false

Should the provided `exec` shell command receive args passed to the task.

> [{@link TaskStepOptions.receiveArgs }]({@link TaskStepOptions.receiveArgs })

---

###### `steps`<sup>Optional</sup> <a name="steps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTask.parameter.steps"></a>

- *Type:* typing.List[projen.TaskStep]

List of task steps to run.

---

##### ~~`add_tip`~~ <a name="add_tip" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTip"></a>

```python
def add_tip(
  message: str
) -> None
```

Prints a "tip" message during synthesis.

###### `message`<sup>Required</sup> <a name="message" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTip.parameter.message"></a>

- *Type:* str

The message.

---

##### `annotate_generated` <a name="annotate_generated" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.annotateGenerated"></a>

```python
def annotate_generated(
  glob: str
) -> None
```

Marks the provided file(s) as being generated.

This is achieved using the
github-linguist attributes. Generated files do not count against the
repository statistics and language breakdown.

> [https://github.com/github/linguist/blob/master/docs/overrides.md](https://github.com/github/linguist/blob/master/docs/overrides.md)

###### `glob`<sup>Required</sup> <a name="glob" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.annotateGenerated.parameter.glob"></a>

- *Type:* str

the glob pattern to match (could be a file path).

---

##### `post_synthesize` <a name="post_synthesize" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.postSynthesize"></a>

```python
def post_synthesize() -> None
```

Called after all components are synthesized.

Order is *not* guaranteed.

##### `pre_synthesize` <a name="pre_synthesize" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.preSynthesize"></a>

```python
def pre_synthesize() -> None
```

Called before all components are synthesized.

##### `remove_task` <a name="remove_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeTask"></a>

```python
def remove_task(
  name: str
) -> Task
```

Removes a task from a project.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeTask.parameter.name"></a>

- *Type:* str

The name of the task to remove.

---

##### `run_task_command` <a name="run_task_command" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.runTaskCommand"></a>

```python
def run_task_command(
  task: Task
) -> str
```

Returns the shell command to execute in order to run a task.

This will
typically be `npx projen TASK`.

###### `task`<sup>Required</sup> <a name="task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.runTaskCommand.parameter.task"></a>

- *Type:* projen.Task

The task for which the command is required.

---

##### `synth` <a name="synth" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.synth"></a>

```python
def synth() -> None
```

Synthesize all project files into `outdir`.

1. Call "this.preSynthesize()"
2. Delete all generated files
3. Synthesize all sub-projects
4. Synthesize all components of this project
5. Call "postSynthesize()" for all components of this project
6. Call "this.postSynthesize()"

##### `try_find_file` <a name="try_find_file" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindFile"></a>

```python
def try_find_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and all its subprojects.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be resolved
from the root of _this_ project.

---

##### ~~`try_find_json_file`~~ <a name="try_find_json_file" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindJsonFile"></a>

```python
def try_find_json_file(
  file_path: str
) -> JsonFile
```

Finds a json file by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindJsonFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_find_object_file` <a name="try_find_object_file" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindObjectFile"></a>

```python
def try_find_object_file(
  file_path: str
) -> ObjectFile
```

Finds an object file (like JsonFile, YamlFile, etc.) by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryFindObjectFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_remove_file` <a name="try_remove_file" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryRemoveFile"></a>

```python
def try_remove_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and removes it.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.tryRemoveFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be
resolved from the root of _this_ project.

---

##### `add_bins` <a name="add_bins" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBins"></a>

```python
def add_bins(
  bins: typing.Mapping[str]
) -> None
```

###### `bins`<sup>Required</sup> <a name="bins" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBins.parameter.bins"></a>

- *Type:* typing.Mapping[str]

---

##### `add_bundled_deps` <a name="add_bundled_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBundledDeps"></a>

```python
def add_bundled_deps(
  deps: str
) -> None
```

Defines bundled dependencies.

Bundled dependencies will be added as normal dependencies as well as to the
`bundledDependencies` section of your `package.json`.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addBundledDeps.parameter.deps"></a>

- *Type:* str

Names modules to install.

By default, the the dependency will
be installed in the next `npx projen` run and the version will be recorded
in your `package.json` file. You can upgrade manually or using `yarn
add/upgrade`. If you wish to specify a version range use this syntax:
`module@^7`.

---

##### ~~`add_compile_command`~~ <a name="add_compile_command" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addCompileCommand"></a>

```python
def add_compile_command(
  commands: str
) -> None
```

DEPRECATED.

###### `commands`<sup>Required</sup> <a name="commands" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addCompileCommand.parameter.commands"></a>

- *Type:* str

---

##### `add_deps` <a name="add_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDeps"></a>

```python
def add_deps(
  deps: str
) -> None
```

Defines normal dependencies.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDeps.parameter.deps"></a>

- *Type:* str

Names modules to install.

By default, the the dependency will
be installed in the next `npx projen` run and the version will be recorded
in your `package.json` file. You can upgrade manually or using `yarn
add/upgrade`. If you wish to specify a version range use this syntax:
`module@^7`.

---

##### `add_dev_deps` <a name="add_dev_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDevDeps"></a>

```python
def add_dev_deps(
  deps: str
) -> None
```

Defines development/test dependencies.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addDevDeps.parameter.deps"></a>

- *Type:* str

Names modules to install.

By default, the the dependency will
be installed in the next `npx projen` run and the version will be recorded
in your `package.json` file. You can upgrade manually or using `yarn
add/upgrade`. If you wish to specify a version range use this syntax:
`module@^7`.

---

##### `add_fields` <a name="add_fields" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addFields"></a>

```python
def add_fields(
  fields: typing.Mapping[typing.Any]
) -> None
```

Directly set fields in `package.json`.

###### `fields`<sup>Required</sup> <a name="fields" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addFields.parameter.fields"></a>

- *Type:* typing.Mapping[typing.Any]

The fields to set.

---

##### `add_keywords` <a name="add_keywords" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addKeywords"></a>

```python
def add_keywords(
  keywords: str
) -> None
```

Adds keywords to package.json (deduplicated).

###### `keywords`<sup>Required</sup> <a name="keywords" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addKeywords.parameter.keywords"></a>

- *Type:* str

The keywords to add.

---

##### `add_peer_deps` <a name="add_peer_deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPeerDeps"></a>

```python
def add_peer_deps(
  deps: str
) -> None
```

Defines peer dependencies.

When adding peer dependencies, a devDependency will also be added on the
pinned version of the declared peer. This will ensure that you are testing
your code against the minimum version required from your consumers.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addPeerDeps.parameter.deps"></a>

- *Type:* str

Names modules to install.

By default, the the dependency will
be installed in the next `npx projen` run and the version will be recorded
in your `package.json` file. You can upgrade manually or using `yarn
add/upgrade`. If you wish to specify a version range use this syntax:
`module@^7`.

---

##### `add_scripts` <a name="add_scripts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addScripts"></a>

```python
def add_scripts(
  scripts: typing.Mapping[str]
) -> None
```

Replaces the contents of multiple npm package.json scripts.

###### `scripts`<sup>Required</sup> <a name="scripts" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addScripts.parameter.scripts"></a>

- *Type:* typing.Mapping[str]

The scripts to set.

---

##### ~~`add_test_command`~~ <a name="add_test_command" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTestCommand"></a>

```python
def add_test_command(
  commands: str
) -> None
```

DEPRECATED.

###### `commands`<sup>Required</sup> <a name="commands" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.addTestCommand.parameter.commands"></a>

- *Type:* str

---

##### `has_script` <a name="has_script" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.hasScript"></a>

```python
def has_script(
  name: str
) -> bool
```

Indicates if a script by the name name is defined.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.hasScript.parameter.name"></a>

- *Type:* str

The name of the script.

---

##### `remove_script` <a name="remove_script" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeScript"></a>

```python
def remove_script(
  name: str
) -> None
```

Removes the npm script (always successful).

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.removeScript.parameter.name"></a>

- *Type:* str

The name of the script.

---

##### `render_workflow_setup` <a name="render_workflow_setup" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.renderWorkflowSetup"></a>

```python
def render_workflow_setup(
  mutable: bool = None
) -> typing.List[JobStep]
```

Returns the set of workflow steps which should be executed to bootstrap a workflow.

###### `mutable`<sup>Optional</sup> <a name="mutable" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.renderWorkflowSetup.parameter.mutable"></a>

- *Type:* bool
- *Default:* false

Should the pacakge lockfile be updated?

---

##### `set_script` <a name="set_script" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.setScript"></a>

```python
def set_script(
  name: str,
  command: str
) -> None
```

Replaces the contents of an npm package.json script.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.setScript.parameter.name"></a>

- *Type:* str

The script name.

---

###### `command`<sup>Required</sup> <a name="command" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.setScript.parameter.command"></a>

- *Type:* str

The command to execute.

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildTask">build_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.compileTask">compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.components">components</a></code> | <code>typing.List[projen.Component]</code> | Returns all the components within this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.deps">deps</a></code> | <code>projen.Dependencies</code> | Project dependencies. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.ejected">ejected</a></code> | <code>bool</code> | Whether or not the project is being ejected. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.files">files</a></code> | <code>typing.List[projen.FileBase]</code> | All files in this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitattributes">gitattributes</a></code> | <code>projen.GitAttributesFile</code> | The .gitattributes file for this repository. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitignore">gitignore</a></code> | <code>projen.IgnoreFile</code> | .gitignore. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.logger">logger</a></code> | <code>projen.Logger</code> | Logging utilities. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.name">name</a></code> | <code>str</code> | Project name. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.outdir">outdir</a></code> | <code>str</code> | Absolute output directory of this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.packageTask">package_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.postCompileTask">post_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.preCompileTask">pre_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projectBuild">project_build</a></code> | <code>projen.ProjectBuild</code> | Manages the build process of the project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projenCommand">projen_command</a></code> | <code>str</code> | The command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.root">root</a></code> | <code>projen.Project</code> | The root project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tasks">tasks</a></code> | <code>projen.Tasks</code> | Project tasks. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.testTask">test_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.defaultTask">default_task</a></code> | <code>projen.Task</code> | This is the "default" task, the one that executes "projen". |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.initProject">init_project</a></code> | <code>projen.InitProject</code> | The options used when this project is bootstrapped via `projen new`. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.parent">parent</a></code> | <code>projen.Project</code> | A parent project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projectType">project_type</a></code> | <code>projen.ProjectType</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.autoApprove">auto_approve</a></code> | <code>projen.github.AutoApprove</code> | Auto approve set up for this project. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.devContainer">dev_container</a></code> | <code>projen.vscode.DevContainer</code> | Access for .devcontainer.json (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.github">github</a></code> | <code>projen.github.GitHub</code> | Access all github components. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitpod">gitpod</a></code> | <code>projen.Gitpod</code> | Access for Gitpod. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.vscode">vscode</a></code> | <code>projen.vscode.VsCode</code> | Access all VSCode components. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.allowLibraryDependencies">allow_library_dependencies</a></code> | <code>bool</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.artifactsDirectory">artifacts_directory</a></code> | <code>str</code> | The build output directory. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.artifactsJavascriptDirectory">artifacts_javascript_directory</a></code> | <code>str</code> | The location of the npm tarball after build (`${artifactsDirectory}/js`). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.bundler">bundler</a></code> | <code>projen.javascript.Bundler</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.entrypoint">entrypoint</a></code> | <code>str</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.manifest">manifest</a></code> | <code>typing.Any</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.package">package</a></code> | <code>projen.javascript.NodePackage</code> | API for managing the node package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.packageManager">package_manager</a></code> | <code>projen.javascript.NodePackageManager</code> | The package manager to use. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.runScriptCommand">run_script_command</a></code> | <code>str</code> | The command to use to run scripts (e.g. `yarn run` or `npm run` depends on the package manager). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.autoMerge">auto_merge</a></code> | <code>projen.github.AutoMerge</code> | Component that sets up mergify for merging approved pull requests. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildWorkflow">build_workflow</a></code> | <code>projen.build.BuildWorkflow</code> | The PR build GitHub workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildWorkflowJobId">build_workflow_job_id</a></code> | <code>str</code> | The job ID of the build workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.jest">jest</a></code> | <code>projen.javascript.Jest</code> | The Jest configuration (if enabled). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.maxNodeVersion">max_node_version</a></code> | <code>str</code> | Maximum node version required by this package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.minNodeVersion">min_node_version</a></code> | <code>str</code> | Minimum node.js version required by this package. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.npmignore">npmignore</a></code> | <code>projen.IgnoreFile</code> | The .npmignore file. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.prettier">prettier</a></code> | <code>projen.javascript.Prettier</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.publisher">publisher</a></code> | <code>projen.release.Publisher</code> | Package publisher. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.release">release</a></code> | <code>projen.release.Release</code> | Release management. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.upgradeWorkflow">upgrade_workflow</a></code> | <code>projen.javascript.UpgradeDependencies</code> | The upgrade workflow. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.docsDirectory">docs_directory</a></code> | <code>str</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.libdir">libdir</a></code> | <code>str</code> | The directory in which compiled .js files reside. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.srcdir">srcdir</a></code> | <code>str</code> | The directory in which source files reside. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.testdir">testdir</a></code> | <code>str</code> | The directory in which tests reside. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfigDev">tsconfig_dev</a></code> | <code>projen.javascript.TypescriptConfig</code> | A typescript configuration file which covers all files (sources, tests, projen). |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.watchTask">watch_task</a></code> | <code>projen.Task</code> | The "watch" task. |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.docgen">docgen</a></code> | <code>bool</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.eslint">eslint</a></code> | <code>projen.javascript.Eslint</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfig">tsconfig</a></code> | <code>projen.javascript.TypescriptConfig</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfigEslint">tsconfig_eslint</a></code> | <code>projen.javascript.TypescriptConfig</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.applicationName">application_name</a></code> | <code>str</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.publicDir">public_dir</a></code> | <code>str</code> | *No description.* |

---

##### `build_task`<sup>Required</sup> <a name="build_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildTask"></a>

```python
build_task: Task
```

- *Type:* projen.Task

---

##### `commit_generated`<sup>Required</sup> <a name="commit_generated" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool

Whether to commit the managed files by default.

---

##### `compile_task`<sup>Required</sup> <a name="compile_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.compileTask"></a>

```python
compile_task: Task
```

- *Type:* projen.Task

---

##### `components`<sup>Required</sup> <a name="components" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.components"></a>

```python
components: typing.List[Component]
```

- *Type:* typing.List[projen.Component]

Returns all the components within this project.

---

##### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.deps"></a>

```python
deps: Dependencies
```

- *Type:* projen.Dependencies

Project dependencies.

---

##### `ejected`<sup>Required</sup> <a name="ejected" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.ejected"></a>

```python
ejected: bool
```

- *Type:* bool

Whether or not the project is being ejected.

---

##### `files`<sup>Required</sup> <a name="files" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.files"></a>

```python
files: typing.List[FileBase]
```

- *Type:* typing.List[projen.FileBase]

All files in this project.

---

##### `gitattributes`<sup>Required</sup> <a name="gitattributes" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitattributes"></a>

```python
gitattributes: GitAttributesFile
```

- *Type:* projen.GitAttributesFile

The .gitattributes file for this repository.

---

##### `gitignore`<sup>Required</sup> <a name="gitignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitignore"></a>

```python
gitignore: IgnoreFile
```

- *Type:* projen.IgnoreFile

.gitignore.

---

##### `logger`<sup>Required</sup> <a name="logger" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.logger"></a>

```python
logger: Logger
```

- *Type:* projen.Logger

Logging utilities.

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.name"></a>

```python
name: str
```

- *Type:* str

Project name.

---

##### `outdir`<sup>Required</sup> <a name="outdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.outdir"></a>

```python
outdir: str
```

- *Type:* str

Absolute output directory of this project.

---

##### `package_task`<sup>Required</sup> <a name="package_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.packageTask"></a>

```python
package_task: Task
```

- *Type:* projen.Task

---

##### `post_compile_task`<sup>Required</sup> <a name="post_compile_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.postCompileTask"></a>

```python
post_compile_task: Task
```

- *Type:* projen.Task

---

##### `pre_compile_task`<sup>Required</sup> <a name="pre_compile_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.preCompileTask"></a>

```python
pre_compile_task: Task
```

- *Type:* projen.Task

---

##### `project_build`<sup>Required</sup> <a name="project_build" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projectBuild"></a>

```python
project_build: ProjectBuild
```

- *Type:* projen.ProjectBuild

Manages the build process of the project.

---

##### `projen_command`<sup>Required</sup> <a name="projen_command" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str

The command to use in order to run the projen CLI.

---

##### `root`<sup>Required</sup> <a name="root" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.root"></a>

```python
root: Project
```

- *Type:* projen.Project

The root project.

---

##### `tasks`<sup>Required</sup> <a name="tasks" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tasks"></a>

```python
tasks: Tasks
```

- *Type:* projen.Tasks

Project tasks.

---

##### `test_task`<sup>Required</sup> <a name="test_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.testTask"></a>

```python
test_task: Task
```

- *Type:* projen.Task

---

##### `default_task`<sup>Optional</sup> <a name="default_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.defaultTask"></a>

```python
default_task: Task
```

- *Type:* projen.Task

This is the "default" task, the one that executes "projen".

Undefined if
the project is being ejected.

---

##### `init_project`<sup>Optional</sup> <a name="init_project" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.initProject"></a>

```python
init_project: InitProject
```

- *Type:* projen.InitProject

The options used when this project is bootstrapped via `projen new`.

It
includes the original set of options passed to the CLI and also the JSII
FQN of the project type.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

A parent project.

If undefined, this is the root project.

---

##### `project_type`<sup>Required</sup> <a name="project_type" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.projectType"></a>

```python
project_type: ProjectType
```

- *Type:* projen.ProjectType

---

##### `auto_approve`<sup>Optional</sup> <a name="auto_approve" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.autoApprove"></a>

```python
auto_approve: AutoApprove
```

- *Type:* projen.github.AutoApprove

Auto approve set up for this project.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.devContainer"></a>

```python
dev_container: DevContainer
```

- *Type:* projen.vscode.DevContainer

Access for .devcontainer.json (used for GitHub Codespaces).

This will be `undefined` if devContainer boolean is false

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.github"></a>

```python
github: GitHub
```

- *Type:* projen.github.GitHub

Access all github components.

This will be `undefined` for subprojects.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.gitpod"></a>

```python
gitpod: Gitpod
```

- *Type:* projen.Gitpod

Access for Gitpod.

This will be `undefined` if gitpod boolean is false

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.vscode"></a>

```python
vscode: VsCode
```

- *Type:* projen.vscode.VsCode

Access all VSCode components.

This will be `undefined` for subprojects.

---

##### ~~`allow_library_dependencies`~~<sup>Required</sup> <a name="allow_library_dependencies" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.allowLibraryDependencies"></a>

- *Deprecated:* use `package.allowLibraryDependencies`

```python
allow_library_dependencies: bool
```

- *Type:* bool

---

##### `artifacts_directory`<sup>Required</sup> <a name="artifacts_directory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.artifactsDirectory"></a>

```python
artifacts_directory: str
```

- *Type:* str

The build output directory.

An npm tarball will be created under the `js`
subdirectory. For example, if this is set to `dist` (the default), the npm
tarball will be placed under `dist/js/boom-boom-1.2.3.tg`.

---

##### `artifacts_javascript_directory`<sup>Required</sup> <a name="artifacts_javascript_directory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.artifactsJavascriptDirectory"></a>

```python
artifacts_javascript_directory: str
```

- *Type:* str

The location of the npm tarball after build (`${artifactsDirectory}/js`).

---

##### `bundler`<sup>Required</sup> <a name="bundler" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.bundler"></a>

```python
bundler: Bundler
```

- *Type:* projen.javascript.Bundler

---

##### ~~`entrypoint`~~<sup>Required</sup> <a name="entrypoint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.entrypoint"></a>

- *Deprecated:* use `package.entrypoint`

```python
entrypoint: str
```

- *Type:* str

---

##### ~~`manifest`~~<sup>Required</sup> <a name="manifest" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.manifest"></a>

- *Deprecated:* use `package.addField(x, y)`

```python
manifest: typing.Any
```

- *Type:* typing.Any

---

##### `package`<sup>Required</sup> <a name="package" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.package"></a>

```python
package: NodePackage
```

- *Type:* projen.javascript.NodePackage

API for managing the node package.

---

##### ~~`package_manager`~~<sup>Required</sup> <a name="package_manager" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.packageManager"></a>

- *Deprecated:* use `package.packageManager`

```python
package_manager: NodePackageManager
```

- *Type:* projen.javascript.NodePackageManager

The package manager to use.

---

##### `run_script_command`<sup>Required</sup> <a name="run_script_command" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.runScriptCommand"></a>

```python
run_script_command: str
```

- *Type:* str

The command to use to run scripts (e.g. `yarn run` or `npm run` depends on the package manager).

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.autoMerge"></a>

```python
auto_merge: AutoMerge
```

- *Type:* projen.github.AutoMerge

Component that sets up mergify for merging approved pull requests.

---

##### `build_workflow`<sup>Optional</sup> <a name="build_workflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildWorkflow"></a>

```python
build_workflow: BuildWorkflow
```

- *Type:* projen.build.BuildWorkflow

The PR build GitHub workflow.

`undefined` if `buildWorkflow` is disabled.

---

##### `build_workflow_job_id`<sup>Optional</sup> <a name="build_workflow_job_id" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.buildWorkflowJobId"></a>

```python
build_workflow_job_id: str
```

- *Type:* str

The job ID of the build workflow.

---

##### `jest`<sup>Optional</sup> <a name="jest" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.jest"></a>

```python
jest: Jest
```

- *Type:* projen.javascript.Jest

The Jest configuration (if enabled).

---

##### `max_node_version`<sup>Optional</sup> <a name="max_node_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.maxNodeVersion"></a>

```python
max_node_version: str
```

- *Type:* str

Maximum node version required by this package.

---

##### `min_node_version`<sup>Optional</sup> <a name="min_node_version" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.minNodeVersion"></a>

```python
min_node_version: str
```

- *Type:* str

Minimum node.js version required by this package.

---

##### `npmignore`<sup>Optional</sup> <a name="npmignore" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.npmignore"></a>

```python
npmignore: IgnoreFile
```

- *Type:* projen.IgnoreFile

The .npmignore file.

---

##### `prettier`<sup>Optional</sup> <a name="prettier" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.prettier"></a>

```python
prettier: Prettier
```

- *Type:* projen.javascript.Prettier

---

##### ~~`publisher`~~<sup>Optional</sup> <a name="publisher" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.publisher"></a>

- *Deprecated:* use `release.publisher`.

```python
publisher: Publisher
```

- *Type:* projen.release.Publisher

Package publisher.

This will be `undefined` if the project does not have a
release workflow.

---

##### `release`<sup>Optional</sup> <a name="release" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.release"></a>

```python
release: Release
```

- *Type:* projen.release.Release

Release management.

---

##### `upgrade_workflow`<sup>Optional</sup> <a name="upgrade_workflow" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.upgradeWorkflow"></a>

```python
upgrade_workflow: UpgradeDependencies
```

- *Type:* projen.javascript.UpgradeDependencies

The upgrade workflow.

---

##### `docs_directory`<sup>Required</sup> <a name="docs_directory" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.docsDirectory"></a>

```python
docs_directory: str
```

- *Type:* str

---

##### `libdir`<sup>Required</sup> <a name="libdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.libdir"></a>

```python
libdir: str
```

- *Type:* str

The directory in which compiled .js files reside.

---

##### `srcdir`<sup>Required</sup> <a name="srcdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.srcdir"></a>

```python
srcdir: str
```

- *Type:* str

The directory in which source files reside.

---

##### `testdir`<sup>Required</sup> <a name="testdir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.testdir"></a>

```python
testdir: str
```

- *Type:* str

The directory in which tests reside.

---

##### `tsconfig_dev`<sup>Required</sup> <a name="tsconfig_dev" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfigDev"></a>

```python
tsconfig_dev: TypescriptConfig
```

- *Type:* projen.javascript.TypescriptConfig

A typescript configuration file which covers all files (sources, tests, projen).

---

##### `watch_task`<sup>Required</sup> <a name="watch_task" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.watchTask"></a>

```python
watch_task: Task
```

- *Type:* projen.Task

The "watch" task.

---

##### `docgen`<sup>Optional</sup> <a name="docgen" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.docgen"></a>

```python
docgen: bool
```

- *Type:* bool

---

##### `eslint`<sup>Optional</sup> <a name="eslint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.eslint"></a>

```python
eslint: Eslint
```

- *Type:* projen.javascript.Eslint

---

##### `tsconfig`<sup>Optional</sup> <a name="tsconfig" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfig"></a>

```python
tsconfig: TypescriptConfig
```

- *Type:* projen.javascript.TypescriptConfig

---

##### `tsconfig_eslint`<sup>Optional</sup> <a name="tsconfig_eslint" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.tsconfigEslint"></a>

```python
tsconfig_eslint: TypescriptConfig
```

- *Type:* projen.javascript.TypescriptConfig

---

##### `application_name`<sup>Required</sup> <a name="application_name" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.applicationName"></a>

```python
application_name: str
```

- *Type:* str

---

##### `public_dir`<sup>Required</sup> <a name="public_dir" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.publicDir"></a>

```python
public_dir: str
```

- *Type:* str

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.DEFAULT_TASK">DEFAULT_TASK</a></code> | <code>str</code> | The name of the default task (the task executed when `projen` is run without arguments). |

---

##### `DEFAULT_TASK`<sup>Required</sup> <a name="DEFAULT_TASK" id="@aws-prototyping-sdk/cloudscape-react-ts-website.CloudscapeReactTsWebsiteProject.property.DEFAULT_TASK"></a>

```python
DEFAULT_TASK: str
```

- *Type:* str

The name of the default task (the task executed when `projen` is run without arguments).

Normally
this task should synthesize the project files.

---


